@@ -46,24 +46,14 @@ class MenuManager extends CMSModule
     return $this->CheckPermission('Manage Menu');
   }
 
-  function Uninstall()
-  {
-    // remove the permissions
-    $this->RemovePermission('Manage Menu');
-    $this->RemovePreference();
-    $this->RemoveEventHandler('Core','ContentEditPost');
-    $this->RemoveEventHandler('Core','ContentDeletePost');
-    $this->DeleteTemplate();
-  }
-
   function GetVersion()
   {
-    return '1.7.7';
+    return '1.8.2';
   }
 
   function MinimumCMSVersion()
   {
-    return '1.10-beta0';
+    return '1.11-alpha0';
   }
 
   function GetAdminDescription()
@@ -76,7 +66,15 @@ class MenuManager extends CMSModule
     return 'layout';
   }
 
-  function LazyLoadFrontend() { return TRUE; }
+  function LazyLoadFrontend() 
+  { 
+	return FALSE; 
+  }
+
+  function LazyLoadAdmin()
+  {
+	return FALSE;
+  }
 
   public function InitializeFrontend()
   {
@@ -95,9 +93,13 @@ class MenuManager extends CMSModule
     $this->SetParameterType('includeprefix',CLEAN_STRING); 
     $this->SetParameterType('childrenof',CLEAN_STRING);
     $this->SetParameterType('nocache',CLEAN_INT);
+    $this->SetParameterType('root',CLEAN_STRING);
+
+    //cmsms()->GetSmarty()->register_function('menu',array($this,'function_plugin')); <- Moved to install method
+    //cmsms()->GetSmarty()->register_function('cms_breadcrumbs',array($this,'smarty_cms_breadcrumbs')); <- Moved to install method
   }
 
-  function SetParameters()
+  function InitializeAdmin()
   {
     $this->CreateParameter('collapse', '1', $this->lang('help_collapse'));
     $this->CreateParameter('loadprops', '0', $this->lang('help_loadprops'));
@@ -113,6 +115,8 @@ class MenuManager extends CMSModule
     $this->CreateParameter('includeprefix','',$this->Lang('help_includeprefix'));
     $this->CreateParameter('childrenof','',$this->Lang('help_childrenof'));
     $this->CreateParameter('nocache','',$this->Lang('help_nocache'));
+    $this->CreateParameter('root','',$this->Lang('help_root'));
+    $this->CreateParameter('action','',$this->Lang('help_action'));
   }
 
   /**
@@ -147,14 +151,18 @@ class MenuManager extends CMSModule
 	if (isset($children) && count($children))
 	  {
 	    reset($children);
+	    $nchildren = count($children);
+	    $nc = -1;
 	    while (list($key) = each($children))
 	      {
+		$nc++;
 		$onechild =& $children[$key];
 		$content = $onechild->GetContent($deep);
 		if( !is_object($content) ) 
 		  {
 		    // uhm, couldn't get the content object... this is strange
 		    // should I trigger an error?
+		    $nchildren--;
 		    continue;
 		  }
 
@@ -194,7 +202,15 @@ class MenuManager extends CMSModule
 		    ($content->ShowInMenu() || ($show_all == 1  && !$content->IsSystemPage())))
 		  {
 		    $newnode = $this->FillNode($content, $onechild, $nodelist, 
-					       $gCms, $count, $prevdepth, $origdepth, $deep, $params);
+					       $count, $prevdepth, $origdepth, $deep, $params);
+		    if( $nc == 0 )
+		      {
+			$newnode->first = 1;
+		      }
+		    if( $nc >= $nchildren - 1 )
+		      {
+			$newnode->last = 1;
+		      }
 		    $nadded++;
 
 		    //Ok, this one is nasty...
@@ -222,11 +238,8 @@ class MenuManager extends CMSModule
       return $nadded;
   }
 
-  function & FillNode(&$content, &$node, &$nodelist, &$gCms, &$count, &$prevdepth, $origdepth, $deep = false, $params = array())
+  function & FillNode(&$content, &$node, &$nodelist, &$count, &$prevdepth, $origdepth, $deep = false, $params = array())
     {
-      $gCms = cmsms();
-      $config = $gCms->GetConfig();
-
       $onenode = new stdClass();
       $onenode->id = $content->Id();
       $onenode->pagetitle = $content->Name();
@@ -238,12 +251,17 @@ class MenuManager extends CMSModule
       $onenode->modified = $content->GetModifiedDate();
       $onenode->created = $content->GetCreationDate();
       $onenode->hierarchy = $content->Hierarchy();
+      $onenode->haschildren = false;
+      if( $content->DefaultContent() )
+	{
+	  $onenode->default = 1;
+	}
       $onenode->depth = count(explode('.', $content->Hierarchy())) - ($origdepth - 1);
       $onenode->prevdepth = $prevdepth - ($origdepth - 1);
       if ($onenode->prevdepth == 0)
 	$onenode->prevdepth = 1;
       $onenode->children_exist = false;
-      if ($node->has_children())
+      if (is_object($node) && $node->has_children())
 	{
 	  $children = $node->get_children();
 	  if( $children )
@@ -251,7 +269,7 @@ class MenuManager extends CMSModule
 	      for( $i = 0; $i < count($children); $i++ )
 		{
 		  $tmpc = $children[$i]->getContent(false,true,true);
-		  if( $tmpc->Active() && $tmpc->ShowInMenu() )
+		  if( is_object($tmpc) && $tmpc->Active() && $tmpc->ShowInMenu() )
 		    {
 		      $onenode->children_exist = true;
 		      break;
@@ -259,9 +277,8 @@ class MenuManager extends CMSModule
 		}
 	    }
 	}
-      $onenode->haschildren = false;
       $prevdepth = $onenode->depth + ($origdepth - 1);
-      $onenode->menutext = my_htmlentities($content->MenuText());
+      $onenode->menutext = cms_htmlentities($content->MenuText());
       $onenode->raw_menutext = $content->MenuText();
       $onenode->target = '';
       $onenode->index = $count;
@@ -269,8 +286,10 @@ class MenuManager extends CMSModule
       $onenode->parent = false;
       $count++;
 
+      $gCms = cmsms();
       if( $deep )
 	{
+	  $config = cmsms()->GetConfig();
 	  $onenode->extra1 = $content->GetPropertyValue('extra1');
 	  $onenode->extra2 = $content->GetPropertyValue('extra2');
 	  $onenode->extra3 = $content->GetPropertyValue('extra3');
@@ -360,7 +379,7 @@ class MenuManager extends CMSModule
 
   function GetChangeLog()
   {
-    return $this->Lang('changelog');
+    return file_get_contents(dirname(__FILE__).'/changelog.inc');
   } 
 
   function GetMenuTemplate($tpl_name)
@@ -410,6 +429,14 @@ class MenuManager extends CMSModule
 	  }
       }
   }
+
+
+  final static public function smarty_cms_breadcrumbs($params,&$smarty)
+  {
+    $params['action'] = 'breadcrumbs';
+    $params['module'] = 'MenuManager';
+    return cms_module_plugin($params,$smarty);
+  }
 } // End of class
 
 # vim:ts=4 sw=4 noet
