@@ -1,6 +1,20 @@
 <?php
-$lang['usage'] = 'Uso';
-$lang['help_loadprops'] = 'Usa questo parametro quando stai usando le propriet&agrave; avanzate nel Vostro MenuManager template. Questo parametro forzer&agrave; il caricamento di tutte le propriet&agrave; di ciascun nodo (come extra1, image, thumbnail, etc) e quindi permetter&agrave; la costruzione di menu molto pi&ugrave; avanzati ma aumenter&agrave; considerevolmente il numero di query richieste per costruire un menu e quindi l&#039;ammontare di memoria richiesta';
+$lang['help_action'] = 'Specificare il comportamento del modulo.  Ci sono due possibilit&agrave; per questo parametro:
+<ul>
+  <li>default <em>(default)</em> - Utilizzato per costruire un menu di navigazione.</li>
+  <li>breadcrumbs - Utilizzato per creare l&#039;indicazione di percorso alla pagina visualizzata.  <strong>Nota: {cms_breadcrumbs}</strong> &egrave; un&#039;abbreviazione per per richiamare questa zione.</li>
+</ul>';
+$lang['help_root'] = 'Applicabile solo all&#039;azione breadcrumbs, permette di specificare un livello di partenza che non sia la pagina predefinita.';
+$lang['youarehere'] = 'Voi siete qui';
+$lang['set_cachable'] = 'Imposta questo template come memorizzabile in cache';
+$lang['help_nocache'] = 'Disabilita la memorizzazione in cache di questa chiamata al menu. Questo parametro, se impostato su un valore positivo, sovrascrive qualsiasi impostazione nell&#039;oggetto Contenuto e nel template del menu.';
+$lang['cachable'] = 'Memorizzabile in cache';
+$lang['help_childrenof'] = 'Con questa opzione il menu visualizzer&agrave; solo gli elementi di livello superiore all&#039;ID di pagina o alias selezionato. Ad es.: <code>{menu childrenof=$page_alias}</code> visualizzer&agrave; solo le pagine figlio di quella corrente.';
+$lang['usage'] = 'Utilizzo';
+$lang['import'] = 'Importa';
+$lang['edit'] = 'Modifica';
+$lang['delete'] = 'Elimina';
+$lang['help_loadprops'] = 'Utilizzate questo parametro quando NON state sfruttando propriet&agrave; avanzate nel vostro modello del gestore menu. Questo parametro disabiliter&agrave; il caricamento di tutte le propriet&agrave; di contenuto per ogni nodo (come extra1, imagine, miniatura, ecc.). Quest&#039;operazione diminuir&agrave; drasticamente il numero di query richieste per creare il menu e la memoria necessaria, ma inibir&agrave; la possibilit&agrave; di menu molto pi&ugrave; avanzati';
 $lang['readonly'] = 'sola lettura';
 $lang['error_templatename'] = 'Voi non potete specificare un nome di template che termina con .tpl';
 $lang['this_is_default'] = 'Menu template predefinito';
@@ -9,22 +23,6 @@ $lang['default'] = 'Predefinito';
 $lang['templates'] = 'Modelli';
 $lang['addtemplate'] = 'Aggiungere Modello';
 $lang['areyousure'] = 'Sei sicuri di volerlo eliminare?';
-$lang['changelog'] = '	<ul>
-<li>1.6.3 - Adds usage column.</li>
-<li>1.6.2 - Can no longer delete default template, fix problem with default database templates.</li>
-<li>1.6.1 - Add created and modified entries on each node.</li>
-<li>1.6 - Re-design admin interface, allow setting the default menu manager template.</li>
-        <li>1.5.4 - Minor bugfix, now require CMS 1.5.3.</li>
-        <li>1.5.3 - Support for syntax hilighter.</li>
-        <li>1.5.2 - Added more fields available in each node in the template.</li>
-        <li>1.5 - Bump version to be compatible with 1.1 only, and add the SetParameterTypes calls</li>
-
-	<li>1.4.1 -- Fix a problem where menus would not show if includeprefix was not specified.
-	<li>1.4 -- Accept a comma separated list of includeprefixes or excludeprefixes</li>
-	<li>1.3 -- Added includeprefix and excludeprefix params</li>
-	<li>1.1 -- Added handling of target parameter, mainly for the Link content type</li>
-	<li>1.0 -- Initial Release</li>
-</ul>';
 $lang['dbtemplates'] = 'Database dei Modelli';
 $lang['description'] = 'Gestione dei Modelli per visualizzare i menu in ogni maniera.';
 $lang['deletetemplate'] = 'Elimina Modello';
@@ -83,7 +81,11 @@ $lang['help'] = '	<h3>Che cosa fa?</h3>
 			<li>$node->index -- Contatore di questo nodo nell&#039;intero menu</li>
 			<li>$node->parent -- True (vero) se questo nodo &egrave; un parent (genitore) della pagina correntemente selezionata</li>
 		</ul>
-	</p>';
+	</p>
+        <h3>Caching</h3>
+        <p>This module has the capability to cache its output into static files to reduce memory requirements and sql queries, and to improve frontend performance.  This provides all the advantages of static menus without the inconvenience involved when creating or editing pages.</p>
+        <p>Each menu template can be marked as &amp;quot;Cachable&amp;quot;. When a cachable menu template is used on a content page that is cachable, any cached menu output that is available for thsi page will be used.  The nocache parameter on the menu tag can be used to completely disable caching.</p>
+        <p>All cached menu files are erased when a content item is added, edited, or deleted... and also when a menu template is added/edited or deleted.</p>';
 $lang['importtemplate'] = 'Importa Modello nel database';
 $lang['menumanager'] = 'Gestore menu';
 $lang['newtemplate'] = 'Nuovo nome di Modello';
@@ -92,9 +94,9 @@ $lang['notemplatefiles'] = 'Nessun modello per file in %s';
 $lang['notemplatename'] = 'Nessun nome di Modello fornito.';
 $lang['templatecontent'] = 'Contenuto del Modello';
 $lang['templatenameexists'] = 'Un Modello con questo nome esiste gi&agrave;';
-$lang['qca'] = 'P0-341425854-1271258489279';
-$lang['utma'] = '156861353.1785716972.1271258827.1272464498.1272484592.7';
-$lang['utmz'] = '156861353.1272484592.7.6.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
+$lang['utma'] = '156861353.1309687447.1326717301.1326717301.1326717301.1';
+$lang['utmz'] = '156861353.1326717301.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['qca'] = 'P0-1222936636-1320224029415';
+$lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.1.10.1272484592';
 ?>
\ No newline at end of file
