@@ -20,7 +20,7 @@
  #$Id$
  #
  */
-if( !isset($gCms) ) exit;
+if( !cmsms() ) exit();
 
 global $CMS_ADMIN_PAGE;
 if( isset($CMS_ADMIN_PAGE) ) return;
