@@ -153,15 +153,12 @@ Added dependency checking.
   <li>Changes to REST API.. No longer uses nuSOAP.</li>
   <li>Many optimizations to downloading and installing modules.</li>
   <li>Can now install older versions of modules easily.</li>
-  <li>Handle automatic upgrading of ddependencies.</li>
+  <li>Handle automatic upgrading of dependencies.</li>
 </ul>
 </li>
-
-
-
 </ul>';
 $lang['help'] = '<h3>Was macht dieses Modul?</h3>
-<p>Ein Client f&uuml;r das Modul &quot;ModulRepository&quot;. Dieses Modul erlaubt die Vorschau und die Modul-Installation von Remote-Seiten aus, ohne dass diese per FTP auf den Server geladen oder entpackt werden m&uuml;ssen. Die XML-Modul-Dateien werden &uuml;ber die SOAP-Technologie herunter geladen, auf Integrit&auml;t &uuml;berpr&uuml;ft und automatisch entpackt.</p>
+<p>Ein Client f&uuml;r das Modul &quot;ModulRepository&quot;. Dieses Modul erlaubt die Vorschau und die Modul-Installation von Remote-Seiten aus, ohne dass diese per FTP auf den Server geladen oder entpackt werden m&uuml;ssen. Die XML-Modul-Dateien werden &uuml;ber die REST-Technologie herunter geladen, auf Integrit&auml;t &uuml;berpr&uuml;ft und automatisch entpackt.</p>
 <h3>Wie wird es eingesetzt ?</h3>
 <p>Zur Verwendung dieses Moduls ben&ouml;tigen Sie die Berechtigung &#039;Modify Modules&#039; und die URL einer &#039;ModulRepository&#039;-Installation. Diese URL k&ouml;nnen Sie auf der Seite &#039;Erweiterungen > ModulManager > Einstellungen&#039; festlegen.</p>
 <p>Die Administration dieses Moduls finden Sie im Men&uuml; &#039;Erweiterungen&#039;. Bei Auswahl dieses Moduls wird automatisch eine Liste der verf&uuml;gbaren XML-Module abgefragt.  Diese Liste wird auf die Liste der aktuell installierten Module referenziert und eine Zusammenfassung angezeigt. Sie k&ouml;nnen sich die Beschreibung und die Hilfe der zu Module anzeigen lassen, ohne diese installieren zu m&uuml;ssen. Von hier aus k&ouml;nnen die Module dann auch installiert oder aktualisiert werden.</p>
@@ -170,9 +167,8 @@ $lang['help'] = '<h3>Was macht dieses Modul?</h3>
 <h3>Copyright und Lizenz</h3>
 <p>Copyright &copy; 2006, calguy1000 <a href="mailto:calguy1000@hotmail.com"><calguy1000@hotmail.com></a>. Alle Rechte vorbehalten.</p>
 <p>Dieses Modul wurde unter der <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a> ver&ouml;ffentlicht. Sie m&uuml;ssen dieser Lizenz zustimmen, bevor Sie das Modul verwenden.</p>';
-$lang['utma'] = '156861353.1689361602.1315895785.1315895785.1315895785.1';
-$lang['utmz'] = '156861353.1315895785.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
-$lang['qca'] = 'P0-1209344414-1263563671334';
-$lang['utmb'] = '156861353';
+$lang['utma'] = '156861353.1800671983.1321592330.1321592330.1321592330.1';
+$lang['utmz'] = '156861353.1321592330.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
