@@ -1,16 +1,16 @@
 <?php
 $lang['error_search'] = 'S&oslash;kefeil';
-$lang['prompt_disable_caching'] = 'Deaktiver mellomlagring av foresp&oslash;rsler fra serveren';
-$lang['info_disable_caching'] = '<strong>Ikke Anbefalt</strong>. For bedre ytelse s&aring; vil ModuleManager mellomlagre (som standard en time) mye av informasjonen hentet fra den eksterne serveren';
-$lang['operation_results'] = 'Operasjonsresultater';
-$lang['error_noresults'] = 'Vi forventet noen resultater &aring; v&aelig;re tilgjengelig fra perasjoner lagt i k&oslash;, men ingen ble funnet. Vennligst fors&oslash;k &aring; gjenskape denne hendelsen, og gi tilstrekkelig informasjon til &aring; st&oslash;ttepersonell for diagnostisering';
-$lang['versionsformodule'] = 'Tilgjengelige versjoner av modulen %s';
+$lang['prompt_disable_caching'] = 'Sl&aring; av mellomlagring av foresp&oslash;rsler fra serveren';
+$lang['info_disable_caching'] = 'strong>Ikke Anbefalt</strong>. Av ytelsesgrunner vil ModuleManager mellomlagre mye av informasjonen som hentes fra den eksterne serveren (som standard en time)';
+$lang['operation_results'] = 'Handlingsresultater';
+$lang['error_noresults'] = 'Vi forventet noen resultater &aring; v&aelig;re tilgjengelig fra operasjoner i k&oslash;, men ingen ble funnet. Pr&oslash;v &aring; reprodusere denne erfaringen, og gi tilstrekkelig informasjon for &aring; st&oslash;tte personell for diagnostisering.';
+$lang['versionsformodule'] = 'Tilgjengelige versjoner av modulen%s';
 $lang['yourversion'] = 'Din versjon';
-$lang['latestdepends'] = 'Installer alltid de nyeste modulene';
-$lang['info_latestdepends'] = 'N&aring;r du installerer en modul med avhengigheter, s&aring; vil dette alternativet s&oslash;rge for at den seneste versjonen av avhengigheten blir installert';
+$lang['latestdepends'] = 'Alltid installer de nyeste modulversjonene';
+$lang['info_latestdepends'] = 'N&aring;r du installerer en modul med avhengigheter, vil dette alternativet sikre at den nyeste versjonen av avhengigheten vil bli installert';
 $lang['error_internal'] = 'Intern feil... Vennligst rapporter dette til din systemadministrator';
-$lang['error_downloadxml'] = 'Et problem oppstod ved nedlasting av XML-filen: %s';
-$lang['error_request_problem'] = 'Et problem oppstod under kommunikasjon med modul-serveren';
+$lang['error_downloadxml'] = 'Et problem oppstod ved nedlasting av XML filen: %s';
+$lang['error_request_problem'] = 'Et problem oppstod under kommunikasjon med modulserveren';
 $lang['error_searchterm'] = 'Vennligst oppgi noe som er gyldig &aring; s&oslash;ke etter';
 $lang['search_noresults'] = 'S&oslash;k lyktes men ingen resultater matchet uttrykket det ble s&oslash;kt etter';
 $lang['advancedsearch_help'] = 'Angi ord som skal inkluderes eller ekskluderes fra s&oslash;ket ved hjelp av en + eller -, omslutt eksakte setninger med sitattegn. i.e:   +r&oslash;d -eple +&quot;tekst&quot;';
@@ -63,7 +63,7 @@ $lang['download'] = 'Last ned og Installer';
 $lang['error_moduleinstallfailed'] = 'Modul installasjonen feilet';
 $lang['error_connectnomodules'] = 'Selv om tilkobling var vellykket til det spesifiserte modullageret, s&aring; ser det ut til at dette lageret enn&aring; ikke deler noen moduler';
 $lang['submit'] = 'Utf&oslash;r';
-$lang['text_repository_url'] = 'Linken burde v&aelig;re som dette http://www.mycmssite.com/path/soap.php?module=ModuleRepository';
+$lang['text_repository_url'] = 'Linken burde v&aelig;re som dette http://www.mycmsmssite.com/ModuleRepository/request/v2 (forutsatt pene webadresser er aktivert p&aring; depotserveren)<br />Merk: &Aring; &aring;pne denne lenken i nettleseren din vil returnere en Error404!';
 $lang['prompt_repository_url'] = 'ModulLager Link:';
 $lang['title_installation'] = 'Installasjon';
 $lang['availmodules'] = 'Tilgjengelige Moduler';
@@ -167,8 +167,8 @@ $lang['help'] = '<h3>Hva gj&oslash;r denne?</h3>
 <p> Copyright &copy; 2006, calguy1000 <a href="mailto:calguy1000@hotmail.com"> <calguy1000@hotmail.com> </a>. Alle rettigheter er reservert. </p>
 <p> Denne modulen har blitt utgitt under <a href="http://www.gnu.org/licenses/licenses.html#GPL"> GNU Public License </a>. Du m&aring; godta denne lisensavtalen f&oslash;r du bruker modulen. </p>';
 $lang['qca'] = 'P0-536849115-1307983495210';
-$lang['utma'] = '156861353.1064316688.1319894667.1320446839.1320502404.15';
-$lang['utmz'] = '156861353.1319894667.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
-$lang['utmb'] = '156861353.2.10.1320502404';
+$lang['utma'] = '156861353.1599290770.1342983049.1343408911.1343423602.14';
+$lang['utmz'] = '156861353.1342983049.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
+$lang['utmb'] = '156861353.1.10.1343424179';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
