@@ -1,16 +1,16 @@
 <?php
-$lang['error_search'] = 'Search Error';
-$lang['prompt_disable_caching'] = 'Disable caching of requests from the server';
-$lang['info_disable_caching'] = '<strong>Not Recommended</strong>.  For performance reasons, ModuleManager will cache for (by default one hour) much of the information retrieved from the remote server';
-$lang['operation_results'] = 'Operation Results';
+$lang['error_search'] = 'Napaka v iskanju';
+$lang['prompt_disable_caching'] = 'Onemogoči predpomnenje zahtev iz strežnika';
+$lang['info_disable_caching'] = '<strong>Not Recommended</strong>.  For performance reasons, ModuleManager will cache for (by default one hour) much of the information retrieved from the remote server ';
+$lang['operation_results'] = 'Rezultati delovanja';
 $lang['error_noresults'] = 'We expected some results to be available from queued operations, but none were found.  Please try to reproduce this experience, and provide sufficient information to support personell for diagnoses';
-$lang['versionsformodule'] = 'Available versions of the module %s';
-$lang['yourversion'] = 'Your Version';
-$lang['latestdepends'] = 'Always install the newest modules';
-$lang['info_latestdepends'] = 'When installing a module with dependencies, this option will make sure that the latest version of the dependency will be installed';
-$lang['error_internal'] = 'Internal Error... Please report this to your system administrator';
-$lang['error_downloadxml'] = 'A problem occurred downloading the XML FILE: %s';
-$lang['error_request_problem'] = 'A problem occurred communicating with the module server';
+$lang['versionsformodule'] = 'Različice modula %s na voljo';
+$lang['yourversion'] = 'Va&scaron;a različica';
+$lang['latestdepends'] = 'Vedno namestite najnovej&scaron;e module';
+$lang['info_latestdepends'] = 'When installing a module with dependencies, this option will make sure that the latest version of the dependency will be installed ';
+$lang['error_internal'] = 'Notranja napaka ... Prosimo, sporočite problem, skrbniku sistema';
+$lang['error_downloadxml'] = 'Problem v nalaganju XML datoteke: %s';
+$lang['error_request_problem'] = 'Problem v komunikacijo z modulnim strežnikom ';
 $lang['error_searchterm'] = 'Navedite veljavno besedo za iskanje';
 $lang['search_noresults'] = 'Iskanje je uspelo, vendar ni rezultatov ki se ujemajo formuli';
 $lang['advancedsearch_help'] = 'Specify words to include or exclude from the search using a + or -, surround exact phrases with quotes.  i.e:  &quot;+red -apple +&quot;some text&quot;';
@@ -120,32 +120,55 @@ $lang['changelog'] = '<ul>
 <li>Version 1.1.6 May, 2008. Now show if available modules are incompatible with the current CMS_VERSION.</li>
 </li>
 <li>Version 1.2 June, 2008.<br/>
-This version should reduce the memory requirements of this module, and trade it off for performance on the server, and mroe requests to the server.
+This version should reduce the memory requirements of this module, and trade it off for performance on the server, and more requests to the server.
    <ul>
     <li>Bumped Minimum CMS Version to 1.3</li>
     <li>Bumped Minimum repository version to 1.1</li>
     <li>Get rid of all of the session stuff</li>
     <li>Add support for requesting modules beginning with a prefix (usually a single letter)</li>
-    <li>Add support for requestion only the newest versions of the modules</li>
+    <li>Add support for requesting only the newest versions of the modules</li>
    </ul>
 </li>
 <li>Version 1.2.1 August, 2008.<br/>
 Added a warning message to the top of the admin display.
 </li>
+<li>Version 1.3 May, 2009.<br/>
+Added dependency checking.
+</li>
+<li>Version 1.3.3 March, 2010.<br/>
+<ul>
+  <li>PHP 5.x improvements (specifically remove warnings for PHP 5.3)</li>
+  <li>Minor bug fixes.</li>
+</ul>
+</li>
+<li>Version 1.4 June, 2010.<br/>
+<ul>
+  <li>Implemented automatic dependency calculation, and one-click installation.</li>
+  <li>Assorted usability improvements.</li>
+  <li>Minor bug fixes.</li>
+</ul>
+<li>Version 1.5  - July, 2011
+<ul>
+  <li>Changes to REST API.. No longer uses nuSOAP.</li>
+  <li>Many optimizations to downloading and installing modules.</li>
+  <li>Can now install older versions of modules easily.</li>
+  <li>Handle automatic upgrading of ddependencies.</li>
+</ul>
+</li>
 </ul>';
 $lang['help'] = '<h3>What Does This Do?</h3>
-<p>A client for the ModuleRepository, this module allows previewing, and installing modules from remote sites without the need for ftping, or unzipping archives.  Module XML files are downloaded using SOAP, integrity verified, and then expanded automatically.</p>
+<p>A client for the ModuleRepository, this module allows previewing, and installing modules from remote sites without the need for ftping, or unzipping archives.  Module XML files are downloaded using REST, integrity verified, and then expanded automatically.</p>
 <h3>How Do I Use It</h3>
-<p>In order to use this module, you will need the &#039;Modify Modules&#039; permission, and you will also need the complete, and full URL to a &#039;Module Repository&#039; installation.  You can specify this url in the &#039;Site Admin&#039; --> &#039;Global Settings&#039; page.</p><br/>
+<p>In order to use this module, you will need the &#039;Modify Modules&#039; permission, and you will also need the complete, and full URL to a &#039;Module Repository&#039; installation.  You can specify this url in the &#039;Extensions&#039; --&amp;gt; &#039;Module Manager&#039; --&amp;gt; &#039;Preferences&#039; page.</p><br/>
 <p>You can find the interface for this module under the &#039;Extensions&#039; menu.  When you select this module, the &#039;Module Repository&#039; installation will automatically be queried for a list of it&#039;s available xml modules.  This list will be cross referenced with the list of currently installed modules, and a summary page displayed.  From here, you can view the descriptive information, the help, and the about information for a module without physically installing it.  You can also choose to upgrade or install modules.</p>
 <h3>Support</h3>
 <p>As per the GPL, this software is provided as-is. Please read the text of the license for the full disclaimer.</p>
 <h3>Copyright and License</h3>
-<p>Copyright &copy; 2006, calguy1000 <a href="mailto:calguy1000@hotmail.com"><calguy1000@hotmail.com></a>. All Rights Are Reserved.</p>
+<p>Copyright &amp;copy; 2006, calguy1000 <a href="mailto:calguy1000@hotmail.com">&amp;lt;calguy1000@hotmail.com&amp;gt;</a>. All Rights Are Reserved.</p>
 <p>This module has been released under the <a href="http://www.gnu.org/licenses/licenses.html#GPL">GNU Public License</a>. You must agree to this license before using the module.</p>';
 $lang['qca'] = 'P0-1458450664-1284573084918';
-$lang['utma'] = '156861353.652452006.1315907550.1315907550.1315907550.1';
+$lang['utmz'] = '156861353.1338818723.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
+$lang['utma'] = '156861353.1673260288.1338818723.1338818723.1338822728.2';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1315907550.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
