@@ -141,12 +141,11 @@ if( isset($params['submit']) || isset($params['apply']) )
 	    // make sure this url isn't taken.
 	    $news_url = trim($news_url," /\t\r\n\0\x08");
 	    cms_route_manager::load_routes();
-	    $route = cms_route_manager::find_match($news_url);
+	    $route = cms_route_manager::find_match($news_url,TRUE);
 	    if( $route )
 	      {
 		$dflts = $route->get_defaults();
-		if( $route->is_content() || 
-		    $route->get_dest() != $this->GetName() || 
+		if( $route['key1'] != $this->GetName() ||
 		    !isset($dflts['articleid']) || 
 		    $dflts['articleid'] != $articleid )
 		  {
@@ -279,7 +278,13 @@ if( isset($params['submit']) || isset($params['apply']) )
 		$db->Execute( $query, array( $articleid, $k ) );
 	      }
 	  }
-    
+
+	if( !$error && $status == 'published' && $news_url != '' )
+	  {
+	    news_admin_ops::delete_static_route($articleid);
+	    news_admin_ops::register_static_route($news_url,$articleid);
+	  }
+
 	//Update search index
 	if( !$error )
 	  {
@@ -311,18 +316,12 @@ if( isset($params['submit']) || isset($params['apply']) )
 	      }
 	
 	    @$this->SendEvent('NewsArticleEdited', array('news_id' => $articleid, 'category_id' => $usedcategory, 'title' => $title, 'content' => $content, 'summary' => $summary, 'status' => $status, 'start_time' => $startdate, 'end_time' => $enddate, 'extra' => $extra, 'useexp' => $useexp, 'news_url'=>$news_url));
+				// put mention into the admin log
+		audit($articleid, 'News: '.$articleid, 'Article edited');
 	  }
 
       } // else if no error
 
-    if( !isset($params['apply']) && !$error )
-      {
-	// redirect out o here.
-	$params = array('tab_message'=> 'articleupdated', 'active_tab' => 'articles');
-	$this->Redirect($id, 'defaultadmin', $returnid, $params);
-	return;
-      }
-
     if( isset($params['apply']) && isset($params['ajax']) )
       {
 	$response = '<EditArticle>';
@@ -341,6 +340,14 @@ if( isset($params['submit']) || isset($params['apply']) )
 	return;
       }
 
+    if( !isset($params['apply']) && !$error )
+      {
+	// redirect out o here.
+	$params = array('tab_message'=> 'articleupdated', 'active_tab' => 'articles');
+	$this->Redirect($id, 'defaultadmin', $returnid, $params);
+	return;
+      }
+
     if( $error )
       {
 	echo $this->ShowErrors($error);
@@ -446,8 +453,8 @@ $smarty->assign('endform', $this->CreateFormEnd());
 
 if( $author_id > 0 )
   {
-    $userops =& $gCms->GetUserOperations();
-    $theuser =& $userops->LoadUserById( $author_id );
+    $userops = $gCms->GetUserOperations();
+    $theuser = $userops->LoadUserById( $author_id );
     $smarty->assign('inputauthor',$theuser->username);
   }
 else if( $author_id == 0 )
@@ -456,7 +463,7 @@ else if( $author_id == 0 )
   }
 else 
   {
-    $feu =& $this->GetModuleInstance('FrontEndUsers');
+    $feu = $this->GetModuleInstance('FrontEndUsers');
     if( $feu ) {
       $uinfo = $feu->GetUserInfo($author_id * -1);
       if( $uinfo[0] )
