@@ -21,15 +21,15 @@ $dest_page = $returnid;
 $tmp = $this->GetPreference('fesubmit_redirect');
 if( !empty($tmp) )
   {
-    $manager =& $gCms->GetHierarchyManager();
-    $node =& $manager->sureGetNodeByAlias($tmp);
+    $manager = $gCms->GetHierarchyManager();
+    $node = $manager->sureGetNodeByAlias($tmp);
     if (isset($node))
       {
 	$dest_page = $node->getID();
       }
     else
       {
-	$node =& $manager->sureGetNodeById($tmp);
+	$node = $manager->sureGetNodeById($tmp);
 	if (isset($node))
 	  {
 	    $dest_page = $tmp;
@@ -125,7 +125,7 @@ if( isset( $params['submit'] ) )
 
     if( isset($params['title'] ) )
       {
-	$title = $params['title'];
+	$title = strip_tags(cms_html_entity_decode($params['title']));
       }
 
     if( $title == '' )
@@ -160,7 +160,7 @@ if( isset( $params['submit'] ) )
 		    $_FILES[$elem]['tmp_name'] != '' )
 		  {
 		    $error = '';
-		    $value = $this->handle_upload($articleid,$elem,$error);
+		    $value = news_admin_ops::handle_upload($articleid,$elem,$error);
 		    if( $value === FALSE )
 		      {
 			$error = true;
@@ -217,8 +217,8 @@ if( isset( $params['submit'] ) )
 	    // should've checked those errors too, but eh, I'm up for the odds.
 
 	    //Update search index
-	    $module =& $this->GetModuleInstance('Search');
-	    if ($module != FALSE)
+	    $module = cms_utils::get_search_module();
+	    if (is_object($module))
 	      {
 		$module->AddWords($this->GetName(), $articleid, 'article', $content . ' ' . $summary . ' ' . $title . ' ' . $title, $useexp == 1 ? $enddate : NULL);
 	      }
@@ -239,7 +239,10 @@ if( isset( $params['submit'] ) )
 				    'end_time' => $enddate, 
 				    'useexp' => $useexp));
 	
-	    // and we're done
+		// put mention into the admin log
+		audit('', 'News Frontend Submit', 'Article added');
+		
+		// and we're done
 	    $smarty->assign('message',$this->Lang('articleadded'));
 	  }
       }
@@ -344,7 +347,7 @@ if( $do_send_email == true )
   {
     // this needs to be done after the form is generated
     // because we use some of the same smarty variables
-    $cmsmailer =& $this->GetModuleInstance('CMSMailer');
+    $cmsmailer = $this->GetModuleInstance('CMSMailer');
     if( $cmsmailer )
       {
 	$addy = trim($this->GetPreference('formsubmit_emailaddress'));
