@@ -1,21 +1,21 @@
 <?php
 $lang['error_insufficientparams'] = 'Unzureichende (oder leere) Parameter';
 $lang['error_duplicatename'] = 'Ein Eintrag mit diesem Namen existiert bereits';
-$lang['detail_page'] = 'Detailansichts Seite';
+$lang['detail_page'] = 'Detail-Ansichtsseite';
 $lang['detail_template'] = 'Detail-Template';
-$lang['warning_preview'] = 'Warnung: Diese Vorschau verh&auml;lt sich &auml;hnlich wie ein Browser-Fenster, mit dem Sie von der urspr&uuml;nglich ausgew&auml;hlten Seite aus navigieren k&ouml;nnen. Jedoch k&ouml;nnen unerwartete Verhalten auftreten. Wenn Sie auf der urspr&uuml;nglich angew&auml;hlten Seite navigieren und dann dorthin zur&uuml;ckkehren, sehen Sie die unver&auml;nderten Inhalte, obwohl Sie im der Hauptregisterkarte &Auml;nderungen vorgenommen und diese neu geladen haben. Wenn Sie Inhalte hinzuf&uuml;gen, w&auml;hrenddessen Sie auf der Seite navigieren, ist es Ihnen nicht m&ouml;glich zur&uuml;ckzukehren - Sie m&uuml;ssen dann die Vorschau-Seite aktualisieren.<br/><strong>Hinweis:</strong> Die Vorschau wird keine Dateien hochladen die Sie m&ouml;glicherweise f&uuml;r den Upload ausgew&auml;hlt haben.';
+$lang['warning_preview'] = 'Warnung: Diese Vorschau verh&auml;lt sich &auml;hnlich wie ein Browser-Fenster, mit dem Sie von der urspr&uuml;nglich ausgew&auml;hlten Seite aus navigieren k&ouml;nnen. Jedoch k&ouml;nnen unerwartete Verhalten auftreten. Wenn Sie auf der urspr&uuml;nglich angew&auml;hlten Seite navigieren und dann dorthin zur&uuml;ckkehren, sehen Sie die unver&auml;nderten Inhalte, obwohl Sie im der Hauptregisterkarte &Auml;nderungen vorgenommen und diese neu geladen haben. Wenn Sie Inhalte hinzuf&uuml;gen, w&auml;hrenddessen Sie auf der Seite navigieren, ist es Ihnen nicht m&ouml;glich zur&uuml;ckzukehren - Sie m&uuml;ssen dann die Vorschau-Seite aktualisieren.<br /><strong>Hinweis:</strong> Im Vorschau-Modus werden keine Dateien hochladen, die Sie m&ouml;glicherweise daf&uuml;r ausgew&auml;hlt haben.';
 $lang['article'] = 'Artikel';
 $lang['preview'] = 'Vorschau';
 $lang['info_detail_returnid'] = 'Mit diesen Einstellungen kann eine Seite festgelegt werden (und damit auch ein Template), die f&uuml;r die Anzeige der Detailansicht verwendet werden soll. Die individuellen News-Detail-URLs werden jedoch nicht funktionieren, wenn dieser Parameter keine g&uuml;ltige Seite enth&auml;lt. Wird diese Einstellung aktiviert und im news-Tag der Parameter detailpage nicht angegeben, wird dieser Wert f&uuml;r Detail-Links verwendet.';
 $lang['title_detail_returnid'] = 'Voreingestellte Seite, die f&uuml;r die Detailansicht verwendet werden soll';
 $lang['title_submission_settings'] = 'Einstellungen f&uuml;r die News-&Uuml;bertragung';
-$lang['title_fesubmit_settings'] = 'Einstellungen f&uuml;r den Versand &uuml;ber die Webseite';
+$lang['title_fesubmit_settings'] = 'Einstellungen f&uuml;r die News-Einsendung &uuml;ber die Webseite';
 $lang['title_notification_settings'] = 'Benachrichtigungseinstellungen';
 $lang['title_detail_settings'] = 'Einstellungen f&uuml;r die Detailansicht';
 $lang['error_invalidurl'] = 'Ung&uuml;ltige URL <em>(eventuell wird diese bereits verwendet oder sie enth&auml;lt ung&uuml;ltige Zeichen)</em>';
-$lang['url'] = 'URL ';
+$lang['url'] = 'Individuelle Artikel-URL ';
 $lang['expired_searchable'] = 'Artikel, deren Anzeigedauer &uuml;berschritten ist, d&uuml;rfen in den Suchergebnissen erscheinen';
-$lang['helpshowall'] = 'Alle Artikel anzeigen (unabh&auml;ngig von deren Anzeigedauer)';
+$lang['helpshowall'] = 'Mit diesem Parameter k&ouml;nnen alle Artikel (unabh&auml;ngig von der festgelegten Anzeigedauer) angezeigt werden (showall=&#039;1&#039;).';
 $lang['error_invaliddates'] = 'Ein oder mehrere der eingegebenen Daten sind ung&uuml;ltig';
 $lang['notify_n_draft_items_sub'] = '%d News-Artikel';
 $lang['notify_n_draft_items'] = '%s News-Artikel wurde(n) noch nicht ver&ouml;ffentlicht.';
@@ -37,7 +37,7 @@ $lang['title_desc'] = 'nach Titel absteigend';
 $lang['title_asc'] = 'nach Titel aufsteigend';
 $lang['status_desc'] = 'nach Status absteigend';
 $lang['status_asc'] = 'nach Status aufsteigend';
-$lang['fesubmit_status'] = 'Der Status f&uuml;r Artikel, die &uuml;ber die Webseite (Frontend) erstellt wurden';
+$lang['fesubmit_status'] = 'Status f&uuml;r Artikel, die &uuml;ber die Webseite (Frontend) eingesandt wurden';
 $lang['error_invalidfiletype'] = 'Dieser Dateityp darf nicht hochgeladen werden';
 $lang['error_upload'] = 'Beim Hochladen der Datei ist ein Problem aufgetreten';
 $lang['error_movefile'] = 'Konnte die Datei %s nicht erstellen';
@@ -59,7 +59,7 @@ $lang['checkbox'] = 'Kontrollk&auml;stchen';
 $lang['textarea'] = 'Mehrzeiliger Textbereich';
 $lang['file'] = 'Datei';
 $lang['auto_create_thumbnails'] = 'F&uuml;r Dateien mit dieser Namenserweiterung automatisch ein Vorschaubild erstellen';
-$lang['allowed_upload_types'] = 'Nur Dateien mit dieser Namenserweiterung d&uuml;rfen hochgeladen werden';
+$lang['allowed_upload_types'] = 'Es d&uuml;rfen nur Dateien mit dieser Namenserweiterung hochgeladen werden';
 $lang['fielddefupdated'] = 'Das Extra-Feld wurde aktualisiert';
 $lang['editfielddef'] = 'Extra-Feld bearbeiten';
 $lang['up'] = 'Nach oben';
@@ -76,10 +76,10 @@ $lang['maxlength'] = 'Maximale L&auml;nge';
 $lang['addfielddef'] = 'Extra-Feld hinzuf&uuml;gen';
 $lang['customfields'] = 'Extra-Felder';
 $lang['deprecated'] = 'Nicht unterst&uuml;tzt';
-$lang['subject_newnews'] = 'Ein neuer Artikel wurde ins System eingestellt';
-$lang['email_subject'] = 'Betreff der ausgehenden E-Mail';
-$lang['email_template'] = 'Inhalt der E-Mail-Nachricht';
-$lang['formsubmit_emailaddress'] = 'E-Mail-Adresse zur Benachrichtigung bei neuen Artikeln';
+$lang['subject_newnews'] = 'Es wurde ein neuer Artikel eingesandt';
+$lang['email_subject'] = 'Betreff der ausgehenden Email';
+$lang['email_template'] = 'Inhalt der Email-Nachricht';
+$lang['formsubmit_emailaddress'] = 'Email-Adresse zur Benachrichtigung bei neuen Artikeln';
 $lang['extra'] = 'Extra-Feld';
 $lang['uploadscategory'] = 'Kategorie im Uploads-Modul';
 $lang['title_available_templates'] = 'Verf&uuml;gbare Templates';
@@ -89,14 +89,14 @@ $lang['title_detail_template'] = 'Editor f&uuml;r die Detail-Templates';
 $lang['title_summary_template'] = 'Editor f&uuml;r die Zusammenfassungs-Templates';
 $lang['prompt_templatename'] = 'Template-Name';
 $lang['prompt_template'] = 'Template-Quelle';
-$lang['title_form_sysdefault'] = 'Standard-Template f&uuml;r das Formular';
-$lang['title_summary_sysdefault'] = 'Standard-Template f&uuml;r die Zusammenfassung';
-$lang['title_detail_sysdefault'] = 'Standard-Template f&uuml;r die Details';
+$lang['title_form_sysdefault'] = 'Voreingestelltes Template f&uuml;r das Formular';
+$lang['title_summary_sysdefault'] = 'Voreingestelltes Template f&uuml;r die Zusammenfassung';
+$lang['title_detail_sysdefault'] = 'Voreingestelltes Template f&uuml;r die Details';
 $lang['info_sysdefault2'] = '<strong>Hinweis:</strong> In den Textbereichen dieser Registerkarte k&ouml;nnen Sie die Templates vordefinieren, die automatisch eingef&uuml;gt werden, wenn Sie eine neues Zusammenfassungs-, Detail- oder Formular-Template erstellen. Das &Auml;ndern/Speichern der Inhalte in diesem Reiter hat <strong>keine Auswirkungen auf die aktuelle Anzeige</strong>.';
 $lang['info_sysdefault'] = '(der Inhalt, der standardm&auml;&szlig;ig beim Erstellen eines neuen Templates verwendet wird)';
 $lang['template'] = 'Template ';
 $lang['prompt_name'] = 'Name ';
-$lang['prompt_default'] = 'Standard';
+$lang['prompt_default'] = 'Voreingestellt';
 $lang['prompt_newtemplate'] = 'Ein neues Template erstellen';
 $lang['help_pagelimit'] = 'Maximale Anzahl der anzuzeigenden Eintr&auml;ge (pro Seite). Ohne diesen Parameter werden alle Eintr&auml;ge angezeigt. Wenn dieser Parameter gesetzt wurde und mehr Eintr&auml;ge vorhanden sind, als pro Seite angezeigt werden sollen, werden Links eingeblendet, um vorw&auml;rts oder r&uuml;ckw&auml;rts zu den n&auml;chsten Seiten bl&auml;ttern zu k&ouml;nnen.';
 $lang['prompt_page'] = 'Seite';
@@ -130,7 +130,7 @@ $lang['articles'] = 'Artikel';
 $lang['cancel'] = 'Abbrechen';
 $lang['category'] = 'Kategorie';
 $lang['categories'] = 'Kategorien';
-$lang['default_category'] = 'Standard-Kategorie';
+$lang['default_category'] = 'Voreingestellte Kategorie';
 $lang['content'] = 'Inhalt';
 $lang['dateformat'] = '%s ist nicht im g&uuml;ltigen Format &bdquo;JJJJ-MM-TT hh:mm:ss&ldquo;';
 $lang['delete'] = 'L&ouml;schen';
@@ -175,6 +175,7 @@ $lang['sortascending'] = 'aufsteigend sortieren';
 $lang['startdate'] = 'Startzeitpunkt';
 $lang['startoffset'] = 'Beginnt mit der Anzeige ab dem <em>n</em>-ten Eintrag';
 $lang['startrequiresend'] = 'Die Eingabe eines Startzeitpunktes erfordert auch die Eingabe eines Endzeitpunktes.';
+$lang['apply'] = '&Uuml;bernehmen';
 $lang['submit'] = 'Speichern';
 $lang['summary'] = 'Zusammenfassung';
 $lang['summarytemplate'] = 'Zusammenfassungs-Templates';
@@ -185,32 +186,96 @@ $lang['optionsupdated'] = 'Die Einstellungen wurden gespeichert.';
 $lang['useexpiration'] = 'Zeitsteuerung aktivieren';
 $lang['eventdesc-NewsArticleAdded'] = 'Ausf&uuml;hren, wenn ein Artikel hinzugef&uuml;gt wurde.';
 $lang['eventhelp-NewsArticleAdded'] = '<p>Ausf&uuml;hren, wenn ein Artikel hinzugef&uuml;gt wurde.</p>
-<h4>Parameter</h4>
-<ul>
-<li>&quot;news_id&quot; - ID des News-Artikels</li>
-<li>&quot;category_id&quot; - ID der Kategorie f&uuml;r diesen Artikel</li>
-<li>&quot;title&quot; - Titel des Artikels</li>
-<li>&quot;content&quot; - Inhalt des Artikels</li>
-<li>&quot;summary&quot; - Zusammenfassung des Artikels</li>
-<li>&quot;status&quot; - Status des Artikels (&bdquo;Entwurf/draft&ldquo; oder &bdquo;Ver&ouml;ffentlicht/publish&ldquo;)</li>
-<li>&quot;start_time&quot; - Datum, ab dem der Artikel angezeigt werden soll</li>
-<li>&quot;end_time&quot; - Datum, ab dem der Artikel nicht mehr angezeigt werden soll</li>
-<li>&quot;useexp&quot; - die Zeitsteuerung soll ignoriert werden oder auch nicht</li>
-</ul>';
+<table>
+	<thead>
+		<th>Parameter</th>
+		<th>Beschreibung</th>
+	</thead>
+	<tbody>
+		<tr>
+			<th>news_id</th>
+			<td>ID des News-Artikels</td>
+		</tr>
+		<tr>
+			<th>category_id</th>
+			<td>ID der Kategorie f&uuml;r diesen Artikel</td>
+		</tr>
+		<tr>
+			<th>title</th>
+			<td>Titel des Artikels</td>
+		</tr>
+		<tr>
+			<th>content</th>
+			<td>Inhalt des Artikels</td>
+		</tr>
+		<tr>
+			<th>summary</th>
+			<td>Zusammenfassung des Artikels</td>
+		</tr>
+		<tr>
+			<th>status</th>
+			<td>Status des Artikels (&bdquo;Entwurf/draft&ldquo; oder &bdquo;Ver&ouml;ffentlicht/publish&ldquo;)</td>
+		</tr>
+		<tr>
+			<th>start_time</th>
+			<td>Datum, ab dem der Artikel angezeigt werden soll</td>
+		</tr>
+		<tr>
+			<th>end_time</th>
+			<td>Datum, ab dem der Artikel nicht mehr angezeigt werden soll</td>
+		</tr>
+		<tr>
+			<th>useexp</th>
+			<td>die Zeitsteuerung soll ignoriert werden oder auch nicht</td>
+		</tr>
+	</tbody>
+</table>';
 $lang['eventdesc-NewsArticleEdited'] = 'Ausf&uuml;hren, wenn ein Artikel bearbeitet wurde.';
 $lang['eventhelp-NewsArticleEdited'] = '<p>Ausf&uuml;hren, wenn ein Artikel bearbeitet wurde.</p>
-<h4>Parameter</h4>
-<ul>
- <li>&quot;news_id&quot; - ID des News-Artikels</li>
-<li>&quot;category_id&quot; - ID der Kategorie f&uuml;r diesen Artikel</li>
-<li>&quot;title&quot; - Titel des Artikels</li>
-<li>&quot;content&quot; - Inhalt des Artikels</li>
-<li>&quot;summary&quot; - Zusammenfassung des Artikels</li>
-<li>&quot;status&quot; - Status des Artikels (&bdquo;Entwurf/draft&ldquo; oder &bdquo;Ver&ouml;ffentlicht/publish&ldquo;)</li>
-<li>&quot;start_time&quot; - Datum, ab dem der Artikel angezeigt werden soll</li>
-<li>&quot;end_time&quot; - Datum, ab dem der Artikel nicht mehr angezeigt werden soll</li>
-<li>&quot;useexp&quot; - die Zeitsteuerung soll ignoriert werden oder auch nicht</li>
-</ul>';
+<table>
+	<thead>
+		<th>Parameter</th>
+		<th>Beschreibung</th>
+	</thead>
+	<tbody>
+		<tr>
+			<th>news_id</th>
+			<td>ID des News-Artikels</td>
+		</tr>
+		<tr>
+			<th>category_id</th>
+			<td>ID der Kategorie f&uuml;r diesen Artikel</td>
+		</tr>
+		<tr>
+			<th>title</th>
+			<td>Titel des Artikels</td>
+		</tr>
+		<tr>
+			<th>content</th>
+			<td>Inhalt des Artikels</td>
+		</tr>
+		<tr>
+			<th>summary</th>
+			<td>Zusammenfassung des Artikels</td>
+		</tr>
+		<tr>
+			<th>status</th>
+			<td>Status des Artikels (&bdquo;Entwurf/draft&ldquo; oder &bdquo;Ver&ouml;ffentlicht/publish&ldquo;)</td>
+		</tr>
+		<tr>
+			<th>start_time</th>
+			<td>Datum, ab dem der Artikel angezeigt werden soll</td>
+		</tr>
+		<tr>
+			<th>end_time</th>
+			<td>Datum, ab dem der Artikel nicht mehr angezeigt werden soll</td>
+		</tr>
+		<tr>
+			<th>useexp</th>
+			<td>die Zeitsteuerung soll ignoriert werden oder auch nicht</td>
+		</tr>
+	</tbody>
+</table>';
 $lang['eventdesc-NewsArticleDeleted'] = 'Ausf&uuml;hren, wenn ein Artikel gel&ouml;scht wurde.';
 $lang['eventhelp-NewsArticleDeleted'] = '<p>Ausf&uuml;hren, wenn ein Artikel gel&ouml;scht wurde.</p>
 <h4>Parameter</h4>
@@ -226,12 +291,26 @@ $lang['eventhelp-NewsCategoryAdded'] = '<p>Ausf&uuml;hren, wenn eine Kategorie h
 </ul>';
 $lang['eventdesc-NewsCategoryEdited'] = 'Ausf&uuml;hren, wenn eine Kategorie bearbeitet wurde.';
 $lang['eventhelp-NewsCategoryEdited'] = '<p>Ausf&uuml;hren, wenn eine Kategorie bearbeitet wurde.</p>
-<h4>Parameter</h4>
-<ul>
-<li>&quot;category_id&quot; - ID der News-Kategorie</li>
-<li>&quot;name&quot; - Name der News-Kategorie</li>
-<li>&quot;origname&quot; - urspr&uuml;nglicher Name der News-Kategorie</li>
-</ul>';
+<table>
+	<thead>
+		<th>Parameter</th>
+		<th>Beschreibung</th>
+	</thead>
+	<tbody>
+		<tr>
+			<th>category_id</th>
+			<td>ID der Nachrichtenkategorie</td>
+		</tr>
+		<tr>
+			<th>name</th>
+			<td>Name der Nachrichtenkategorie</td>
+		</tr>
+		<tr>
+			<th>origname</th>
+			<td>urspr&uuml;nglicher Name der Nachrichtenkategorie</td>
+		</tr>
+	</tbody>
+</table>';
 $lang['eventdesc-NewsCategoryDeleted'] = 'Ausf&uuml;hren, wenn eine Kategorie gel&ouml;scht wurde.';
 $lang['eventhelp-NewsCategoryDeleted'] = '<p>Ausf&uuml;hren, wenn eine Kategorie gel&ouml;scht wurde.</p>
 <h4>Parameter</h4>
@@ -251,13 +330,13 @@ $lang['helpdetailtemplate'] = 'Verwendet eine separates Template f&uuml;r die De
 $lang['helpsortby'] = 'Felder, nach denen die Eintr&auml;ge sortiert werden. M&ouml;gliche Optionen sind: &bdquo;news_date&ldquo;, &bdquo;summary&ldquo;, &bdquo;news_data&ldquo;, &bdquo;news_category&ldquo;, &bdquo;news_title&ldquo;, &bdquo;news_extra&ldquo;, &bdquo;end_time&ldquo;, &bdquo;start_time&ldquo;, &bdquo;random&ldquo;. Standard ist &bdquo;news_date&ldquo;. Ist die gew&auml;hlte Option &bdquo;random&ldquo;, wird der Parameter &bdquo;sortasc&ldquo; ignoriert.';
 $lang['helpsortasc'] = 'Sortiert Eintr&auml;ge in aufsteigender Folge anstatt in absteigender (nach Datum).';
 $lang['helpdetailpage'] = 'Seite, auf der die Nachrichtendetails angezeigt werden. Das kann entweder ein Seiten-Alias oder eine Seiten-ID sein. Damit k&ouml;nnen die Nachrichtendetails in einem anderen Template als die Nachrichtenzusammenfassung angezeigt werden.';
-$lang['helpshowarchive'] = 'Mit diesem Parameter werden nur die Artikel angezeigt, deren Anzeigedauer au&szlig;erhalb des aktuellen Datums liegt.';
+$lang['helpshowarchive'] = 'Mit diesem Parameter werden nur die Artikel angezeigt, deren festgelegte Anzeigedauer bereits abgelaufen ist (showarchive=&#039;1&#039;).';
 $lang['helpbrowsecat'] = 'Mit diesem Parameter wird eine Liste der Kategorien angezeigt (browsecat=&#039;1&#039;). Kann NICHT zusammen mit dem Parameter &bdquo;category&ldquo; verwendet werden.';
 $lang['helpaction'] = '&Uuml;berschreibt die vorgegebene Aktion. M&ouml;gliche Werte sind:
 <ul>
 <li>&quot;detail&quot; - einen bestimmten Artikel im Detail-Modus anzeigen</li>
 <li>&quot;default&quot; - die Zusammenfassungansicht anzeigen</li>
-<li>&quot;fesubmit&quot; - auf der Webseite ein Formular zum &Uuml;bermitteln neuer Artikel anzeigen</li>
+<li>&quot;fesubmit&quot; - auf der Webseite ein Formular zum Einsenden neuer Artikel anzeigen. Um f&uuml;r das Formular den voreingestellten WYSIWYG-Editor zu verwenden, m&uuml;ssen Sie den Metadaten (Webseiten-Administration > Globale Einstellungen) <code>{cms_init_editor}</code> hinzuf&uuml;gen.</li>
 <li>&quot;browsecat&quot; - eine Kategorienliste anzeigen.</li>
 </ul>';
 $lang['help'] = '<h3>Wichtiger Hinweis</h3>
@@ -281,10 +360,10 @@ $lang['help'] = '<h3>Wichtiger Hinweis</h3>
 <h3>Wie wird es eingesetzt?</h3>
 <p>Am einfachsten kann das Modul mit dem <code>{news}</code>-Tag verwendet werden. Dieser f&uuml;gt die Ausgabe des Moduls in Ihr Template oder Seite ein und zeigt die News-Eintr&auml;ge an. Der einzuf&uuml;gende Code sollte so aussehen: <code>{news number=&#039;5&#039;}</code></p>
 <h3>Templates</h3>
-<p>Seit Version 2.3 werden die Templates des News-Moduls in der Datenbank gespeichert. Dateibasierte Templates werden nicht mehr unterst&uuml;tzt. Wenn Sie noch dateibasierte Templates verwenden, sollten Sie mit der folgenden Anleitung jedes verwendete (dateibasierte) Template importieren:</p>
+<p>Seit Version 2.3 werden die Templates des News-Moduls in der Datenbank gespeichert. Dateibasierte Templates werden nicht mehr unterst&uuml;tzt. Wenn Sie noch solche verwenden, sollten Sie mit der folgenden Anleitung jedes verwendete (dateibasierte) Template importieren:</p>
 <ul>
 <li>Kopieren Sie den Inhalt Ihrer Template-Datei in den Zwischenspeicher Ihres Rechners.</li>
-<li>Erstellen Sie eins neues Datenbank-Template <em>(je nach Bedarf f&uuml;r die Zusammenfassungs- oder Detailansicht)</em>. Geben Sie dem neuen Template den gleichen Namen wie dem alten Template (einschlie&szlig;lich der Endung .tpl). F&uuml;gen Sie den Inhalt des Zwischenspeichers ein.</li>
+<li>Erstellen Sie ein neues Datenbank-Template <em>(je nach Bedarf f&uuml;r die Zusammenfassungs- oder Detailansicht)</em>. Geben Sie dem neuen Template den gleichen Namen wie der alten (einschlie&szlig;lich der Endung .tpl). F&uuml;gen Sie den Inhalt des Zwischenspeichers ein.</li>
 <li>Klicken Sie auf &bdquo;Absenden&ldquo;</li>
 </ul>
 <p>Mit diesem Ablauf sollte sichergestellt sein, dass Fehlermeldungen &uuml;ber Templates, die nicht gefunden werden oder &auml;hnliche Smarty-Fehler, nicht auftreten, wenn auf eine CMSms-Version aktualisiert wird, die das News-Modul 2.3 oder h&ouml;her verwendet.</p>
@@ -295,9 +374,8 @@ $lang['help'] = '<h3>Wichtiger Hinweis</h3>
 </ul>
 <p>Auch die Variablen der Extra-Felder k&ouml;nnen in den Templates separat verwendet werden. So l&auml;sst sich zum Beispiel das Extrafeld mit dem Namen &bdquo;musterfeld&ldquo; &uuml;ber die Variable entry->musterfeld abfragen.</p>
 <p><strong>ACHTUNG:</strong> Leerzeichen m&uuml;ssen dabei durch den Unterstrich (&bdquo;_&ldquo;) ersetzt werden.</p>';
-$lang['qca'] = 'P0-1458450664-1284573084918';
-$lang['utma'] = '156861353.714059650.1316763677.1316763677.1316763677.1';
+$lang['utma'] = '156861353.843417466.1337413794.1337413794.1337413794.1';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1316763677.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utmz'] = '156861353.1337413794.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
