@@ -1,4 +1,11 @@
 <?php
+$lang['error_insufficientparams'] = 'Faltan los par&aacute;metros necesarios';
+$lang['error_duplicatename'] = 'Ya existe un &iacute;tem con el mismo nombre';
+$lang['detail_page'] = 'P&aacute;gina de detalle';
+$lang['detail_template'] = 'Plantilla de detalle';
+$lang['warning_preview'] = 'Aviso: Este panel de vista previa se comporta de forma muy parecida a la ventana de un navegador permiti&eacute;ndole navegar fuera de la p&aacute;gina previsualizada inicialmente. Si navega fuera de la p&aacute;gina inicial, cuando regrese puede no obtener los resultados esperados<br/><strong>Nota:</strong> La vista previa no sube los archivos que seleccione para subir.';
+$lang['article'] = 'Art&iacute;culo';
+$lang['preview'] = 'Vista previa';
 $lang['info_detail_returnid'] = 'Esta preferencia se usa para determinar una p&aacute;gina (y por lo tanto una plantilla) en la que mostrar la vista de detalle. Las URLs individualizadas para los detalles de las Noticias no funcionar&aacute;n a menos que este par&aacute;metro se configure con una p&aacute;gina valida. Adicionalmente, si esta preferencia est&aacute; establecida, y no se proporciona el parametro &#039;detailpage&#039; (p&aacute;gina de detalle) en la etiqueta de noticias, entonces este valor ser&aacute; utilizado para los enlaces de detalle';
 $lang['title_detail_returnid'] = 'P&aacute;gina por defecto para las vistas de detalle';
 $lang['title_submission_settings'] = 'Configuraci&oacute;n de env&iacute;o de Noticias';
@@ -93,10 +100,10 @@ $lang['prompt_default'] = 'Por Defecto';
 $lang['prompt_newtemplate'] = 'Crear una Nueva Plantilla';
 $lang['help_pagelimit'] = 'M&aacute;ximo n&uacute;mero de elementos a mostrar (por p&aacute;gina).  Si no se proporciona este par&aacute;metro se mostraran todos los elementos coincidentes. Si se especifica, y hay m&aacute;s elementos que los especificados por este par&aacute;metro, se proporcionar&aacute;n textos y enlaces para poder navegar entre los resultados';
 $lang['prompt_page'] = 'P&aacute;gina';
-$lang['firstpage'] = '&amp;lt;&amp;lt;';
-$lang['prevpage'] = '&amp;lt;';
-$lang['nextpage'] = '&amp;gt;';
-$lang['lastpage'] = '&amp;gt;&amp;gt;';
+$lang['firstpage'] = '<<';
+$lang['prevpage'] = '<';
+$lang['nextpage'] = '>';
+$lang['lastpage'] = '>>';
 $lang['prompt_of'] = 'de';
 $lang['prompt_pagelimit'] = 'L&iacute;mite de P&aacute;gina';
 $lang['prompt_sorting'] = 'Ordenar por';
@@ -143,6 +150,7 @@ $lang['filter'] = 'Filtro';
 $lang['more'] = 'M&aacute;s';
 $lang['category_label'] = 'Categor&iacute;a:';
 $lang['author_label'] = 'Enviado por:';
+$lang['extra_label'] = 'Extra: ';
 $lang['moretext'] = 'Texto M&aacute;s';
 $lang['name'] = 'Nombre';
 $lang['news'] = 'Noticias';
@@ -167,6 +175,7 @@ $lang['sortascending'] = 'Orden Ascendente';
 $lang['startdate'] = 'Fecha de Inicio';
 $lang['startoffset'] = 'Comienza a mostrar desde el en&eacute;simo elemento';
 $lang['startrequiresend'] = 'Una fecha de inicio requiere tambi&eacute;n una de fin';
+$lang['apply'] = 'Aplicar';
 $lang['submit'] = 'Enviar';
 $lang['summary'] = 'Resumen';
 $lang['summarytemplate'] = 'Plantilla de Resumen';
@@ -250,10 +259,10 @@ $lang['helpshowarchive'] = 'Mostrar s&oacute;lo los art&iacute;culos de noticias
 $lang['helpbrowsecat'] = 'Muestra un listado de categor&iacute;as que se puede examinar.';
 $lang['helpaction'] = 'Sobrescribe la acci&oacute;n por defecto. Los valores posibles son:
 <ul>
-<li>&amp;quot;detail&amp;quot; - para mostrar un articleid espec&iacute;fico en el modo de detalle.</li>
-<li>&amp;quot;default&amp;quot; - para mostrar la vista de resumen</li>
-<li>&amp;quot;fesubmit&amp;quot; - para mostrar el formulario en el portal de forma que permita a los usuarios eviar art&iacute;culos de noticias directamentes desde el portal.</li>
-<li>&amp;quot;browsecat&amp;quot; - para mostrar una lista de categor&iacute;as en forma de enlaces.</li>
+<li>&quot;detai&quot; - para mostrar un articleid espec&iacute;fico en el modo de detalle.</li>
+<li>&quot;default&quot; - para mostrar la vista de resumen</li>
+<li>&quot;fesubmit&quot; - para mostrar el formulario en el portal de forma que permita a los usuarios eviar art&iacute;culos de noticias directamentes desde el portal.</li>
+<li>&quot;browsecat&quot; - para mostrar una lista de categor&iacute;as en forma de enlaces.</li>
 </ul>';
 $lang['help'] = '<h3>Notas Importantes</h3>
 <p>A partir de la versi&oacute;n 2.9 de las News se ha eliminado el miembro formatpostdate de las plantillas, as&iacute; como el par&aacute;metro dateformat. Debe usar el modificador cms_date_format (como se indica en las plantillas por defecto) para formatear las fechas, y usar en las plantillas entry->postdate en vez de entry->formatpostdate.</p>
@@ -282,9 +291,9 @@ $lang['help'] = '<h3>Notas Importantes</h3>
 <li>Crear una nueva plantilla de base de datos <em>(tanto la de resumen como la de detalles, seg&uacute;n se necesite)</em>.  D&eacute; a la nueva plantilla el mismo nombre (incluyendo la extensi&oacute;n .tpl) que ten&iacute;a la vieja plantilla de archivo, y pegue el contenido del portapapeles.</li>
 <li>Pulse en Enviar</li>
 </ul>
-<p>Con estos pasos se deben solucionar el problema de las plantillas no encontradas y otros errores smarty similares que se producen cuando actualiza a la versi&oacute;n de CMS que incluye News 2.3 o superior.</p>';
-$lang['utma'] = '156861353.1929739349.1309160394.1309334831.1309339735.6';
-$lang['qca'] = 'P0-1077666827-1293014781745';
-$lang['utmz'] = '156861353.1309160366.1.1.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cmsms vulnerability';
+<p>Con estos pasos se deber&iacute;a solucionar el problema de las plantillas no encontradas y otros errores smarty similares que se producen cuando actualiza a una la versi&oacute;n de CMS que incluye el m&oacute;dulo News 2.3 o superior.</p>';
+$lang['utma'] = '156861353.1603343530.1339275764.1339275764.1339275764.1';
+$lang['utmz'] = '156861353.1339275764.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmc'] = '156861353';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
