@@ -3,7 +3,7 @@ $lang['error_insufficientparams'] = 'Param&egrave;tres insuffisant (ou vide)';
 $lang['error_duplicatename'] = 'Un &eacute;l&eacute;ment avec ce nom existe d&eacute;j&agrave;';
 $lang['detail_page'] = 'Page de d&eacute;tail&nbsp;';
 $lang['detail_template'] = 'Gabarit du d&eacute;tail&nbsp;';
-$lang['warning_preview'] = 'Attention : cette page d&#039;aper&ccedil;u se comporte comme une fen&ecirc;tre permettant de naviguer loin de cette page aper&ccedil;u originale. Toutefois, si vous faites cela, attention aux comportements inattendus ! <strong>Note :</strong> la pr&eacute;visualisation ne tient pas compte des fichiers pouvant &ecirc;tre en attente d&#039;upload.';
+$lang['warning_preview'] = 'Attention : cette page d&#039;aper&ccedil;u se comporte comme une fen&ecirc;tre permettant de naviguer loin de cette page aper&ccedil;u originale. Toutefois, si vous faites cela, attention aux comportements inattendus ! <strong>Note :</strong> La pr&eacute;visualisation ne tient pas compte des fichiers pouvant &ecirc;tre en attente d&#039;upload.';
 $lang['article'] = 'Article ';
 $lang['preview'] = 'Aper&ccedil;u';
 $lang['info_detail_returnid'] = 'Cette pr&eacute;f&eacute;rence est utilis&eacute;e pour d&eacute;termin&eacute;e si une page (et donc un gabarit) sert pour l&#039;affichage des pages de d&eacute;tails. Les URLs individualis&eacute;es ne fonctionneront pas si ce param&egrave;tre n&#039;est pas d&eacute;fini pour une page valide. En outre, si cette pr&eacute;f&eacute;rence est activ&eacute;e, et aucun param&egrave;tre page de d&eacute;tail n&#039;est fourni sur la balise {news}, alors cette valeur sera utilis&eacute;e pour des liens pages de d&eacute;tails';
@@ -35,8 +35,8 @@ $lang['expiry_date_desc'] = 'Date expiration descendante';
 $lang['expiry_date_asc'] = 'Date expiration ascendante';
 $lang['title_desc'] = 'Titre descendant';
 $lang['title_asc'] = 'Titre ascendant';
-$lang['status_desc'] = 'Status descendant';
-$lang['status_asc'] = 'Status ascendant';
+$lang['status_desc'] = 'Statut descendant';
+$lang['status_asc'] = 'Statut ascendant';
 $lang['fesubmit_status'] = 'Le statut des articles soumis via les pages du site (frontend)&nbsp;';
 $lang['error_invalidfiletype'] = 'Impossible de t&eacute;l&eacute;charger ce type de fichier';
 $lang['error_upload'] = 'Il y a eu un probl&egrave;me lors du t&eacute;l&eacute;chargement d&#039;un fichier';
@@ -52,7 +52,7 @@ $lang['error_noarticlesselected'] = 'Aucun article s&eacute;lectionn&eacute;';
 $lang['reassign_category'] = 'Changer la cat&eacute;gorie par&nbsp;';
 $lang['select'] = 'S&eacute;lectionner';
 $lang['approve'] = 'Mettre le statut &agrave; &#039;Publi&eacute;&#039;';
-$lang['revert'] = 'Mettre le statut &agrave; &#039;Brouillon&#039;';
+$lang['revert'] = 'Mettre le statut &agrave; &#039;&Eacute;bauche&#039;';
 $lang['hide_summary_field'] = 'Cacher le champ sommaire lors de l&#039;ajout ou de la modification d&#039;articles&nbsp;';
 $lang['textbox'] = 'Champ de texte';
 $lang['checkbox'] = 'Case &agrave; cocher';
@@ -109,7 +109,7 @@ $lang['prompt_pagelimit'] = 'Nombre par page&nbsp;';
 $lang['prompt_sorting'] = 'Tri&eacute; par&nbsp;';
 $lang['title_filter'] = 'Filtres';
 $lang['published'] = 'Publi&eacute;';
-$lang['draft'] = 'Brouillon';
+$lang['draft'] = '&Eacute;bauche';
 $lang['expired'] = 'Expir&eacute;';
 $lang['author'] = 'Auteur&nbsp;';
 $lang['sysdefaults'] = 'Restaurer les param&egrave;tres par d&eacute;faut';
@@ -175,6 +175,7 @@ $lang['sortascending'] = 'Tri ascendant&nbsp;';
 $lang['startdate'] = 'Date de d&eacute;but&nbsp;';
 $lang['startoffset'] = 'Commence l&#039;affichage au &eacute;ni&egrave;me article&nbsp;';
 $lang['startrequiresend'] = 'Entrer une date de d&eacute;but n&eacute;cessite qu&#039;une date de fin soit &eacute;galement entr&eacute;e';
+$lang['apply'] = 'Appliquer';
 $lang['submit'] = 'Envoyer';
 $lang['summary'] = 'Sommaire&nbsp;';
 $lang['summarytemplate'] = 'Gabarit du sommaire article';
@@ -294,4 +295,9 @@ $lang['help'] = '<h3>Notes Importantes</h3>
 <li>Cliquer sur le bouton Envoyer</li>
 </ul>
 <p>Ces diff&eacute;rentes &eacute;tapes r&eacute;solvent le probl&egrave;me de ces nouveaux gabarits afin d&#039;&eacute;viter les diff&eacute;rentes erreurs de Smarty quand vous mettez &agrave; jour vers une version de CMS avec un module de News version 2.3 ou sup&eacute;rieure.</p>';
+$lang['qca'] = 'P0-1532147203-1273233257739';
+$lang['utma'] = '156861353.372298033.1340641332.1340641332.1340641332.1';
+$lang['utmc'] = '156861353';
+$lang['utmz'] = '156861353.1340641332.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
