@@ -1,12 +1,20 @@
 <?php
+$lang['info_detail_returnid'] = 'This preference is used to determine a page (and therefore a template) to use to view detail pages.  Individualized News Detail URLS will not work if this parameter is not set to a valid page.  Additionally, if this preference is set, and no detailpage parameter is provided on the news tag, then this value will be used for detail links';
+$lang['title_detail_returnid'] = 'Default page to use for detail views';
+$lang['title_submission_settings'] = 'News Submission Settings';
+$lang['title_fesubmit_settings'] = 'Frontend Submit Settings';
+$lang['title_notification_settings'] = '&Eacute;rtes&iacute;t&eacute;s be&aacute;ll&iacute;t&aacute;sok';
+$lang['title_detail_settings'] = 'Detail View Settings';
+$lang['error_invalidurl'] = '&Eacute;rv&eacute;nytelen URL <em>(tal&aacute;n m&aacute;r haszn&aacute;lj&aacute;k vagy &eacute;rv&eacute;nytelen karakterek vannak benne)</em>';
+$lang['url'] = 'URL';
+$lang['expired_searchable'] = 'Lej&aacute;rt cikkek megjelenhessenek a keres&eacute;si eredm&eacute;nyek k&ouml;z&ouml;tt';
+$lang['helpshowall'] = 'Minden cikk mutat&aacute;sa, f&uuml;ggetlen&uuml;l a lej&aacute;rati d&aacute;tumt&oacute;l';
 $lang['error_invaliddates'] = 'Valamelyik megadott d&aacute;tum &eacute;rv&eacute;nytelen volt';
 $lang['notify_n_draft_items_sub'] = '%d darab &uacute;j cikk';
 $lang['notify_n_draft_items'] = '%s darab nem publik&aacute;lt cikked van';
-$lang['helprsscategory'] = 'Az makerssbutton param&eacute;terrel egy&uuml;tt haszn&aacute;lva ez a param&eacute;ter lehetőv&eacute; teszi egy-egy rovat rss-ben val&oacute; megmutat&aacute;s&aacute;t';
 $lang['unlimited'] = 'Korl&aacute;tlan';
 $lang['none'] = 'Nincs';
-$lang['rss_destinationpage'] = 'Az oldal azonos&iacute;t&oacute;ja vagy alias-a a c&eacute;loldalra, rss-beli cikkekhez';
-$lang['anonymous'] = 'Anonymous';
+$lang['anonymous'] = 'Anonim';
 $lang['unknown'] = 'Ismeretlen';
 $lang['fesubmit_redirect'] = 'PageID vagy alias, amire &aacute;t kell ir&aacute;ny&iacute;tani, amikor &uacute;j cikk lett bek&uuml;ldve &#039;fesubmit&#039;-on kereszt&uuml;l';
 $lang['allow_summary_wysiwyg'] = 'WYSIWYG szerkesztő haszn&aacute;lat&aacute;nak enged&eacute;lyez&eacute;se az &ouml;sszefoglal&oacute;ban';
@@ -20,6 +28,8 @@ $lang['expiry_date_desc'] = 'Lej&aacute;rat d&aacute;tuma szerint cs&ouml;kkenő
 $lang['expiry_date_asc'] = 'Lej&aacute;rat d&aacute;tuma szerint n&ouml;vekvő';
 $lang['title_desc'] = 'C&iacute;m szerint cs&ouml;kkenő';
 $lang['title_asc'] = 'C&iacute;m szerint n&ouml;vekvő';
+$lang['status_desc'] = 'Cs&ouml;kkenő &aacute;llapot';
+$lang['status_asc'] = 'N&ouml;vekvő &aacute;llapot';
 $lang['fesubmit_status'] = 'A frontend-ről bek&uuml;ld&ouml;tt cikkik st&aacute;tusza';
 $lang['error_invalidfiletype'] = 'Ilyen t&iacute;pus&uacute; f&aacute;jlt nem lehet felt&ouml;lteni.';
 $lang['error_upload'] = 'A f&aacute;jl felt&ouml;lt&eacute;se k&ouml;zben hiba t&ouml;rt&eacute;nt.';
@@ -63,7 +73,7 @@ $lang['subject_newnews'] = 'Az &uacute;j cikket publik&aacute;ltuk';
 $lang['email_subject'] = 'A kimenő lev&eacute;l t&aacute;rgya';
 $lang['email_template'] = 'A lev&eacute;l form&aacute;tuma';
 $lang['formsubmit_emailaddress'] = 'Az email c&iacute;m, ahova &eacute;rtes&iacute;t&eacute;st k&uuml;ld&uuml;nk a cikk meg&iacute;r&aacute;s&aacute;r&oacute;l';
-$lang['extra'] = 'Extra';
+$lang['extra'] = 'Extra ';
 $lang['uploadscategory'] = 'Felt&ouml;lt&eacute;s kateg&oacute;ria';
 $lang['title_available_templates'] = 'El&eacute;rhető sablonok';
 $lang['resettodefault'] = 'Alap&eacute;rtelmezett &eacute;rt&eacute;kek vissza&aacute;ll&iacute;t&aacute;sa';
@@ -151,8 +161,6 @@ $lang['numbertodisplay'] = 'Megmutathat&oacute; elemek sz&aacute;ma (ha nincs me
 $lang['print'] = 'Nyomtat&aacute;s';
 $lang['postdate'] = 'Publik&aacute;l&aacute;s d&aacute;tuma';
 $lang['postinstall'] = 'Győződj meg r&oacute;la, hogy a \&quot;Modify News\&quot; jogosults&aacute;ggal rendelkezik az &ouml;sszes olyan felhaszn&aacute;l&oacute;, aki cikkeket fog adminisztr&aacute;lni.';
-$lang['rssfeedtitle'] = 'CMS Made Simple RSS h&iacute;rforr&aacute;s';
-$lang['rsstemplate'] = 'RSS sablon';
 $lang['selectcategory'] = 'V&aacute;lassz rovatot';
 $lang['showchildcategories'] = 'Gyermekrovatok mutat&aacute;sa';
 $lang['sortascending'] = 'N&ouml;vekvő rendez&eacute;s';
@@ -167,8 +175,6 @@ $lang['title'] = 'C&iacute;m';
 $lang['options'] = 'Opci&oacute;k';
 $lang['optionsupdated'] = 'Az opci&oacute;kat sikeresen friss&iacute;tett&uuml;k.';
 $lang['useexpiration'] = 'Lej&aacute;rati d&aacute;tum haszn&aacute;lata';
-$lang['showautodiscovery'] = 'Feed Auto-Discovery Link mutat&aacute;sa';
-$lang['autodiscoverylink'] = 'Feed Auto-Discovery URL (&uuml;resen hagyva az alap&eacute;rtelmezett lesz)';
 $lang['eventdesc-NewsArticleAdded'] = 'Akkor k&uuml;ldj&uuml;k, amikor &uacute;j cikk j&ouml;n l&eacute;tre.';
 $lang['eventhelp-NewsArticleAdded'] = '<p>Sent when an article is added.</p>
 <h4>Parameters</h4>
@@ -227,14 +233,14 @@ $lang['eventhelp-NewsCategoryDeleted'] = '<p>Sent when a category is deleted.</p
 <li>\&quot;category_id\&quot; - Id of the news categpry</li>
 </ul>
 ';
+$lang['help_articleid'] = 'Ez a param&eacute;ter csak a r&eacute;szletes n&eacute;zetben &eacute;rtelmezett. Megadhat&oacute; vele, hogy melyik cikk legyen l&aacute;that&oacute; a r&eacute;szletes n&eacute;zetben. Ha -1-et adsz meg, akkor a rendszer a legfrissebb, nem lej&aacute;rt, publik&aacute;lt st&aacute;tusz&uacute; cikket fogja megjelen&iacute;teni.';
 $lang['helpnumber'] = 'A maxim&aacute;lisan megjelen&iacute;thető elemek sz&aacute;ma -- ha nem adod meg, minden elem meg lesz mutatva';
 $lang['helpstart'] = 'Az n. elemn&eacute;l kezdj&uuml;k a megjelen&iacute;t&eacute;st -- &uuml;resen hagyva az első elemn&eacute;l kezdődik  ';
-$lang['helpmakerssbutton'] = 'Link l&eacute;trehoz&aacute;sa a h&iacute;r elemek RSS h&iacute;rforr&aacute;s&aacute;hoz.';
 $lang['helpcategory'] = 'Csak az adott rovat h&iacute;reit jelen&iacute;ts&uuml;k meg. A n&eacute;v ut&aacute;n a * karaktert alkalmazva a gyermekrovatok is megmutathat&oacute;k. T&ouml;bb rovat is megadhat&oacute;, vesszővel elv&aacute;lasztva. &Uuml;resen hagyva minden rovat meg lesz mutatva.';
 $lang['helpmoretext'] = 'A sz&ouml;veg, amit akkor jelen&iacute;t&uuml;nk meg, ha a h&iacute;r hosszabb, mint az &ouml;sszefoglal&oacute; hossza. Alap&eacute;rtelmez&eacute;sben ez \&quot;tov&aacute;bb...\&quot;';
 $lang['helpsummarytemplate'] = 'K&uuml;l&ouml;n sablon haszn&aacute;lata az &ouml;sszefoglal&oacute; megjelen&iacute;t&eacute;s&eacute;hez. L&eacute;teznie kell a modules/News/templates alatt.';
-$lang['helpformtemplate'] = 'Use a database template for displaying the article submission form. This template must exist and be visible in the form templates tab of the News admin, though it does not need to be the default.  If this parameter is not specified, then the current template marked as default will be used.';
-$lang['helpbrowsecattemplate'] = 'Use a database template for displaying the category browser. This template must exist and be visible in the Browse Category Templates tab of the News admin, though it does not need to be the default.  If this parameter is not specified, then the current template marked as default will be used.';
+$lang['helpformtemplate'] = 'Adatb&aacute;zis sablon haszn&aacute;lata a cikk bek&uuml;ldő form megjelen&iacute;t&eacute;s&eacute;hez. Ennek a sablonnak l&eacute;teznie kell &eacute;s l&aacute;that&oacute;nak kell lennie az admin fel&uuml;let sablon panelj&aacute;n, de nem kell alap&eacute;rtelmezettnek lennie. Ha ez a param&eacute;ter nincs megadva, akkor az aktu&aacute;lis alap&eacute;rtelmezett sablont fogja haszn&aacute;lni a rendszer.';
+$lang['helpbrowsecattemplate'] = 'Adatb&aacute;zis sablon haszn&aacute;lata a rovat b&ouml;ng&eacute;sző megjelen&iacute;t&eacute;s&eacute;hez. Ennek a sablonnak l&eacute;teznie kell &eacute;s l&aacute;that&oacute;nak kell lennie az admin fel&uuml;let Rovat sablonok panelj&aacute;n, de nem kell alap&eacute;rtelmezettnek lennie. Ha ez a param&eacute;ter nincs megadva, akkor az aktu&aacute;lis alap&eacute;rtelmezett sablont fogja haszn&aacute;lni a rendszer.';
 $lang['helpdetailtemplate'] = 'K&uuml;l&ouml;n sablon haszn&aacute;lata a cikk megjelen&iacute;t&eacute;s&eacute;hez. L&eacute;teznie kell a modules/News/templates alatt.';
 $lang['helpsortby'] = 'A rendez&eacute;s alapja.  V&aacute;laszt&aacute;si lehetős&eacute;gek: \&quot;news_date\&quot;, \&quot;summary\&quot;, \&quot;news_data\&quot;, \&quot;news_category\&quot;, \&quot;news_title\&quot;.  Alap&eacute;rtelmez&eacute;sben ez a \&quot;news_date\&quot;.';
 $lang['helpsortasc'] = 'Az elemek n&ouml;vekvő sorrendben val&oacute; megmutat&aacute;sa.';
@@ -250,8 +256,8 @@ $lang['help'] = '	<h3>What does this do?</h3>
 	<p>In order to edit the global news preferences, the user must belong to a group with the \&#039;Modify Site Preferences\&#039; permission.</p>
 	<h3>How do I use it?</h3>
 	<p>The easiest way to use it is in conjunction with the cms_module tag.  This will insert the module into your template or page anywhere you wish, and display news items.  The code would look something like: <code>{cms_module module=\&quot;news\&quot; number=\&quot;5\&quot; category=\&quot;beer\&quot;}</code></p>';
-$lang['utma'] = '156861353.1745742775.1167462096.1227524728.1227528035.121';
-$lang['utmz'] = '156861353.1223837548.118.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
-$lang['utmc'] = '156861353';
+$lang['utma'] = '156861353.1637687971.1300706706.1300706706.1300706706.1';
 $lang['utmb'] = '156861353';
+$lang['utmc'] = '156861353';
+$lang['utmz'] = '156861353.1300706706.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 ?>
\ No newline at end of file
