@@ -1,4 +1,19 @@
 <?php
+$lang['error_insufficientparams'] = 'Parametri insufficienti (o non presenti)';
+$lang['error_duplicatename'] = 'Esiste gi&agrave; un elemento con lo stesso nome';
+$lang['detail_page'] = 'Pagina Dettagli';
+$lang['detail_template'] = 'Modello Dettagli';
+$lang['warning_preview'] = 'Attenzione: questo pannello anteprima si comporta in buona parte come la finestra di un browser, permettendovi di navigare rispetto alla pagina iniziale visualizzata. Tuttavia, se lo fate, potreste riscontrare comportamenti inattesi.  Navigare spostandosi dalla pagina iniziale per poi ritornarvi non dur&agrave; i risutati attesi.<br/><strong>Nota:</strong> L&#039;anteprima non carica i file che potreste avere selezionato in attesa di caricamento.';
+$lang['article'] = 'Articolo';
+$lang['preview'] = 'Anteprima';
+$lang['info_detail_returnid'] = 'Questa preferenza &egrave; utilizzata per determinare una pagina (e quindi un template) da usare per visualizzare le pagine di dettaglio. Le URL di Dettaglio News individuali non funzionano se questo parametro non &egrave; impostato su una pagina valida. In aggiunta, se questo parametro &egrave; impostato e nessun parametro detailpage &egrave; aggiunto sul tag news, allora questo valore sar&agrave; usato per i link dei dettagli';
+$lang['title_detail_returnid'] = 'Pagina preefinita da usare per le visualizzazioni di dettaglio';
+$lang['title_submission_settings'] = 'Configurazioni inserimento News';
+$lang['title_fesubmit_settings'] = 'Configurazioni inserimento dal frontend';
+$lang['title_notification_settings'] = 'Configurazioni di notifica';
+$lang['title_detail_settings'] = 'Configurazioni visualizzazione dettaglo';
+$lang['error_invalidurl'] = 'URL invalido <em>(forse &egrave; gi&agrave; usato, o ci sono dei caratteri non validi)</em>';
+$lang['url'] = 'URL ';
 $lang['expired_searchable'] = 'Articoli spirati possono apparire nei risultati della ricerca';
 $lang['helpshowall'] = 'Mostra tutti gli articoli, senza considerare la data di termine visualizzazione';
 $lang['error_invaliddates'] = 'Una o pi&ugrave; date inserite non sono valide';
@@ -42,7 +57,7 @@ $lang['hide_summary_field'] = 'Nasconde il campo sommario quando aggiungi o modi
 $lang['textbox'] = 'Textinput';
 $lang['checkbox'] = 'Check';
 $lang['textarea'] = 'Textarea';
-$lang['file'] = 'File';
+$lang['file'] = 'File ';
 $lang['auto_create_thumbnails'] = 'Automaticamente crea miniature per i file con queste estensioni';
 $lang['allowed_upload_types'] = 'Permettere l&#039;invio solo di file con le seguenti estensioni';
 $lang['fielddefupdated'] = 'Definizione del campo aggiornata';
@@ -65,7 +80,7 @@ $lang['subject_newnews'] = 'Un nuovo articolo &egrave; stato pubblicato';
 $lang['email_subject'] = 'L&#039;Oggetto della email di uscita';
 $lang['email_template'] = 'Il formato del messaggio di email';
 $lang['formsubmit_emailaddress'] = 'Indirizzo email che ricever&agrave; notifica di inserimenti';
-$lang['extra'] = 'Extra';
+$lang['extra'] = 'Extra ';
 $lang['uploadscategory'] = 'Categoria di Upload';
 $lang['title_available_templates'] = 'Modelli utilizzabili';
 $lang['resettodefault'] = 'Reset ai valori predefiniti';
@@ -135,9 +150,10 @@ $lang['filter'] = 'Filtra';
 $lang['more'] = 'Continua...';
 $lang['category_label'] = 'Categoria:';
 $lang['author_label'] = 'Postato da:';
+$lang['extra_label'] = 'Extra:';
 $lang['moretext'] = 'Altro testo';
 $lang['name'] = 'Nome';
-$lang['news'] = 'News';
+$lang['news'] = 'News ';
 $lang['news_return'] = 'Ritorna';
 $lang['newcategory'] = 'Nuova categoria';
 $lang['needpermission'] = 'Hai bisogno del permesso &#039;%s&#039; per usufruire di questa funzione.';
@@ -159,6 +175,7 @@ $lang['sortascending'] = 'Ordine crescente';
 $lang['startdate'] = 'Data inizio';
 $lang['startoffset'] = 'Inizia la visualizzazione dal n-imo articolo';
 $lang['startrequiresend'] = 'Inserire una data di inizio richiede anche una data di fine';
+$lang['apply'] = 'Applica';
 $lang['submit'] = 'Inserisci';
 $lang['summary'] = 'Sommario';
 $lang['summarytemplate'] = 'Modello Sommario';
@@ -273,9 +290,8 @@ $lang['help'] = '<h3>Note Importanti</h3>
 <li>Premere Invio</li>
 </ul>
 Seguendo questi passi si dovrebbe risolvere il problema dei nuovi modelli non trovati e altri errori similari di smarty quando aggiorni ad una versione di CMS che contiene News 2.3 o maggiore.</p>';
-$lang['qca'] = 'P0-341425854-1271258489279';
-$lang['utma'] = '156861353.1785716972.1271258827.1272464498.1272484592.7';
-$lang['utmz'] = '156861353.1272484592.7.6.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php';
+$lang['utma'] = '156861353.1173279377.1339488425.1339488425.1339492135.2';
+$lang['utmz'] = '156861353.1339488425.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.1.10.1272484592';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
