@@ -176,6 +176,7 @@ $lang['sortascending'] = 'Sorteer oplopend';
 $lang['startdate'] = 'Begindatum';
 $lang['startoffset'] = 'Begin tonen bij het n-de item';
 $lang['startrequiresend'] = 'Het toevoegen van een begindatum vereist ook een einddatum';
+$lang['apply'] = 'Opslaan';
 $lang['submit'] = 'Versturen';
 $lang['summary'] = 'Samenvatting';
 $lang['summarytemplate'] = 'Samenvattingssjabloon';
@@ -296,9 +297,8 @@ $lang['help'] = '<h3>Belangrijke opmerkingen</h3>
 <li>Klik Versturen</li>
 </ul>
 Het uitvoeren van bovenstaande stappen moet het probleem oplossen van verdwenen nieuwssjablonen en vergelijkbare smarty-fouten als u upgrade naar een versie van CMSMS die de News-module versie 2.3 of nieuwer heeft.</p>';
-$lang['qca'] = 'P0-1157065314-1313856308297';
-$lang['utma'] = '156861353.1414653339.1316370951.1316370951.1316370951.1';
-$lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1316370951.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utma'] = '156861353.932488201.1336041124.1336041124.1336041124.1';
+$lang['utmz'] = '156861353.1336041124.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/search.php|utmcmd=referral';
 $lang['utmb'] = '156861353';
+$lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
