@@ -7,7 +7,7 @@ $lang['warning_preview'] = 'Upozornenie: Z&aacute;ložka n&aacute;hľadu umožuj
 $lang['article'] = 'Čl&aacute;nok';
 $lang['preview'] = 'N&aacute;hľad';
 $lang['info_detail_returnid'] = 'Parameter služi na zobrazenie novinky na vybranej detailnej str&aacute;nke. Vlastn&eacute; URL nebud&uacute; fungovať ak nebude tento parameter nastaven&yacute; na korektn&uacute; str&aacute;nku. Pokiaľ je ale nastaven&aacute; t&aacute;to voľba a detailpage parameter nebude zadan&yacute; v značke News, použije sa pre zobrazenie detailu d&aacute;to voľba.';
-$lang['title_detail_returnid'] = 'Prednastaven&eacute; str&aacute;nka rpe detail';
+$lang['title_detail_returnid'] = 'Prednastaven&eacute; str&aacute;nka pre detail';
 $lang['title_submission_settings'] = 'Nastavenie odoslania noviniek ';
 $lang['title_fesubmit_settings'] = 'Nastavenie odoslania cez web';
 $lang['title_notification_settings'] = 'Nastavenia notifik&aacute;cie';
@@ -175,6 +175,7 @@ $lang['sortascending'] = 'Triediť vzostupne';
 $lang['startdate'] = 'Zač&iacute;na';
 $lang['startoffset'] = 'Začiatok zobrazovania od N-tej položky';
 $lang['startrequiresend'] = 'Vloženie d&aacute;tumu začiatku potrebuje tiež d&aacute;tum ukončenia';
+$lang['apply'] = 'Vykonať';
 $lang['submit'] = 'Odoslať';
 $lang['summary'] = 'S&uacute;hrn';
 $lang['summarytemplate'] = '&Scaron;abl&oacute;na s&uacute;hrnu';
@@ -296,8 +297,4 @@ $lang['help'] = '<h3>D&ocirc;ležit&eacute; upozornenie</h3>
 <li>Hit Submit</li>
 </ul>
 <p>Following these steps should solve the problem of your news templates not being found and other similar smarty errors when you upgrade to a version of CMS that has News 2.3 or greater.</p>';
-$lang['utmc'] = '156861353';
-$lang['utma'] = '156861353.397069566.1316370484.1316370484.1316453841.2';
-$lang['utmz'] = '156861353.1316453841.2.2.utmccn=(referral)|utmcsr=dev.cmsmadesimple.org|utmcct=/|utmcmd=referral';
-$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
