@@ -13,7 +13,7 @@ $lang['title_fesubmit_settings'] = 'Pode&scaron;avanje procedue objavljivanja iz
 $lang['title_notification_settings'] = 'Pode&scaron;avanje obave&scaron;tenja';
 $lang['title_detail_settings'] = 'Pode&scaron;avanja detaljnog pregleda';
 $lang['error_invalidurl'] = 'Lo&scaron; URL <em>(možda je već u upotrebi, ili sadrži nevalidne karaktere)</em>';
-$lang['url'] = 'URL';
+$lang['url'] = 'URL ';
 $lang['expired_searchable'] = 'Članci kojima je važnost istekla mogu se pojaviti u rezultatima pretrage';
 $lang['helpshowall'] = 'Prikaži sve članke, nezavisno od datuma prestanka važnosti';
 $lang['error_invaliddates'] = 'Jedan ili vi&scaron;e unetih datuma nisu validni';
@@ -144,9 +144,9 @@ $lang['edit'] = 'Izmeni';
 $lang['enddate'] = 'Datum isteka';
 $lang['endrequiresstart'] = 'Uno&scaron;enje datuma isteka zahteva da unesete i datum početka važenja';
 $lang['entries'] = '%s članak(a)';
-$lang['status'] = 'Status';
+$lang['status'] = 'Status ';
 $lang['expiry'] = 'Ističe';
-$lang['filter'] = 'Filter';
+$lang['filter'] = 'Filter ';
 $lang['more'] = 'Jo&scaron;';
 $lang['category_label'] = 'Kategorija:';
 $lang['author_label'] = 'Objavio/la:';
@@ -175,6 +175,7 @@ $lang['sortascending'] = 'Sortiraj u rastućem redosledu';
 $lang['startdate'] = 'Datum početka važenja';
 $lang['startoffset'] = 'Počni da prikazuje&scaron; od n-tog članka';
 $lang['startrequiresend'] = 'Uno&scaron;enje datuma početka važenja zahteva da unesete i datum isteka';
+$lang['apply'] = 'Primeni izmene';
 $lang['submit'] = 'Po&scaron;alji';
 $lang['summary'] = 'Sažetak';
 $lang['summarytemplate'] = '&Scaron;abloni sažetaka';
@@ -294,9 +295,8 @@ $lang['help'] = '<h3>Važne napomene</h3>
 <li>Kliknite na &#039;Po&scaron;alji&#039;</li>
 </ul>
 <p>Ovo bi trebalo da re&scaron;i problem nepronalaženja &scaron;ablona za novosti i druge slične Smarty gre&scaron;ke koje su se mogle javiti nakon &scaron;to se prebacite na verziju CMS MS-a koja sadrži verziju 2.3 modula ili noviju.</p>';
-$lang['utma'] = '156861353.1702067667.1318973760.1319013867.1319046026.5';
-$lang['utmz'] = '156861353.1318973760.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
-$lang['qca'] = 'P0-91463818-1318971343774';
-$lang['utmb'] = '156861353.2.10.1319046093';
+$lang['utma'] = '156861353.279934917.1335981957.1335981957.1335981957.1';
+$lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
+$lang['utmz'] = '156861353.1335981957.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 ?>
\ No newline at end of file
