@@ -175,6 +175,7 @@ $lang['sortascending'] = 'Sortera stigande';
 $lang['startdate'] = 'Startdatum';
 $lang['startoffset'] = 'B&ouml;rja visa fr&aring;n nyhet nummer X';
 $lang['startrequiresend'] = 'Ett startdatum kr&auml;ver ocks&aring; att man anger ett stoppdatum';
+$lang['apply'] = 'Verkst&auml;ll';
 $lang['submit'] = 'L&auml;gg till';
 $lang['summary'] = 'Sammandrag';
 $lang['summarytemplate'] = 'Mall f&ouml;r sammandrag';
@@ -289,9 +290,8 @@ $lang['help'] = '<h3>Important Notes</h3>
 <li>Hit Submit</li>
 </ul>
 Following these steps should solve the problem of your news templates not being found and other similar smarty errors when you upgrade to a version of CMS that has News 2.3 or greater.</p>';
-$lang['utma'] = '156861353.2084869274.1316417662.1316417662.1316417662.1';
-$lang['utmz'] = '156861353.1316417662.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/search.php|utmcmd=referral';
-$lang['qca'] = 'P0-1529175659-1310081076901';
+$lang['utma'] = '156861353.1145988012.1339276866.1339276866.1339276866.1';
+$lang['utmz'] = '156861353.1339276866.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/viewtopic.php|utmcmd=referral';
 $lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
