@@ -269,4 +269,31 @@ if( version_compare($oldversion,'2.10.6') < 0 )
      $dict->ExecuteSQLArray($sqlarray);
   }
 
+if( version_compare($oldversion,'2.12.7') < 0 )
+  {
+    $res = $this->RegisterModulePlugin(true);
+
+    $this->RegisterSmartyPlugin('news','function','function_plugin');
+
+    $this->CreateStaticRoutes();
+    
+    # Setup Simplex Theme HTML5 sample summary template
+    $fn = dirname(__FILE__).DIRECTORY_SEPARATOR.
+        'templates'.DIRECTORY_SEPARATOR.'Summary_Simplex_template.tpl';
+    if( file_exists( $fn ) )
+    {
+        $template = @file_get_contents($fn);
+        $this->SetTemplate('summarySummary_Simplex',$template);
+    }
+
+    # Setup Simplex Theme HTML5 sample detail template
+    $fn = dirname(__FILE__).DIRECTORY_SEPARATOR.
+        'templates'.DIRECTORY_SEPARATOR.'Simplex_Detail_template.tpl';
+    if( file_exists( $fn ) )
+    {
+        $template = @file_get_contents($fn);
+        $this->SetTemplate('detailSimplex_Detail',$template);
+    }
+  }
+
 ?>
