@@ -1,4 +1,5 @@
 <?php
+$lang['use_or'] = 'Encontrar resultados que correspondam a QUALQUER palavra';
 $lang['param_detailpage'] = 'Usado apenas para combinar resultados de m&oacute;dulos, este par&acirc;metro permite especificar uma p&aacute;gina de diferentes detalhes  para os resultados. Isso &eacute; &uacute;til se, por exemplo, sempre que mostrar a op&ccedil;&atilde;o para a p&aacute;gina detalhe com um modelo diferente. <em>(<strong>Nota os m&oacute;dulos podem, opcionalmente, substituir isto</strong>)</em>';
 $lang['prompt_resultpage'] = 'P&aacute;gina de resultados para cada m&oacute;dulo <em>(Nota os m&oacute;dulos podem, opcionalmente, substituir isto)</em>';
 $lang['search_method'] = 'Compatibilidade com &quot;Pretty Urls&quot; via m&eacute;todo POST, o valor padr&atilde;o &eacute; sempre GET, para fazer com que trabalhe desta forma, basta colocar {search search_method=&quot;post&quot;}';
@@ -26,6 +27,20 @@ $lang['description'] = 'M&oacute;dulo de pesquisa local e outros conte&uacute;do
 $lang['reindexallcontent'] = 'Reindexar todos os conte&uacute;dos';
 $lang['reindexcomplete'] = 'Reindexa&ccedil;&atilde;o Completa!';
 $lang['stopwords'] = 'Ignorar as seguintes palavras';
+$lang['default_stopwords'] = 'i, me, my, myself, we, our, ours, ourselves, you, your, yours, 
+yourself, yourselves, he, him, his, himself, she, her, hers, 
+herself, it, its, itself, they, them, their, theirs, themselves, 
+what, which, who, whom, this, that, these, those, am, is, are, 
+was, were, be, been, being, have, has, had, having, do, does, 
+did, doing, a, an, the, and, but, if, or, because, as, until, 
+while, of, at, by, for, with, about, against, between, into, 
+through, during, before, after, above, below, to, from, up, down, 
+in, out, on, off, over, under, again, further, then, once, here, 
+there, when, where, why, how, all, any, both, each, few, more, 
+most, other, some, such, no, nor, not, only, own, same, so, 
+than, too, very';
+$lang['prompt_resetstopwords'] = 'Carregue Stop Words predefinidas, a partir da linguagem';
+$lang['input_resetstopwords'] = 'Carregar';
 $lang['searchresultsfor'] = 'Resultados de pesquisa por';
 $lang['noresultsfound'] = 'N&atilde;o foram encontradas p&aacute;ginas com os termos da sua pesquisa.';
 $lang['timetaken'] = 'Tempo Gasto';
@@ -87,9 +102,8 @@ $lang['help'] = '<h3>What does this do?</h3>
 <p>The search module will not search any &quot;inactive&quot; pages. However on occasion, when you are using the CustomContent module, or other smarty logic to show different content to different groups of users, it may be advisiable to prevent the entire page from being indexed even when it is live.  To do this include the following tag anywhere on the page <em>&amp;lt;!-- pageAttribute: NotSearchable --&amp;gt;</em> When the search module sees this tag in the page it will not index any content for that page.</p>
 <p>The <em>&amp;lt;!-- pageAttribute: NotSearchable --&amp;gt;</em> tag can be placed in the template as well.  if this is done, none of the pages attached to that template will be indexed.  Those pages will be re-indexed if the tag is removed</p>
 ';
-$lang['utma'] = '156861353.1237943808.1260371543.1269303018.1269308063.80';
-$lang['utmz'] = '156861353.1269224531.76.37.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
-$lang['qca'] = 'P0-938093432-1260371543221';
+$lang['utma'] = '156861353.1883263935.1338828144.1338828144.1338828144.1';
+$lang['utmz'] = '156861353.1338828144.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmc'] = '156861353';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
