@@ -204,7 +204,7 @@ foreach( $val as $elem )
 	{
 	  continue;
 	}
-      $onetemplate->active = 0;
+      $onetemplate->active = 1; // changed for CMSMS 1.11.
       $onetemplate->default = 0;
       $templates[] = $onetemplate;
       $onetemplate = new Template();
@@ -243,10 +243,16 @@ foreach( $val as $elem )
 	}
 
     case 'ASSOC_TNAME':
+      if( strpos($value,' : ') !== FALSE ) {
+        list($junk,$value) = explode(' : ',$value,2);
+      }
       $oneassoc['tname'] = $value;
       break;
 
     case 'ASSOC_CSSNAME':
+      if( strpos($value,' : ') !== FALSE ) {
+        list($junk,$value) = explode(' : ',$value,2);
+      }
       $oneassoc['cssname'] = $value;
       break;
 
@@ -409,7 +415,6 @@ foreach( $templates as $onetemplate )
   $newtemplates[] = $onetemplate;
 }
 $templates = $newtemplates;
-	
 
 // save our references as files
 // first we create the destination directory if it doesn't already exist
