@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: edithtmlblob.php 7396 2011-09-15 12:57:25Z rolf1 $
+#$Id: edithtmlblob.php 8110 2012-06-25 13:29:33Z calguy1000 $
 
 $CMS_ADMIN_PAGE=1;
 
@@ -75,7 +75,7 @@ if( $gcb_wysiwyg )
 
 if ($access)
 {
-	if (isset($_POST["submit2"]) || $ajax)
+  if (isset($_POST["submit2"]) || isset($_POST['apply']) || $ajax)
 	{
 		$validinfo = true;
 		if ($htmlblob == "")
@@ -102,8 +102,8 @@ if ($access)
 			$the_blob->content = $content;
 			$the_blob->owner = $owner_id;
 
+			$the_blob->ClearAuthors();
 			if (isset($_POST["additional_editors"])) {
-			  $the_blob->ClearAuthors();
 			  foreach ($_POST["additional_editors"] as $addt_user_id) {
 			    $the_blob->AddAuthor($addt_user_id);
 			  }
