@@ -33,9 +33,18 @@ if( !isset($CMS_INSTALL_PAGE) )
   }
 
 #Setup session with different id and start it
-if( !isset($CMS_ADMIN_PAGE) && !isset($CMS_INSTALL_PAGE) )
+if( isset($CMS_ADMIN_PAGE) || isset($CMS_INSTALL_PAGE) )
   {
     // admin pages can't be cached... period, at all.. never.
+    @session_cache_limiter('private');
+    header("Expires: Mon, 26 Jul 1997 05:00:00 GMT");
+    header("Last-Modified: " . gmdate("D, d M Y H:i:s") . " GMT");
+    header("Cache-Control: no-store, no-cache, must-revalidate");
+    header("Cache-Control: post-check=0, pre-check=0", false);
+    header("Pragma: no-cache");
+  }
+else
+  {
     @session_cache_limiter('public');
   }
 
@@ -59,7 +68,7 @@ if (version_compare(phpversion(),"5.3.0","<")) {
 require_once($dirname.DIRECTORY_SEPARATOR.'fileloc.php');
 require_once($dirname.DIRECTORY_SEPARATOR.'lib'.DIRECTORY_SEPARATOR.'classes'.DIRECTORY_SEPARATOR.'class.CmsException.php');
 require_once($dirname.DIRECTORY_SEPARATOR.'lib'.DIRECTORY_SEPARATOR.'classes'.DIRECTORY_SEPARATOR.'class.cms_config.php');
-require_once($dirname.DIRECTORY_SEPARATOR.'lib'.DIRECTORY_SEPARATOR.'classes'.DIRECTORY_SEPARATOR.'class.CmsObject.php');
+require_once($dirname.DIRECTORY_SEPARATOR.'lib'.DIRECTORY_SEPARATOR.'classes'.DIRECTORY_SEPARATOR.'class.CmsApp.php');
 if( !isset($CMS_INSTALL_PAGE) )
 {
   require_once($dirname.DIRECTORY_SEPARATOR.'lib'.DIRECTORY_SEPARATOR.'shutdown.php');
@@ -81,6 +90,27 @@ if (isset($starttime))
 
 if( isset($CMS_ADMIN_PAGE) )
   {
+    function cms_admin_sendheaders($content_type = 'text/html',$charset = '')
+    {
+      if( !$charset ) $charset = get_encoding();
+
+      // Date in the past
+      header("Expires: Mon, 26 Jul 1997 05:00:00 GMT");
+
+      // always modified
+      header("Last-Modified: " . gmdate("D, d M Y H:i:s") . " GMT");
+ 
+      // HTTP/1.1
+      header("Cache-Control: no-store, no-cache, must-revalidate");
+      header("Cache-Control: post-check=0, pre-check=0", false);
+
+      // HTTP/1.0
+      header("Pragma: no-cache");
+        
+      // Language shizzle
+      header("Content-Type: $content_type; charset=$charset");
+    }
+
      if( !isset($_SESSION[CMS_USER_KEY]) )
        {
 	 if( isset($_COOKIE[CMS_SECURE_PARAM_NAME]) )
@@ -185,13 +215,6 @@ if (!isset($_SERVER['REQUEST_URI']))
     }
 }
 
-#Setup the object sent to modules
-cmsms()->set_variable('pluginnum',1);
-if (isset($page))
-{
-  cmsms()->set_variable('page',$page);
-}
-
 #Set a umask
 $global_umask = get_site_preference('global_umask','');
 if( $global_umask != '' )
@@ -199,27 +222,6 @@ if( $global_umask != '' )
   @umask( octdec($global_umask) );
 }
 
-#Set the locale if it's set
-#either in the config, or as a site preference.
-if (isset($config['locale']) && $config['locale'] != '')
-{
-  $str = $config['locale'];
-  if( is_string($str) )
-    {
-      $str = trim($str);
-    }
-  $res = @setlocale(LC_ALL, $str);
-  if( $res === FALSE )
-    {
-      debug_buffer('IMPORTANT: SetLocale failed');
-    }
-}
-$frontendlang = get_site_preference('frontendlang');
-
-$smarty->assign('sitename', get_site_preference('sitename', 'CMSMS Site'));
-$smarty->assign('lang',$frontendlang);
-$smarty->assign('encoding',get_encoding());
-
 if ($config['debug'] == true)
 {
   $smarty->debugging = true;
@@ -227,6 +229,7 @@ if ($config['debug'] == true)
 }
 
 #Setup content routes
+/* not needed
 if( !isset($CMS_ADMIN_PAGE) && !isset($CMS_STYLESHEET) && !isset($CMS_INSTALL_PAGE) )
 {
   debug_buffer('','Loading Routes');
@@ -235,6 +238,7 @@ if( !isset($CMS_ADMIN_PAGE) && !isset($CMS_STYLESHEET) && !isset($CMS_INSTALL_PA
   $contentops->register_routes();
   debug_buffer('','End of Loading Routes');
 }
+*/
 
 #Load all installed module code
 if (! isset($CMS_INSTALL_PAGE))
@@ -245,12 +249,19 @@ if (! isset($CMS_INSTALL_PAGE))
     debug_buffer('', 'End of Loading Modules');
   }
 
+#Setup language stuff.... will auto-detect languages
+CmsNlsOperations::set_language();
+
+$CMS_LAZYLOAD_MODULES = 1; // still used ??
+
 #Do auto task stuff.
 if (! isset($CMS_INSTALL_PAGE))
   {
     CmsRegularTaskHandler::handle_tasks();
   }
 
+$smarty->assign('sitename', get_site_preference('sitename', 'CMSMS Site'));
+
 function sanitize_get_var(&$value, $key)
 {
   if (version_compare(phpversion(),"5.3.0","<")) {
