@@ -1,11 +1,11 @@
 <?php
 $lang['installed_module'] = 'Modul nainstalov&aacute;n';
-$lang['automatedtask_success'] = 'Automated Task Succeeded';
+$lang['automatedtask_success'] = 'Automatick&aacute; &uacute;loha byla &uacute;spě&scaron;n&aacute;';
 $lang['ip_addr'] = 'IP adresa';
 $lang['install_admin_pwsalt_note'] = 'Pokud se rozhodnete zapnout solen&iacute; hesel, nebude absolutně ž&aacute;dn&yacute; způsob, jak hesla vyresetovat, než přes funkci obnovy zapomenut&eacute;ho hesla. Proto je velmi důležit&eacute; ke každ&eacute;mu administr&aacute;torsk&eacute;mu &uacute;čtu přiřadit spr&aacute;vnou emailovou adresu';
 $lang['admin_salt'] = 'Solit administr&aacute;torsk&aacute; hesla';
 $lang['setup_flat_urls'] = 'Nastavuj&iacute; se ploch&eacute; URL';
-$lang['install_timezone'] = 'Někter&eacute; server s PHP 5.3 nemaj&iacute; spr&aacute;vně nastavenou časovou z&oacute;nu. Než budete pokračovat, vyberte pros&iacute;m odpov&iacute;daj&iacute;c&iacute; časovou z&oacute;nu ze seznamu n&iacute;že. Pokud to na Va&scaron;em serveru nen&iacute; nutn&eacute;, můžete vybrat &quot;Ž&aacute;dn&yacute;&quot;. <strong>Pozn&aacute;mka:</strong> Vyberte časovou z&oacute;nu Va&scaron;eho serveru, toto neovlivn&iacute; zobrazen&iacute;, ale je použito při v&yacute;počtech vztahuj&iacute;c&iacute;ch se k datumu. Toto nastaven&iacute; může b&yacute;t změněno po instalaci &uacute;pravou souboru config.php.';
+$lang['install_timezone'] = 'Někter&eacute; servery s PHP 5.3 nemaj&iacute; spr&aacute;vně nastavenou časovou z&oacute;nu. Než budete pokračovat, vyberte pros&iacute;m odpov&iacute;daj&iacute;c&iacute; časovou z&oacute;nu ze seznamu n&iacute;že. Pokud to na Va&scaron;em serveru nen&iacute; nutn&eacute;, můžete vybrat &quot;Ž&aacute;dn&yacute;&quot;. <strong>Pozn&aacute;mka:</strong> Vyberte časovou z&oacute;nu Va&scaron;eho serveru, toto neovlivn&iacute; zobrazen&iacute;, ale je použito při v&yacute;počtech vztahuj&iacute;c&iacute;ch se k datumu. Toto nastaven&iacute; může b&yacute;t změněno po instalaci &uacute;pravou souboru config.php.';
 $lang['timezone'] = 'Časov&aacute; z&oacute;na';
 $lang['none'] = 'Ž&aacute;dn&aacute;';
 $lang['test_error_estrict'] = 'Testuje je error_reporting pro uji&scaron;těn&iacute;, že E_STRICT je zak&aacute;z&aacute;no';
@@ -96,7 +96,7 @@ $lang['test_check_open_basedir'] = 'Kontrola PHP Open Basedir';
 $lang['test_check_open_basedir_failed'] = 'Open basedir omezen&iacute; jsou v &uacute;činnosti. S t&iacute;mto omezen&iacute;m mohou b&yacute;t probl&eacute;my s funkčnost&iacute; někter&yacute;ch modulů.';
 $lang['unlimited'] = 'Neomezeno';
 $lang['test_open_basedir_session_save_path'] = 'Open basedir omezen&iacute; vypadaj&iacute; b&yacute;t v &uacute;činnosti. Pokud budete m&iacute;t probl&eacute;my s  SESSION a ini_set funguje, můžete povolit session přes cookies vložen&iacute;m: ini_set(&#039;session.use_only_cookies&#039;, 1);  na zač&aacute;tek souboru include.php';
-$lang['install_warn_db_createtables'] = 'Norm&aacute;lně by toto pole mělo b&yacute;t za&scaron;krtnuto vždy. Při zakazov&aacute;n&iacute; t&eacute;to vlastnosti je třeba b&yacute;t opatrn&yacute;';
+$lang['install_warn_db_createtables'] = 'Norm&aacute;lně by toto pole mělo b&yacute;t za&scaron;krtnuto vždy. Při zakazov&aacute;n&iacute; t&eacute;to vlastnosti je třeba b&yacute;t opatrn&yacute;.';
 $lang['install_admin_tablesnotcreated'] = 'Proces kompletn&iacute;. Instalačn&iacute; proces skončil, na V&aacute;&scaron; požadavek nebyly datab&aacute;zov&eacute; tabulky vytvořeny. Přesto byl konfiguračn&iacute; soubor resetov&aacute;n a v&scaron;echny před-instalačn&iacute; testy souhlas&iacute;. Děkujeme a zde je V&aacute;&scaron;';
 $lang['info_create_dir_and_file'] = 'Vlastn&iacute;k HTTP procesu nemůže vytvořit soubor uvnitř adres&aacute;ře, kter&yacute; vlastn&iacute;. Toto je pravděpodobně zapnut&yacute;m safe modem. Mnoho funkc&iacute; v CMS Made Simple nebude spr&aacute;vně fungovat s t&iacute;mto nastaven&iacute;m. Pokračov&aacute;n&iacute; nen&iacute; možn&eacute;.';
 $lang['test_create_dir_and_file'] = 'Kontroluje se, zda httpd proces může vytvořit soubor uvnitř j&iacute;m vytvořen&eacute;ho adres&aacute;ře.';
@@ -298,7 +298,7 @@ $lang['install_admin_email_info'] = 'Odeslat informace o vytv&aacute;řen&eacute
 $lang['install_admin_email_note'] = '<strong>Pozn&aacute;mka:</strong> Tato funkce použ&iacute;v&aacute; funkci mail v php. Pokud neobdrž&iacute;te tento e-mail, může to znamenat, že server nen&iacute; spr&aacute;vně nakonfigurov&aacute;n a měli byste kontaktovat administr&aacute;tora (podporu) hostingu.';
 $lang['install_admin_sitename'] = 'Toto je jm&eacute;no Va&scaron;&iacute; str&aacute;nky. Bude použito na různ&yacute;ch m&iacute;stech v&yacute;choz&iacute;ch &scaron;ablon a kdekoliv, kam zad&aacute;te tag {sitename}.';
 $lang['install_admin_db'] = 'Informace o datab&aacute;zi';
-$lang['install_admin_db_info'] = '<p>Ujistěte se, že jste vytvořili datab&aacute;zi a přidělili uživateli, kter&eacute;ho hodl&aacute;te použ&iacute;vat.</p>
+$lang['install_admin_db_info'] = '<p>Ujistěte se, že jste vytvořili datab&aacute;zi a přidělili pln&aacute; pr&aacute;va uživateli, kter&yacute; ji bude použ&iacute;vat.</p>
 <p>Pro MySQL postupujte n&aacute;sleduj&iacute;c&iacute;m způsobem:</p>
 <p>Přihla&scaron;te se do MySQL z konzole a zadejte n&aacute;sleduj&iacute;c&iacute; př&iacute;kazy:</p>
 <ol>
@@ -337,7 +337,7 @@ $lang['install_admin_install_modules'] = 'Instaluj&iacute; se moduly...';
 $lang['install_admin_index_search'] = 'Vytv&aacute;ř&iacute; se index pro hled&aacute;n&iacute;...';
 $lang['install_admin_clear_cache'] = 'Čist&iacute; se cache str&aacute;nek (pokud existuje)...';
 $lang['install_admin_emailing'] = 'Odes&iacute;laj&iacute; se informace o administr&aacute;torsk&eacute;m &uacute;čtu e-mailem...';
-$lang['install_admin_congratulations'] = 'Gratulujeme, v&scaron;echna nastaven&iacute; byla provedena - zde je va&scaron;e nov&aacute; str&aacute;nka</a>';
+$lang['install_admin_congratulations'] = 'Gratulujeme, v&scaron;echna nastaven&iacute; byla provedena - zde jsou va&scaron;e nov&eacute; ';
 $lang['could_not_connect_db'] = 'Nelze se připojit do datab&aacute;ze. Ověřte pros&iacute;m spr&aacute;vnost uživatelsk&eacute;ho jm&eacute;na a hesla, a opr&aacute;vněn&iacute; uživatele přistupovat k dan&eacute; datab&aacute;zi.';
 $lang['cannot_write_config'] = 'Chyba: Nelze zapisovat do %s.';
 $lang['email_accountinfo_subject'] = 'Informace administr&aacute;torsk&eacute;ho &uacute;čtu CMS Made Simple';
@@ -348,9 +348,9 @@ uživatelsk&eacute; jm&eacute;no: %s
 heslo: %s
 
 Přihl&aacute;sit do administrace se můžete zde: %s';
-$lang['utma'] = '156861353.94793895.1320075411.1320075411.1320075411.1';
-$lang['utmz'] = '156861353.1320075411.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
-$lang['qca'] = 'P0-2065764558-1319293569112';
-$lang['utmb'] = '156861353.3.9.1320077767335';
+$lang['qca'] = 'P0-1271871094-1301294880209';
+$lang['utma'] = '156861353.1968969400.1314780963.1320732581.1321001127.3';
+$lang['utmz'] = '156861353.1314780963.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
+$lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
 ?>
\ No newline at end of file
