@@ -1,11 +1,21 @@
 <?php
+$lang['setup_flat_urls'] = 'Flat URLs are setup';
+$lang['install_timezone'] = 'Some servers running php 5.3 have not set the timezone correctly.  Please select the appropriate timezone from the list before.  If this is not necessary on your server you may select &quot;None&quot;, you can always change this setting later in the config.php.';
+$lang['timezone'] = 'Tidszone';
+$lang['none'] = 'Ingen';
+$lang['test_error_estrict'] = 'Testing error_reporting to ensure E_STRICT is disabled';
+$lang['test_estrict_failed'] = 'E_STRICT er sl&aring;et til';
+$lang['info_estrict_failed'] = 'Some libraries that CMSMS uses do not work well with E_STRICT.  Please disable this before continuing';
+$lang['test_error_edeprecated'] = 'Testing error_reporting to ensure E_DEPRECATED is disabled';
+$lang['test_edeprecated_failed'] = 'E_DEPRECATED er sl&aring;et til';
+$lang['info_edeprecated_failed'] = 'If E_DEPRECATED is enabled in your error reporting users will see alot of warning messages that could effect the display and functionalty';
 $lang['invalidemail'] = 'Den angivne email adresse er ikke gyldig';
 $lang['empty_query'] = 'Tom foresp&oslash;rgsel? %s';
 $lang['no_db_driver'] = 'Ingen kompatibel database driver fundet';
 $lang['test_check_output_buffering'] = 'Kontrollerer output bufferin';
 $lang['test_check_output_buffering_failed'] = 'Output buffering er sl&aring;et fra. Du vil muligvis ikke kunne benytte funktioner der kr&aelig;ver dette.';
 $lang['phpinfo'] = 'Vis PHP information';
-$lang['mod_security'] = 'Apache Mod Security';
+$lang['mod_security'] = 'Apache Mod sikkerhed';
 $lang['test_check_tempnam'] = 'Kontrollerer for tempnam function';
 $lang['test_check_db_drivers'] = 'DB drivere';
 $lang['test_check_db_drivers_failed'] = 'Ingen DB drivere found';
@@ -44,7 +54,7 @@ $lang['upgrade_ok'] = 'Please review config.php, modify any new settings as nece
 $lang['upgrade_complete'] = 'Opgraderingen er udf&oslash;rt';
 $lang['upgrade_end'] = 'CMS er opgraderet. Klik %s for at se dit cms-site eller du kan %s.';
 $lang['here'] = 'her';
-$lang['go_to_admin'] = 'for at g&aring; til administrationen';
+$lang['go_to_admin'] = 'G&aring; til administrationen';
 $lang['errorfilenot'] = 'Fil ikke fundet!';
 $lang['errorfilenotwritable'] = 'Fil ikke skrivbar!';
 $lang['nofiles'] = 'Denne ressource eksisterer ikke!';
@@ -56,7 +66,7 @@ $lang['not_checksum'] = 'Kunne ikke hente checksum.';
 $lang['format_datetime'] = '%c';
 $lang['upload_err_ini_size'] = 'Den upload&#039;ede fil er st&oslash;rre end den upload_max_filesize der er angivet i php.ini!';
 $lang['upload_err_form_size'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';
-$lang['upload_err_partial'] = 'The uploaded file was only partially uploaded.';
+$lang['upload_err_partial'] = 'Den upload&#039;ede fil blev kun delvist upload&#039;et';
 $lang['upload_err_no_file'] = 'Ingen fil blev upload&#039;et.';
 $lang['upload_err_no_tmp_dir'] = 'Mangler en midlertidig mappe.';
 $lang['upload_err_cant_write'] = 'Fejl ved skrivning til disk.';
@@ -70,14 +80,14 @@ $lang['test_check_magic_quotes_gpc'] = 'Magic quotes for Get/Post/Cookie operati
 $lang['test_check_magic_quotes_gpc_failed'] = 'When magic_quotes are on, all single-quote, double quote and backslash are escaped with a backslash automatically. This can cause many problems in CMS.';
 $lang['test_check_magic_quotes_runtime'] = 'Magic quotes in runtime';
 $lang['test_check_magic_quotes_runtime_failed'] = 'When magic_quotes are on, most functions that return data from any sort of external source including databases and text files will have quotes escaped with a backslash. This will cause problems with CMS made simple.';
-$lang['install_admin_checksum'] = 'Check your installation';
-$lang['upgrade_admin_checksum'] = 'Check your system upgrade';
+$lang['install_admin_checksum'] = 'Tjek din installation';
+$lang['upgrade_admin_checksum'] = 'Tjek din system opgradering';
 $lang['checksum'] = 'Checksum test';
-$lang['checksum_file'] = 'Checksum file';
+$lang['checksum_file'] = 'Checksum fil';
 $lang['install_test_checksum'] = 'You can validate the integrity of your CMS files by comparing against original CMS checksum. It can assist in finding problems with uploads.';
-$lang['checksum_passed'] = 'All checksums match!';
+$lang['checksum_passed'] = 'Alle tjeksummer passer!';
 $lang['checksum_failed'] = 'Checksum match with errors. Look at the help for more information';
-$lang['test_check_open_basedir'] = 'Check for PHP Open Basedir';
+$lang['test_check_open_basedir'] = 'Tjek for PHP Open Basedir';
 $lang['test_check_open_basedir_failed'] = 'Open basedir restrictions are in effect. You may have difficulty with some addon functionality with this restriction.';
 $lang['unlimited'] = 'Ubegr&aelig;nset';
 $lang['test_open_basedir_session_save_path'] = 'Open basedir is setting. If you have SESSION problems and ini_set works you can try to enable session cookies adding: ini_set(&#039;session.use_only_cookies&#039;, 1);  to top of include.php';
@@ -332,8 +342,9 @@ brugernavn: %s
 kodeord: %s
 
 Log ind i site administrationen her: %s';
-$lang['utma'] = '156861353.24508746.1245226592.1245226592.1245226592.1';
-$lang['utmb'] = '156861353';
+$lang['utma'] = '156861353.868490754.1298370706.1299501521.1299526853.9';
+$lang['utmz'] = '156861353.1299501521.8.3.utmcsr=twitter.com|utmccn=(referral)|utmcmd=referral|utmcct=/Bovelett';
+$lang['qca'] = 'P0-392249128-1298370706225';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1245226592.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utmb'] = '156861353.1.10.1299526853';
 ?>
\ No newline at end of file
