@@ -1,4 +1,9 @@
 <?php
+$lang['detected'] = 'Erkannt';
+$lang['docroot_leaveblank'] = 'Lassen Sie dieses Feld leer, um System Voreinstellungen zu verwenden';
+$lang['test_xmlreader_class'] = 'Pr&uuml;fung, ob die PHP-Klasse XMLReader existiert';
+$lang['test_xmlreader_failed'] = 'Die Klasse XMLReader ist in Ihrer PHP-Installation nicht aktiviert. Sie k&ouml;nnen zwar das System verwenden, es ist Ihnen aber nicht m&ouml;glich, die Funktion zur Ferninstallation von Modulen zu verwenden.';
+$lang['test_check_xml_failed'] = 'Die XML-Unterst&uuml;tzung wurde nicht in Ihre PHP-Installation kompiliert. Sie k&ouml;nnen das System verwenden, aber es ist nicht m&ouml;glich, Module &uuml;ber den ModulManager zu installieren.';
 $lang['installed_module'] = 'Modul installiert';
 $lang['automatedtask_success'] = 'Automatische Aufgabenplanung ausgef&uuml;hrt';
 $lang['ip_addr'] = 'IP-Adresse';
@@ -11,7 +16,7 @@ $lang['timezone'] = 'Zeitzone';
 $lang['none'] = 'Keine';
 $lang['test_error_estrict'] = 'Test der Einstellung error_reporting, um sicherzustellen, dass E_STRICT deaktiviert ist';
 $lang['test_estrict_failed'] = 'E_STRICT ist aktiviert';
-$lang['info_estrict_failed'] = 'Einige Programmbibliotheken, die CMSms verwendet, funktionieren nicht gut mit E_STRICT.  Bitte deaktivieren Sie diese Einstellung, bevor Sie weitermachen.';
+$lang['info_estrict_failed'] = 'Einige Programmbibliotheken, die CMSMS verwendet, funktionieren nicht gut mit E_STRICT.  Bitte deaktivieren Sie diese Einstellung, bevor Sie weitermachen.';
 $lang['test_error_edeprecated'] = 'Test der Einstellung error_reporting, um sicherzustellen, dass E_DEPRECATED deaktiviert ist';
 $lang['test_edeprecated_failed'] = 'E_DEPRECATED ist aktiviert';
 $lang['info_edeprecated_failed'] = 'Wenn E_DEPRECATED in Ihren error_reporting Einstellungen aktiviert ist, werden eine ganze Reihe von Warnhinweisen angezeigt, die Auswirkungen auf die Anzeige und die Funktionalit&auml;ten haben k&ouml;nnen.';
@@ -90,7 +95,7 @@ $lang['install_admin_checksum'] = 'Ihre Installation pr&uuml;fen';
 $lang['upgrade_admin_checksum'] = 'Ihre System-Aktualisierung pr&uuml;fen';
 $lang['checksum'] = 'Pr&uuml;fsummen-Test';
 $lang['checksum_file'] = 'Pr&uuml;fsummen-Datei';
-$lang['install_test_checksum'] = 'Sie k&ouml;nnen die Integrit&auml;t Ihrer CMS-Dateien &uuml;ber einen Vergleich mit bekannte Pr&uuml;fsummen kontrollieren. Dies kann hilfreich sein, um Probleme beim Hochladen von Dateien ausfindig zu machen.';
+$lang['install_test_checksum'] = 'Sie k&ouml;nnen die Integrit&auml;t Ihrer CMSMS-Dateien &uuml;ber einen Vergleich mit den originalen CMSMS-Pr&uuml;fsummen kontrollieren. Dies kann hilfreich sein, um Probleme beim Hochladen von Dateien ausfindig zu machen.';
 $lang['checksum_passed'] = 'Alle Pr&uuml;fsummen stimmen &uuml;berein!';
 $lang['checksum_failed'] = 'Die Pr&uuml;fsumme stimmt mit einigen Fehlern &uuml;berein. F&uuml;r weitere Informationen schauen Sie in die Hilfe.';
 $lang['test_check_open_basedir'] = 'Pr&uuml;fung auf PHP Open Basedir';
@@ -132,13 +137,13 @@ $lang['php_information'] = 'PHP-Informationen';
 $lang['cms_install_information'] = 'Informationen zur CMSms-Installation';
 $lang['cms_version'] = 'CMS-Version';
 $lang['systeminfo_copy_paste'] = 'Klicken Sie hier, um diese Informationen f&uuml;r eine Anfrage im Forum zu kopieren.';
-$lang['help_systeminformation'] = 'Die hier angezeigten Informationen werden von verschiedenen Stellen Ihres Systems gesammelt und zusammengefasst angezeigt. Diese Informationen k&ouml;nnen hilfreich sein, wenn Sie versuchen, ein bestimmtes Problem zu diagnostizieren. Auch bei Fragen im CMSms-Forum k&ouml;nnen diese Informationen weiterhelfen, eine L&ouml;sung zu finden.';
+$lang['help_systeminformation'] = 'Die hier angezeigten Informationen werden von verschiedenen Stellen Ihres Systems gesammelt und zusammengefasst angezeigt. Diese Informationen k&ouml;nnen hilfreich sein, wenn Sie versuchen, ein bestimmtes Problem zu diagnostizieren. Auch bei Fragen in den CMSMS-Foren k&ouml;nnen diese Informationen weiterhelfen, eine L&ouml;sung zu finden.';
 $lang['systeminfo'] = 'System-Informationen';
-$lang['systeminfodescription'] = 'Zeigt bestimmte Informationen Ihres Systems an, die bei der Diagnostizierung von Problemen hilfreich sein k&ouml;nnen';
+$lang['systeminfodescription'] = 'Zeigt bestimmte Informationen Ihres Systems an, die bei der Diagnose von Problemen hilfreich sein k&ouml;nnen';
 $lang['error'] = 'Fehler';
 $lang['new_version_available'] = '<em>ACHTUNG:</em> Eine neue Version von CMS Made Simple ist verf&uuml;gbar. Bitte kontaktieren Sie Ihren Administrator/Webmaster schnellstm&ouml;glich f&uuml;r eine Aktualisierung.';
 $lang['info_urlcheckversion'] = 'Wird in diesem Feld &quot;none&quot; eingegeben, erfolgt keine &Uuml;berpr&uuml;fung.<br />Ohne Eintrag wird eine intern vorgegebene URL verwendet.';
-$lang['urlcheckversion'] = '&Uuml;ber diese URL auf neue CMSms-Versionen pr&uuml;fen';
+$lang['urlcheckversion'] = '&Uuml;ber diese URL auf neue CMSMS-Versionen pr&uuml;fen';
 $lang['read'] = 'Lesen';
 $lang['write'] = 'Schreiben';
 $lang['execute'] = 'Ausf&uuml;hren';
@@ -253,7 +258,7 @@ $lang['test_check_md5_func'] = 'Pr&uuml;fung auf MD5-Funktionen';
 $lang['test_check_safe_mode'] = 'Pr&uuml;fung auf die Verwendung des Safe-Modus';
 $lang['test_check_safe_mode_failed'] = 'Wenn der PHP-Safe-Modus verwendet wird, kann es beim Hochladen von Dateien und anderen Funktionen zu Problemen kommen. Dies ist davon abh&auml;ngig, wie streng die Einstellungen Ihres Servers bez&uuml;glich des Safe-Modus sind.';
 $lang['test_check_tokenizer'] = 'Pr&uuml;fung der Tokenizer-Funktionen';
-$lang['test_check_tokenizer_failed'] = 'Ohne den Tokenizer wird m&ouml;glicherweise nur eine wei&szlig;e Seite angezeigt. Dessen Installation ist f&uuml;r den Betrieb von CMsms zwingend erforderlich.';
+$lang['test_check_tokenizer_failed'] = 'Ohne den Tokenizer wird m&ouml;glicherweise nur eine wei&szlig;e Seite angezeigt. Dessen Installation ist f&uuml;r den Betrieb von CMSMS zwingend erforderlich.';
 $lang['test_check_gd'] = 'Pr&uuml;fung auf die GD-Library';
 $lang['test_check_gd_failed'] = 'Die GD-Library wird von einigen Modulen und Funktionalit&auml;ten ben&ouml;tigt.';
 $lang['test_check_write'] = 'Pr&uuml;fung auf aktivierte Schreibberechtigung';
@@ -261,7 +266,6 @@ $lang['test_may_not_exist'] = 'Diese Datei existiert m&ouml;glicherweise noch ni
 $lang['could_not_retrieve_a_value'] = 'Konnte keinen Wert abfragen ... Test &uuml;bersprungen';
 $lang['displaying_the_value_originally'] = '<br />Anzeige des Werts, der in der config-Datei gesetzt wurde.';
 $lang['test_check_xml_func'] = 'Pr&uuml;fung auf einfache XML (expat) Unterst&uuml;tzung';
-$lang['test_check_xml_failed'] = 'Die XML-Unterst&uuml;tzung wurde nicht in Ihre PHP-Installation kompiliert. Sie k&ouml;nnen das System verwenden, aber es ist nicht m&ouml;glich, Module &uuml;ber den ModulManager zu installieren.';
 $lang['test_allow_url_fopen_failed'] = 'Wenn die Funktion &quot;allow url fopen&quot; deaktiviert ist, k&ouml;nnen Sie nicht via FTP oder HTTP auf eine externe (auf einem anderen Server befindliche) Datei zuzugreifen.';
 $lang['test_remote_url'] = 'Test auf eine Remote-URL';
 $lang['test_remote_url_failed'] = 'Die Einstellungen Ihres Hosters erlauben nicht, eine Datei auf einem externen Webserver zu &ouml;ffnen. Aufgrund dessen erh&auml;lt Ihre CMSMS-Installation von cmsmadesimple.org keine Informationen &uuml;ber neue Versionen.';
@@ -269,13 +273,13 @@ $lang['connection_error'] = 'Auf Ihrem Host sind keine ausgehenden http-Verbindu
 $lang['remote_connection_timeout'] = 'Keine Verbindung wegen Zeit&uuml;berschreitung!';
 $lang['search_string_find'] = 'Verbindung ok!';
 $lang['connection_failed'] = 'Verbindung fehlgeschlagen!';
-$lang['remote_response_ok'] = 'Antwort des CMSms-Remote-Servers: ok!';
-$lang['remote_response_404'] = 'Antwort des CMSms-Remote-Servers: Versionsdatei nicht gefunden!';
-$lang['remote_response_error'] = 'Antwort des CMSms-Remote-Servers: Fehler!';
+$lang['remote_response_ok'] = 'Antwort des CMSMS-Remote-Servers: ok!';
+$lang['remote_response_404'] = 'Antwort des CMSMS-Remote-Servers: Versionsdatei nicht gefunden!';
+$lang['remote_response_error'] = 'Antwort des CMSMS-Remote-Servers: Fehler!';
 $lang['test_check_file_upload'] = 'Pr&uuml;fung der M&ouml;glichkeit zum Hochladen von Dateien';
 $lang['test_check_file_failed'] = 'Wenn diese Funktion deaktiviert ist, k&ouml;nnen Sie die in CMS Made Simple enthaltenen F&auml;higkeiten zum Hochladen von Dateien nicht nutzen. Falls m&ouml;glich sollte Ihr Systemadministrator diese Beschr&auml;nkung aufheben. Sie sollten jedoch wissen, was Sie tun.';
 $lang['test_check_memory'] = 'Pr&uuml;fung des PHP-Speicher-Limits';
-$lang['test_check_memory_failed'] = 'M&ouml;glicherweise wird CMSms mit dem Ihnen zur Verf&uuml;gung stehenden Speicher nicht richtig funktionieren. Falls m&ouml;glich sollten Sie Ihren Systemadministrator bitten, diesen Wert zu erh&ouml;hen. Sie sollten jedoch wissen, was Sie tun.';
+$lang['test_check_memory_failed'] = 'M&ouml;glicherweise wird CMSMS mit dem Ihnen zur Verf&uuml;gung stehenden Speicher nicht richtig funktionieren. Falls m&ouml;glich sollten Sie Ihren Systemadministrator bitten, diesen Wert zu erh&ouml;hen. Sie sollten jedoch wissen, was Sie tun.';
 $lang['test_check_time_limit'] = 'Pr&uuml;fung des PHP-Zeitlimits (Sekunden)';
 $lang['test_check_time_limit_failed'] = 'Zeitdauer in Sekunden, die ein PHP-Skript ben&ouml;tigen darf. Bei &Uuml;berschreitung dieses Wertes wird eine Fehlermeldung ausgegeben.';
 $lang['test_check_post_max'] = 'Pr&uuml;fung der maximalen Gr&ouml;&szlig;e f&uuml;r POST-Dateien';
@@ -329,7 +333,7 @@ $lang['install_admin_set_sitename'] = 'Der Seitenname wird gesetzt ... ';
 $lang['install_admin_setup'] = 'Nun geht&#039;s weiter mit den Einstellungen der Konfigurationsdatei, den gr&ouml;&szlig;ten Teil der Installation haben wir bereits hinter uns. F&uuml;r die Funktionsf&auml;higkeit des CMS k&ouml;nnen Sie alle Werte unver&auml;ndert lassen. Wenn Sie fertig sind, klicken Sie auf &quot;Weiter&quot;.';
 $lang['install_admin_docroot'] = 'CMS Dokumenten-Root (vom Webserver aus gesehen)';
 $lang['install_admin_docroot_path'] = 'Pfad zum Dokumenten-Root';
-$lang['install_admin_querystring'] = 'Abfrage-/Query-String (Wenn keine Probleme auftreten, k&ouml;nnen Sie den Wert unver&auml;ndert lassen. Die Datei config.php kann sp&auml;ter manuell anpasst werden.';
+$lang['install_admin_querystring'] = 'Abfrage-/Query-String (Wenn keine Probleme auftreten, k&ouml;nnen Sie den Wert unver&auml;ndert lassen. Die Datei config.php kann sp&auml;ter manuell anpasst werden.)';
 $lang['invalid_querys'] = '<strong>WARNUNG</strong>: Ung&uuml;ltige Abfragen auf Ihre Datenbank!';
 $lang['install_admin_sitedown'] = 'Fehler: Die Datei /tmp/cache/SITEDOWN konnte nicht entfernt werden. Bitte l&ouml;schen Sie diese manuell.';
 $lang['install_admin_update_hierarchy'] = 'Die Seitenhierarchie wird aktualisiert ... ';
@@ -349,8 +353,9 @@ Benutzername: %s
 Passwort: %s
 
 In die Administration Ihrer Seite gelangen Sie hier: %s';
-$lang['utma'] = '156861353.1543459933.1310675457.1310675457.1310675457.1';
-$lang['utmz'] = '156861353.1310675457.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['qca'] = 'P0-1458450664-1284573084918';
+$lang['utmz'] = '156861353.1338818723.1.1.utmcsr=(direct)|utmccn=(direct)|utmcmd=(none)';
+$lang['utma'] = '156861353.1673260288.1338818723.1338818723.1338822728.2';
 $lang['utmc'] = '156861353';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
