@@ -1,4 +1,12 @@
 <?php
+$lang['detected'] = 'Detectado';
+$lang['docroot_leaveblank'] = 'Dejar vac&iacute;o para usar el sistema por defecto';
+$lang['test_xmlreader_class'] = 'Revisando si la clase XMLReader existe';
+$lang['test_xmlreader_failed'] = 'La classe XMLReader no est&aacute; habilitada en su instalaci&oacute;n de PHP. Se puede usar el sistema pero las funciones de instalaci&oacute;n remota de m&oacute;dulos no estar&aacute;n disponibles.';
+$lang['test_check_xml_failed'] = 'El soporte de XML no se ha compilado en su instalaci&oacute;n de PHP. A&uacute;n as&iacute; puede utilizar el sistema, pero no podr&aacute; usar ninguna de las funciones remotas para instalar m&oacute;dulos.';
+$lang['installed_module'] = 'M&oacute;dulo instalado';
+$lang['automatedtask_success'] = 'Tarea automatizada completa';
+$lang['ip_addr'] = 'Direcci&oacute;n IP';
 $lang['install_admin_pwsalt_note'] = 'Si elige permitir sal en contrase&ntilde;as, no habr&aacute; ninguna forma de resetear las contrase&ntilde;as de administraci&oacute;n perdidas excepto a trav&eacute;s de la funcionalidad de contrase&ntilde;as perdidas. Es cr&iacute;tico que asocie una direcci&oacute;n de email con cada cuenta administrativa.';
 $lang['admin_salt'] = 'Sal en Contrase&ntilde;as de Administrador';
 $lang['setup_flat_urls'] = 'URLs simples han sido ajustadas';
@@ -256,7 +264,6 @@ $lang['test_may_not_exist'] = 'El archivo puede que no exista aun. Si es asi, de
 $lang['could_not_retrieve_a_value'] = 'No se pudo obtener un valor... se pasar&aacute; por alto.';
 $lang['displaying_the_value_originally'] = '<br />Mostrando el valor original de el archivo config (est&oacute; puede no ser atinado).';
 $lang['test_check_xml_func'] = 'Comprobando el soporte b&aacute;sico de XML (expat)';
-$lang['test_check_xml_failed'] = 'El soporte de XML no se ha compilado en su instalaci&oacute;n de PHP. A&uacute;n as&iacute; puede utilizar el sistema, pero no podr&aacute; usar ninguna de las funciones remotas para instalar m&oacute;dulos.';
 $lang['test_allow_url_fopen_failed'] = 'Cuando la opci&oacute;n de Permitir &#039;url fopen&#039; esta deshabilitada, no podr&aacute; acceder a objetos de URL como archivo utilizando los protocolos FTP o HTTP.';
 $lang['test_remote_url'] = 'Probar URL remota';
 $lang['test_remote_url_failed'] = 'Probablemente no podr&aacute; abrir un archivo en un servidor remoto.';
@@ -344,9 +351,8 @@ usuario: %s
 clave: %s
 
 Acceda al panel administrativo aqu&iacute;: %s';
-$lang['utma'] = '156861353.1929739349.1309160394.1309245890.1309249658.3';
-$lang['qca'] = 'P0-1077666827-1293014781745';
-$lang['utmz'] = '156861353.1309160366.1.1.utmcsr=google|utmccn=(organic)|utmcmd=organic|utmctr=cmsms vulnerability';
+$lang['utma'] = '156861353.1603343530.1339275764.1339275764.1339275764.1';
+$lang['utmz'] = '156861353.1339275764.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
 $lang['utmc'] = '156861353';
 $lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
