@@ -1,4 +1,9 @@
 <?php
+$lang['detected'] = 'D&eacute;tect&eacute;';
+$lang['docroot_leaveblank'] = 'Laissez ce champ vide pour utiliser le syst&egrave;me par d&eacute;faut';
+$lang['test_xmlreader_class'] = 'V&eacute;rification si la classe XMLReader existe';
+$lang['test_xmlreader_failed'] = 'La classe XMLReader n&#039;est pas activ&eacute;e dans votre installation de PHP. Vous pouvez toujours utiliser le syst&egrave;me, mais ne serez pas en mesure d&#039;utiliser les fonctions du Gestionnaire de Modules.';
+$lang['test_check_xml_failed'] = 'le support XML n&#039;est pas compil&eacute; dans votre installation PHP. Vous pouvez toujours utiliser le syst&egrave;me, mais ne serez pas en mesure d&#039;utiliser les fonctions du Gestionnaire de Modules.';
 $lang['installed_module'] = 'Module install&eacute;';
 $lang['automatedtask_success'] = 'T&acirc;che automatis&eacute;e r&eacute;alis&eacute;e';
 $lang['ip_addr'] = 'Adresse IP';
@@ -58,7 +63,7 @@ $lang['sitedown_not_removed'] = 'Impossible de supprimer le fichier tmp/cache/SI
 $lang['upgrade_ok'] = 'V&eacute;rifier le fichier config.php, modifier &eacute;ventuellement la configuration et remettre les permissions &agrave; 444 pour des raisons de s&eacute;curit&eacute;. Vous pouvez aussi v&eacute;rifier si vos modules sont &agrave; la derni&egrave;re version, en allant au menu Extensions -> Modules et regarder dans l&#039;onglet &quot;Mises &agrave; jour disponibles&quot;.';
 $lang['upgrade_complete'] = 'Mise &agrave; niveau termin&eacute;e';
 $lang['upgrade_end'] = 'CMSMS&trade; est &agrave; jour. Cliquez %s pour aller sur votre site ou aller sur %s.';
-$lang['here'] = 'ici';
+$lang['here'] = 'Ici';
 $lang['go_to_admin'] = 'Administration';
 $lang['errorfilenot'] = 'Fichier non trouv&eacute; !';
 $lang['errorfilenotwritable'] = 'Le fichier n&#039;a pas de permission en &eacute;criture';
@@ -199,12 +204,12 @@ $lang['username'] = 'Nom d&#039;utilisateur ';
 $lang['usernameincorrect'] = 'Nom d&#039;utilisateur ou mot de passe incorrect';
 $lang['version'] = 'Version&nbsp;';
 $lang['install_title'] = 'Installation de CMS Made Simple&trade; (&eacute;tape %s)';
-$lang['install_system'] = 'Installation du Syst&egrave;me';
+$lang['install_system'] = 'Installation du syst&egrave;me';
 $lang['install_thanks'] = 'Merci pour l&#039;installation de CMS Made Simple&trade;';
 $lang['upgrade_title'] = 'CMS Made Simple&trade; mise &agrave; niveau (&eacute;tape %s)';
 $lang['upgrade_system'] = 'Mise &agrave; niveau du syst&egrave;me';
 $lang['upgrade_thanks'] = 'Merci pour la mise &agrave; niveau de CMS Made Simple&trade; vers';
-$lang['install_please_read'] = 'Merci de lire <a rel="external" href="http://wiki.cmsmadesimple.org/index.php/User_Handbook/Installation/Troubleshooting/fr">R&eacute;solution de probl&egrave;mes durant l&#039;installation</a> du Wiki de CMS Made Simple&trade;.';
+$lang['install_please_read'] = 'Merci de lire <a rel="external" href="http://docs.cmsmadesimple.org/installation/requirements">Installation Troubleshooting</a> de la page &quot;Official Documentation&quot; de CMS Made Simple&trade;.';
 $lang['install_checking'] = 'V&eacute;rification des permissions et de la configuration PHP';
 $lang['install_test'] = 'Test&nbsp;';
 $lang['install_result'] = 'R&eacute;sultat';
@@ -259,7 +264,6 @@ $lang['test_may_not_exist'] = 'Ce fichier n&#039;existe peut-&ecirc;tre pas enco
 $lang['could_not_retrieve_a_value'] = 'Valeur non trouv&eacute;e... On passe...&nbsp;';
 $lang['displaying_the_value_originally'] = '<br />Affiche la valeur originelle contenue dans le fichier de configuration (Peut ne pas &ecirc;tre correct).';
 $lang['test_check_xml_func'] = 'V&eacute;rification du support basic XML (expat)';
-$lang['test_check_xml_failed'] = 'le support XML n&#039;est pas compil&eacute; dans votre installation PHP. Vous pouvez toujours utiliser le syst&egrave;me, mais ne serez pas en mesure d&#039;utiliser les fonctions du Gestionnaire de Modules.';
 $lang['test_allow_url_fopen_failed'] = 'Quand l&#039;autorisation &quot;url fopen&quot; est d&eacute;sactiv&eacute;e, vous ne serez pas en mesure d&#039;acc&eacute;der aux URL de fichiers en utilisant le protocole ftp ou http. ';
 $lang['test_remote_url'] = 'Test URL &agrave; distance';
 $lang['test_remote_url_failed'] = 'Vous ne serez probablement pas en mesure d&#039;ouvrir un fichier sur un serveur web distant.';
@@ -291,18 +295,18 @@ $lang['test_empty_session_save_path'] = 'Votre session.save_path est vide. PHP u
 $lang['test_check_session_save_path_failed'] = 'Votre session.save_path est &quot;%s&quot;. Le fait qu&#039;il ne soit pas inscriptible pourrait emp&ecirc;cher la connexion au panneau d&#039;administration. Vous devriez essayer de rendre ce chemin inscriptible si vous avez des probl&egrave;mes &agrave; vous connecter au panneau d&#039;administration. Ce test pourrait &eacute;chouer si safe_mode est activ&eacute; (voir plus bas).';
 $lang['test_check_ini_set'] = 'V&eacute;rification si ini_set fonctionne';
 $lang['test_check_ini_set_failed'] = 'Bien que la capacit&eacute; de passer outre les param&egrave;tres de php ini n&#039;est pas obligatoire, certaines fonctionnalit&eacute;s de module (facultatif) utilisent ini_set pour proroger des d&eacute;lais d&#039;expiration, et pour permettre le t&eacute;l&eacute;chargement de fichiers volumineux, etc. Vous pouvez avoir des difficult&eacute;s avec certaines fonctionnalit&eacute;s sans cette possibilit&eacute;. Ce test peut &eacute;chouer si le safe_mode est activ&eacute; (voir ci-dessous).';
-$lang['install_admin_header'] = 'Information sur le compte administrateur';
+$lang['install_admin_header'] = 'Informations sur le compte administrateur';
 $lang['install_admin_info'] = 'Choisissez le nom d&#039;utilisateur, le mot de passe et l&#039;adresse email pour votre compte d&#039;administration. Veuillez vous assurer que vous enregistrez ces donn&eacute;es &quot;quelque part&quot;, car elles sont indispensables pour l&#039;acc&egrave;s &agrave; votre syst&egrave;me d&#039;administration de CMS Made Simple.';
 $lang['install_admin_email'] = 'Adresse email';
 $lang['install_admin_email_info'] = 'Email pour le compte administrateur';
 $lang['install_admin_email_note'] = '<strong>Remarque :</strong> Cette notification utilise la fonction PHP Mail. Si vous ne recevez pas cet email, cela peut &ecirc;tre une indication de mauvaise configuration de votre serveur et vous devriez contacter votre h&eacute;bergeur.';
 $lang['install_admin_sitename'] = 'C&#039;est le nom de votre site Web. Il sera employ&eacute; dans divers endroits des gabarits par d&eacute;faut et peut &ecirc;tre employ&eacute; n&#039;importe o&ugrave; avec la Balise (Tag) {sitename}.';
 $lang['install_admin_db'] = 'Informations sur la base de donn&eacute;es';
-$lang['install_admin_db_info'] = '<p>Votre site sous CMS made simple&trade;n&eacute;cessite une base de donn&eacute;es pour fonctionner. Avant de poursuivre l&#039;installation, assurez-vous que votre base de donn&eacute;es a &eacute;t&eacute; cr&eacute;&eacute;e et qu&#039;un utilisateur disposant de tous les privil&egrave;ges sur cette base existe.</p>
+$lang['install_admin_db_info'] = '<p>Votre site sous CMS Made Simple&trade; n&eacute;cessite une base de donn&eacute;es pour fonctionner. Avant de poursuivre l&#039;installation, assurez-vous que votre base de donn&eacute;es a &eacute;t&eacute; cr&eacute;&eacute;e et qu&#039;un utilisateur disposant de tous les privil&egrave;ges sur cette base existe.</p>
 <p><strong>Vous pouvez utiliser un programme comme PhpMyAdmin ou le panneau d&#039;administration de votre h&eacute;bergement pour g&eacute;rer votre base de donn&eacute;es.</strong></p>
 <p><strong>Pour MySQL, vous pouvez aussi taper les commandes suivantes dans une console :</strong><br />
 - create database cms; 
-(utilisez le nom que vous voulez pour la base - ici &quot;cms&quot; -, sauf contrainte li&eacute;e &agrave; votre h&eacute;bergeur, mais retenez son nom exact car vous devrez le saisir sur cette page)<br />
+(utilisez le nom que vous voulez pour la base - ici &quot;cms&quot; -, sauf contrainte li&eacute;e &agrave; votre h&eacute;bergeur, et retenez son nom exact car vous devrez le saisir ci-dessous)<br />
 - grant all privileges on cms.* to cms_user@localhost identified by &#039;cms_pass&#039;;<br />
 </p>
 ';
@@ -348,4 +352,9 @@ Nom utilisateur : %s
 Mot de passe : %s
 
 Se connecter &agrave; l&#039;administration : %s';
+$lang['qca'] = 'P0-1532147203-1273233257739';
+$lang['utma'] = '156861353.2080384792.1340297872.1340297872.1340297872.1';
+$lang['utmc'] = '156861353';
+$lang['utmz'] = '156861353.1340297872.1.1.utmccn=(direct)|utmcsr=(direct)|utmcmd=(none)';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
