@@ -1,4 +1,10 @@
 <?php
+$lang['detected'] = 'Gedetecteerd';
+$lang['docroot_leaveblank'] = 'Laat dit veld leeg voor de systeemstandaard';
+$lang['test_xmlreader_class'] = 'Controle of de XMLReader class bestaat';
+$lang['test_xmlreader_failed'] = 'De XMLReader class is niet ingeschakeld in uw PHP-installatie. U kunt het systeem nog steeds gebruiken, maar u kunt geen gebruik maken van de functies om extern geplaatste modules te installeren.';
+$lang['test_check_xml_failed'] = 'XML ondersteuning is niet in de php installatie gecompileerd. Het systeem kan gebruikt worden, maar zal niet in staat zijn de module installatie functies &quot;op afstand&quot; van modulebeheer te gebruiken.
+';
 $lang['installed_module'] = 'Module ge&iuml;nstalleerd';
 $lang['automatedtask_success'] = 'Automatische taak succesvol uitgevoerd';
 $lang['ip_addr'] = 'IP-adres';
@@ -261,8 +267,6 @@ $lang['test_may_not_exist'] = 'Het is mogelijk dat dit bestand niet bestaat. Wan
 $lang['could_not_retrieve_a_value'] = 'Geen waarde opgehaald... verwerking gaat verder.';
 $lang['displaying_the_value_originally'] = '<br />Toont de originele waarde in het configuratie-bestand (deze hoeft niet actueel te zijn).';
 $lang['test_check_xml_func'] = 'Controle van elementaire XML (expat) ondersteuning';
-$lang['test_check_xml_failed'] = 'XML ondersteuning is niet in de php installatie gecompileerd. Het systeem kan gebruikt worden, maar zal niet in staat zijn de module installatie functies &quot;op afstand&quot; van modulebeheer te gebruiken.
-';
 $lang['test_allow_url_fopen_failed'] = 'Als url fopen uitgeschakeld is zal het niet lukken URL objecten zoals bestanden te open middels het ftp of http protocol.
 ';
 $lang['test_remote_url'] = 'Test van externe URL';
@@ -353,9 +357,9 @@ gebruikersnaam: %s
 wachtwoord: %s
 
 Log hier in op het beheerpaneel van de website: %s';
-$lang['qca'] = 'P0-1157065314-1313856308297';
-$lang['utma'] = '156861353.1223380647.1316373603.1316373603.1316373603.1';
+$lang['utma'] = '156861353.1289126069.1327844918.1334919334.1338234714.10';
+$lang['utmz'] = '156861353.1329944852.5.3.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/project/latest_files';
+$lang['qca'] = 'P0-856617467-1310370352588';
+$lang['utmb'] = '156861353';
 $lang['utmc'] = '156861353';
-$lang['utmz'] = '156861353.1316373603.1.1.utmcsr=dev.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/';
-$lang['utmb'] = '156861353.1.10.1316373603';
 ?>
\ No newline at end of file
