@@ -1,8 +1,46 @@
 <?php
-$lang['install_admin_locale'] = 'Locale to use for various default date handling functions, etc. Leaving this blank will use the server&#039;s default or in multilingual environment';
+$lang['detected'] = 'Detectado';
+$lang['docroot_leaveblank'] = 'Deixe em branco para usar a predefini&ccedil;&atilde;o do sistema';
+$lang['test_xmlreader_class'] = 'A verificar se a classe XMLReader existe';
+$lang['test_xmlreader_failed'] = 'A classe XmlReader n&atilde;o est&aacute; habilitada na sua instala&ccedil;&atilde;o de php. Pode utilizar o sistema, mas n&atilde;o ser&aacute; poss&iacute;vel usar nenhuma das fun&ccedil;&otilde;es de instala&ccedil;&atilde;o remota de m&oacute;dulos.';
+$lang['test_check_xml_failed'] = 'O suporte XML n&atilde;o foi compilado na sua instala&ccedil;&atilde;o de php. Pode utilizar o sistema, mas n&atilde;o ser&aacute; poss&iacute;vel usar nenhuma das fun&ccedil;&otilde;es de instala&ccedil;&atilde;o remota de m&oacute;dulos.';
+$lang['installed_module'] = 'M&oacute;dulo Instalado';
+$lang['automatedtask_success'] = 'Tarefa Automatizada Conclu&iacute;da Com Sucesso';
+$lang['ip_addr'] = 'Endere&ccedil;o IP';
+$lang['install_admin_pwsalt_note'] = 'If you choose to enable password salts, there is absolutely no way to reset lost admin passwords, other than through the lost password functionality.   It is critical that you associate an email address with each admin account';
+$lang['admin_salt'] = 'Salt Admin Passwords';
+$lang['setup_flat_urls'] = 'Flat URLs are setup';
+$lang['install_timezone'] = 'Some servers running PHP 5.3 do not have the timezone set correctly. Please select the appropriate timezone from the list below before proceeding. If this is not necessary on your server, you may select &quot;None&quot;. <strong>Note:</strong> Please select your servers timezone, this is not a display setting, but is used in arithmetic related to dates.  This setting can be changed after installation by modifying the config.php file.';
+$lang['timezone'] = 'Timezone';
+$lang['none'] = 'None';
+$lang['test_error_estrict'] = 'Testing error_reporting to ensure E_STRICT is disabled';
+$lang['test_estrict_failed'] = 'E_STRICT is enabled';
+$lang['info_estrict_failed'] = 'Some libraries that CMSMS uses do not work well with E_STRICT.  Please disable this before continuing';
+$lang['test_error_edeprecated'] = 'Testing error_reporting to ensure E_DEPRECATED is disabled';
+$lang['test_edeprecated_failed'] = 'E_DEPRECATED is enabled';
+$lang['info_edeprecated_failed'] = 'If E_DEPRECATED is enabled in your error reporting users will see a lot of warning messages that could effect the display and functionality';
+$lang['invalidemail'] = 'The email address entered is invalid';
+$lang['empty_query'] = 'Empty query?? %s';
+$lang['no_db_driver'] = 'No compatible database drivers found';
+$lang['test_check_output_buffering'] = 'Checking output buffering';
+$lang['test_check_output_buffering_failed'] = 'Output buffering is disabled. You will probably not be able to use any of functionality that requires this';
+$lang['phpinfo'] = 'Display PHP Information';
+$lang['mod_security'] = 'Apache Mod Security';
+$lang['test_check_tempnam'] = 'Checking for tempnam Function';
+$lang['test_check_db_drivers'] = 'DB drivers';
+$lang['test_check_db_drivers_failed'] = 'No DB drivers found';
+$lang['test_check_register_globals'] = 'Checking PHP register globals';
+$lang['test_check_register_globals_failed'] = 'PHP register globals is active. For security reasons, this should be disabled.';
+$lang['test_check_disable_functions'] = 'Checking PHP disable functions';
+$lang['test_check_disable_functions_failed'] = 'Warning: this is a list of functions disabled on your server.';
+$lang['install_admin_db_port'] = 'Database port';
+$lang['install_admin_db_port_info'] = 'If you don&#039;t know, leave this blank to use default settings.';
+$lang['install_admin_db_socket'] = 'Database socket';
+$lang['install_admin_db_socket_info'] = 'NOT SUPPORTED.';
+$lang['install_admin_frontendlang'] = 'Default language for the frontend. This adjusts the locale used for various default date handling functions, etc.';
 $lang['install_default_encoding'] = 'In almost all cases, default_encoding should be utf-8. If you&#039;d like this to be different, change this but keep in mind, however, that the languages translations are all in utf-8';
 $lang['installer_done'] = '[completo]';
-$lang['installer_failed'] = '[erro]';
+$lang['installer_failed'] = '[falhou]';
 $lang['create_permission'] = 'Criar permiss&otilde;es ...';
 $lang['add_column_sql'] = 'Adding column to %s table ...';
 $lang['update_table_sql'] = 'Actualizar tabela %s ...';
@@ -18,6 +56,7 @@ $lang['need_upgrade_schema'] = 'CMS is in need of an upgrade.<br />You are now r
 $lang['schema_ok'] = 'Now the CMS database is up to date using schema version %s';
 $lang['noneed_upgrade_schema'] = 'The CMS database is up to date using schema version %s';
 $lang['upgrade_modules'] = 'Upgrade modules';
+$lang['noneed_upgrade_modules'] = 'The core modules are up to date';
 $lang['upgrade_sql_module_from_to'] = 'Upgrading SQL of &quot;%s&quot; module from %s to %s ...';
 $lang['upgrade_event_module_from_to'] = 'Upgrading Events of &quot;%s&quot; module from %s to %s ...';
 $lang['sitedown_not_removed'] = 'Could not remove the tmp/cache/SITEDOWN file. Please remove manually or you will continue to show a &quot;Site Down for Maintainence&quot; message on your site';
@@ -26,6 +65,8 @@ $lang['upgrade_complete'] = 'Upgrade process complete';
 $lang['upgrade_end'] = 'CMS is up to date. Please click %s to go to your CMS site or you can %s.';
 $lang['here'] = 'aqui';
 $lang['go_to_admin'] = 'go to the Admin Panel';
+$lang['errorfilenot'] = 'File not found!';
+$lang['errorfilenotwritable'] = 'File not writable!';
 $lang['nofiles'] = 'This resource not exist!';
 $lang['is_directory'] = 'This resource is a directory!';
 $lang['is_readable_false'] = 'This resource is not readable!';
@@ -33,8 +74,18 @@ $lang['checksum_match'] = 'Checksum match!';
 $lang['checksum_not_match'] = 'Checksum not match!';
 $lang['not_checksum'] = 'No checksum retrieve!';
 $lang['format_datetime'] = '%c';
-$lang['no_checksum_file'] = 'No checksum file. Upload relative checksum file in install folder of CMS!';
-$lang['checksum_file_no_readable'] = 'Checksum file is not readable!';
+$lang['upload_err_ini_size'] = 'The uploaded file exceeds the upload_max_filesize directive in php.ini!';
+$lang['upload_err_form_size'] = 'The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form.';
+$lang['upload_err_partial'] = 'The uploaded file was only partially uploaded.';
+$lang['upload_err_no_file'] = 'No file was uploaded.';
+$lang['upload_err_no_tmp_dir'] = 'Missing a temporary folder.';
+$lang['upload_err_cant_write'] = 'Failed to write file to disk.';
+$lang['upload_err_extension'] = 'File upload stopped by extension.';
+$lang['upload_err_empty'] = 'File has size zero';
+$lang['upload_err_unknown'] = 'Unknown file upload problem.';
+$lang['function_file_uploads_off'] = 'file_uploads is off in your php configuration!';
+$lang['upload_file_no_readable'] = 'Uploaded file is not readable!';
+$lang['upload_file_multiple'] = 'Multiple file uploads are not allowed!';
 $lang['test_check_magic_quotes_gpc'] = 'Magic quotes for Get/Post/Cookie operations';
 $lang['test_check_magic_quotes_gpc_failed'] = 'When magic_quotes are on, all single-quote, double quote and backslash are escaped with a backslash automatically. You can to have problems in save templates.';
 $lang['test_check_magic_quotes_runtime'] = 'Magic quotes in runtime';
@@ -45,12 +96,12 @@ $lang['checksum'] = 'Checksum test';
 $lang['checksum_file'] = 'Checksum file';
 $lang['install_test_checksum'] = 'You can validate the integrity of your CMS files by comparing against original CMS checksum. It can assist in finding problems with uploads.';
 $lang['checksum_passed'] = 'All checksums match!';
+$lang['checksum_failed'] = 'Checksum match with errors. Look at the help for more information';
 $lang['test_check_open_basedir'] = 'Verificar PHP Open Basedir';
 $lang['test_check_open_basedir_failed'] = 'As restri&ccedil;&otilde;es Open basedir est&atilde;o activas. Pode ter algumas dificuldades em alguns addons com esta restri&ccedil;&atilde;o.';
 $lang['unlimited'] = 'Ilimitado';
-$lang['test_open_basedir_session_save_path'] = 'Open basedir &eacute; configura&ccedil;&atilde;o. Se tem problemas na SESSION ini_set  pode tentar activar cookies acrescentando:ini_set(&#039;session.use_only_cookies&#039;, 1);
-ao topo do include.php';
-$lang['install_warn_db_createtables'] = 'Normalmente, este campo deve ser seleccionado sempre. Tenha cuidado ao desactivar esse recurso';
+$lang['test_open_basedir_session_save_path'] = 'Restri&ccedil;&otilde;es de Open basedir est&atilde;o, aparentemente, em efeito. Se tem problemas de Sess&atilde;o (SESSION) e a configura&ccedil;&atilde;o ini_set funciona, pode tentar habilitar as sess&otilde;es com cookies adicionando: ini_set(&#039;session.use_only_cookies&#039;, 1); ao inicio do seu config.php.';
+$lang['install_warn_db_createtables'] = 'Normalmente, este campo deve estar sempre seleccionado. Tenha cuidado ao desactivar este recurso';
 $lang['install_admin_tablesnotcreated'] = 'Processo completo. O processo de instala&ccedil;&atilde;o est&aacute; conclu&iacute;do, com a sua auroriza&ccedil;&atilde;o os dados nas tabelas n&atilde;o foram criados. No entanto, o arquivo de configura&ccedil;&atilde;o foi recriado e todos os testes de pr&eacute;-instala&ccedil;&atilde;o foram aprovados. Muito obrigado, e aqui est&aacute; o seu';
 $lang['info_create_dir_and_file'] = 'O propriet&aacute;rio do Processo HTTP n&atilde;o pode criar um arquivo dentro de um direct&oacute;rio que &eacute; propriet&aacute;rio. Isso provavelmente significa que modo seguro est&aacute; activado, de alguma forma. Muitas fun&ccedil;&otilde;es dentro CMS  n&atilde;o ir&aacute; funcionar adequadamente sem essa capacidade. N&atilde;o &eacute; poss&iacute;vel continuar.';
 $lang['test_create_dir_and_file'] = 'Verificar se o processo httpd pode criar um arquivo dentro de um direct&oacute;rio criado.';
@@ -170,6 +221,7 @@ $lang['install_symbol'] = 'Simbolo';
 $lang['install_definition'] = 'Defini&ccedil;&atilde;o';
 $lang['install_value_passed'] = 'Um test obrigat&oacute;rio passou';
 $lang['install_value_failed'] = 'Um test obrigat&oacute;rio falhou';
+$lang['install_error_fragment'] = 'Info Installation Troubleshooting';
 $lang['install_value_required'] = 'A defini&ccedil;&atilde;o est&aacute; abaixo de um valor m&iacute;nimo exigido';
 $lang['install_value_recommended'] = 'A defini&ccedil;&atilde;o est&aacute; acima do valor exigido, mas abaixo do valor recomendado <br /> ou ... A capacidade que <em> deveria </em> ser exigida para algumas funcionalidade opcionais n&atilde;o est&atilde;o dispon&iacute;veis';
 $lang['install_value_exceed'] = 'A defini&ccedil;&atilde;o de atingir ou exceder o limite recomendado <br /> ou ... A capacidade que <em> deveria </ em> ser exigida para algumas funcionalidade opcionais est&atilde;o dispon&iacute;veis';
@@ -212,14 +264,13 @@ $lang['test_may_not_exist'] = 'Este arquivo pode ainda n&atilde;o existir. Caso
 $lang['could_not_retrieve_a_value'] = 'N&atilde;o foi poss&iacute;vel obter um valor .... passa de qualquer maneira.';
 $lang['displaying_the_value_originally'] = '<br />Verificando o valor inicialmente estabelecido no ficheiro de configura&ccedil;&atilde;o (isso pode n&atilde;o ser exacto).';
 $lang['test_check_xml_func'] = 'A verificar pelo XML b&aacute;sico (expat) suporte';
-$lang['test_check_xml_failed'] = 'O suporte XML n&atilde;o &eacute; compilado em seu php. Ainda pode utilizar o sistema, mas n&atilde;o ser&aacute; capaz de utilizar todas as possibilidades de instala&ccedil;&atilde;o remota de m&oacute;dulo e fun&ccedil;&otilde;es.';
 $lang['test_allow_url_fopen_failed'] = 'Quando a permiss&atilde;o do url fopen estiver desactivado n&atilde;o poder&aacute; aceder &agrave; URL objecto como o arquivo que usa o protocolo http ou ftp.';
 $lang['test_remote_url'] = 'Teste por URL remoto';
 $lang['test_remote_url_failed'] = 'Provavelmente n&atilde;o ser&aacute; capaz de abrir um arquivo remoto em um servidor web.';
 $lang['connection_error'] = 'Outgoing http connections do not appear to work! There is a firewall or some ACL for external connections?. This will result in module manager, and potentially other functionality failing.';
 $lang['remote_connection_timeout'] = 'Connection Timed Out!';
 $lang['search_string_find'] = 'Connection ok!';
-$lang['fopen_failed'] = 'fopen connection failed!';
+$lang['connection_failed'] = 'Connection failed!';
 $lang['remote_response_ok'] = 'Remote response: ok!';
 $lang['remote_response_404'] = 'Remote response: not found!';
 $lang['remote_response_error'] = 'Remote response: error!';
@@ -289,10 +340,9 @@ $lang['install_admin_install_modules'] = 'M&oacute;dulos Instalados...';
 $lang['install_admin_index_search'] = 'Indexar Pesquisa...';
 $lang['install_admin_clear_cache'] = 'Limpar o cache do site (se tiver algum cache)...';
 $lang['install_admin_emailing'] = 'E-mailing informa&ccedil;&atilde;o da conta de administra&ccedil;&atilde;o...';
-$lang['install_admin_congratulations'] = 'Parab&eacute;ns, configurou todo o sistema - visite o seu novo <a href="%s">CMS site</a>';
+$lang['install_admin_congratulations'] = 'Parab&eacute;ns, configurou todo o sistema - visite o seu novo ';
 $lang['could_not_connect_db'] = 'N&atilde;o foi poss&iacute;vel conectar ao banco de dados. Verifique se nome de usu&aacute;rio e senha est&atilde;o correctos, e que o usu&aacute;rio tenha acesso a um determinado banco de dados.';
 $lang['cannot_write_config'] = 'Erro:  N&atilde;o &eacute; poss&iacute;vel escrever em %s.';
-$lang['install_additional_modules'] = 'Instalar m&oacute;dulos adicionais';
 $lang['email_accountinfo_subject'] = 'CMS Made Simple informa&ccedil;&atilde;o da conta de administra&ccedil;&atilde;o';
 $lang['email_accountinfo_message'] = 'Obrigado por instalar o CMS.
 
@@ -301,8 +351,8 @@ Nome de Utilizador: %s
 Palavra Chave: %s
 
 Administra&ccedil;&atilde;o do site em: %s';
-$lang['utma'] = '156861353.327284758434971800.1219006470.1220095810.1220118543.40';
-$lang['utmz'] = '156861353.1220118543.40.9.utmcsr=forum.cmsmadesimple.org|utmccn=(referral)|utmcmd=referral|utmcct=/index.php/topic,25261.msg122769.html';
+$lang['utma'] = '156861353.762059600.1340221806.1340221806.1340221806.1';
+$lang['utmz'] = '156861353.1340221806.1.1.utmccn=(referral)|utmcsr=forum.cmsmadesimple.org|utmcct=/viewtopic.php|utmcmd=referral';
 $lang['utmc'] = '156861353';
-$lang['utmb'] = '156861353.3.10.1220118543';
+$lang['utmb'] = '156861353';
 ?>
\ No newline at end of file
