@@ -1,7 +1,7 @@
 <?php
 #CMS - CMS Made Simple
 #(c)2004 by Ted Kulp (wishy@users.sf.net)
-#This project's homepage is: http://cmsmadesimple.sf.net
+#This project's homepage is: http://www.cmsmadesimple.org
 #
 #This program is free software; you can redistribute it and/or modify
 #it under the terms of the GNU General Public License as published by
@@ -16,23 +16,13 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: CMSUpgradePage4.class.php 149 2009-03-17 22:22:13Z alby $
+#$Id: CMSUpgradePage4.class.php 296 2010-10-17 22:31:18Z calguy1000 $
 
 class CMSInstallerPage4 extends CMSInstallerPage
 {
-	/**
-	 * Class constructor
-	 * @var object $smarty
-	 * @var array  $errors
-	 * @var bool   $debug
-	 */
-	function CMSInstallerPage4(&$smarty, $errors, $debug)
-	{
-		$this->CMSInstallerPage(4, $smarty, $errors, $debug);
-	}
-
 	function assignVariables()
 	{
+	  $installer = $this->get_installer();
 		$result = true;
 		@clearstatcache();
 
