@@ -41,6 +41,7 @@ class ContentOperations
 {
 	protected function __construct() {}
 	private $_content_types;
+	private $_default_content_id;
 	private static $_instance;
 
 	public static function &get_instance()
@@ -104,19 +105,16 @@ class ContentOperations
 	 */
 	final public function LoadContentType($type)
 	{
-		if( is_object($type) && $type instanceof CmsContentTypePlaceHolder ) 
-			{
-				$type = $type->type;
-			}
+		if( is_object($type) && $type instanceof CmsContentTypePlaceHolder ) {
+			$type = $type->type;
+		}
 
 		$ctph = $this->_get_content_type($type);
-		if( is_object($ctph) )
-			{
-				if( !class_exists( $ctph->class ) && file_exists( $ctph->filename ) )
-					{
-						include_once( $ctph->filename );
-					}
+		if( is_object($ctph) ) {
+			if( !class_exists( $ctph->class ) && file_exists( $ctph->filename ) ) {
+				include_once( $ctph->filename );
 			}
+		}
 
 		return $ctph;
 	}
@@ -134,17 +132,15 @@ class ContentOperations
 	 */
 	public function &CreateNewContent($type)
 	{
-		if( is_object($type) && $type instanceof CmsContentTypePlaceHolder ) 
-			{
-				$type = $type->type;
-			}
+		if( is_object($type) && $type instanceof CmsContentTypePlaceHolder ) {
+			$type = $type->type;
+		}
 		$result = NULL;
 
 		$ctph = $this->LoadContentType($type);
-		if( class_exists($ctph->class) )
-			{
-				$result = new $ctph->class;
-			}
+		if( is_object($ctph) && class_exists($ctph->class) ) {
+			$result = new $ctph->class;
+		}
 		return $result;
 	}
 
@@ -252,11 +248,9 @@ class ContentOperations
 	 */
 	function GetDefaultContent()
 	{
+		if( $this->_default_content_id ) return $this->_default_content_id;
+
 		$gCms = cmsms();
-	  if( isset($gCms->variables['default_content_id']) )
-	    {
-	      return $gCms->variables['default_content_id'];
-	    }
 		$db = $gCms->GetDb();
 
 		$result = -1;
@@ -278,7 +272,7 @@ class ContentOperations
 			}
 		}
 
-		$gCms->variables['default_content_id'] = $result;
+		$this->_default_content_id = $result;
 		return $result;
 	}
 
@@ -545,7 +539,7 @@ class ContentOperations
 		if (file_exists($cachefilename))
 		{
 			$last_modified = cms_utils::get_app_data('last_content_modification');
-			if( !$last_modified );
+			if( $last_modified <= 0 );
 			{
 				$query = 'SELECT modified_date FROM '.cms_db_prefix().'content ORDER BY modified_date DESC';
 				$val = $db->GetOne($query);
@@ -605,6 +599,7 @@ class ContentOperations
 	 * @param integer $id The parent of the content objects to load into the tree
 	 * @param boolean $loadprops If true, load the properties of all loaded content objects
 	 * @param boolean $all If true, load all content objects, even inactive ones.
+	 * @param array   (optional) array of explicit content ids to load
 	 * @return void
 	 * @author Ted Kulp
 	 */
@@ -619,7 +614,8 @@ class ContentOperations
 			$expr = 'content_id IN ('.implode(',',$explicit_ids).')';
 			if( !$all ) $expr .= ' AND active = 1';
 
-			$query = 'SELECT * FROM '.cms_db_prefix().'content WHERE '.$expr.' ORDER BY hierarchy';
+			// note, this is mysql specific...
+			$query = 'SELECT * FROM '.cms_db_prefix().'content FORCE INDEX ('.cms_db_prefix().'index_content_by_idhier) WHERE '.$expr.' ORDER BY hierarchy';
 			$contentrows = $db->GetArray($query);
 		}
 		else 
@@ -762,14 +758,18 @@ class ContentOperations
 	 * @param boolean $ignore_current Ignores the value of $current totally by not marking any items as invalid.
 	 * @param boolean $allow_all If true, show all items, even if the content object 
 	 *                           doesn't have a valid link. Defaults to false.
-	 * @param boolean $use_name if true use Name() else use MenuText() Defaults to true.
+	 * @param boolean $use_name if true use Name() else use MenuText() Defaults to using the system preference.
 	 * @return string The html dropdown of the hierarchy
 	 */
-	function CreateHierarchyDropdown($current = '', $parent = '', $name = 'parent_id', $allowcurrent = 0, $use_perms = 0, $ignore_current = 0, $allow_all = false, $use_name = true)
+	function CreateHierarchyDropdown($current = '', $parent = '', $name = 'parent_id', $allowcurrent = 0, $use_perms = 0, $ignore_current = 0, $allow_all = false, $use_name = null)
 	{
 		$result = '';
 		$userid = -1;
 
+		if( is_null($use_name) ) {
+			$use_name = get_site_preference('listcontent_showtitle',true);
+		}
+
 		$allcontent = $this->GetAllContent(false);
 
 		if ($allcontent !== FALSE && count($allcontent) > 0)
@@ -1006,6 +1006,7 @@ class ContentOperations
 	 * Clears the content cache
 	 *
 	 * @ignore
+         * @internal
          * @access private
 	 * @return void
 	 */
