@@ -452,7 +452,7 @@ final class ModuleOperations
 										  1,$lazyload_fe,$lazyload_admin));
 
 		 $deps = $module_obj->GetDependencies();
-		 if( is_array($deps) )
+		 if( is_array($deps) && count($deps) )
 			 {
 				 $query = 'INSERT INTO '.cms_db_prefix().'module_deps
                            (parent_module,child_module,minimum_version,create_date,modified_date)
@@ -493,12 +493,29 @@ final class ModuleOperations
    */
   public function InstallModule($module, $loadifnecessary = false)
   {
-	  $modinstance = self::get_module_instance($module,'',TRUE);
+	  // get an instance of the object (force it).
+	  $modinstance = $this->get_module_instance($module,'',TRUE);
 	  if( !$modinstance )
 	  {
 		  return array(false,lang('errormodulenotloaded'));
       }
 
+	  // check for dependencies
+	  $deps = $modinstance->GetDependencies();
+	  if( is_array($deps) && count($deps) )
+	  {
+		  foreach( $deps as $mname => $mversion )
+		  {
+			  if( $mname == '' || $mversion == '' ) continue; // invalid entry.
+			  $newmod = $this->get_module_instance($mname);
+			  if( !is_object($newmod) || version_compare($newmod->GetVersion(),$mversion) < 0 )
+			  {
+				  return array(false,lang('missingdependency').': '.$mname);
+			  }
+		  }
+	  }
+
+	  // do the actual installation stuff.
 	  $res = $this->_install_module($modinstance);
 	  if( $res[0] == FALSE && $res[1] == '')
 	  {
@@ -511,7 +528,7 @@ final class ModuleOperations
   private function &_get_module_info()
   {
 	  if( !is_array($this->_moduleinfo) || count($this->_moduleinfo) == 0 )
-	  {
+	  {	  
 		  $query = 'SELECT * FROM '.cms_db_prefix().'modules ORDER BY module_name';
 		  $db = cmsms()->GetDb();
 		  $tmp = $db->GetArray($query);
@@ -572,6 +589,7 @@ final class ModuleOperations
 				  return FALSE;
 			  }
 
+		  debug_buffer('loading module '.$module_name);
 		  require_once($fname); 
 	  }
 
@@ -688,7 +706,7 @@ final class ModuleOperations
 
 	  if( (isset($info[$module_name]) && $info[$module_name]['status'] == 'installed') || $force_load )
 	  {
-		  $this->_modules[$module_name] = $obj;
+		  if( is_object($obj) ) $this->_modules[$module_name] = $obj;
 		  return TRUE;
 	  }
 
@@ -834,9 +852,12 @@ final class ModuleOperations
   /**
    * Upgrade a module
    *
+   * This is an internal method, subject to change in later releases.  It should never be called for upgrading arbitrary modules.
+   * Any use of this function by third party code will not be supported.  Use at your own risk and do not report bugs or issues
+   * related to your use of this module.
+   *
    * @param string $module The name of the module to upgrade
    * @return boolean Whether or not the upgrade was successful
-   * @internal
    */
   public function UpgradeModule( $module_name, $to_version = '')
   {
@@ -883,9 +904,15 @@ final class ModuleOperations
 					  $db->Execute('DELETE FROM '.cms_db_prefix().
 								   'events where originator=?',array($module));
 					  $db->Execute('DELETE FROM '.cms_db_prefix().
-								   "siteprefs where sitepref_name like '".
+								   'module_smarty_plugins where module=?',array($module));
+					  $db->Execute('DELETE FROM '.cms_db_prefix().
+								   "siteprefs WHERE sitepref_name LIKE '".
 								   str_replace("'",'',$db->qstr($module)).
 								   "_mapi_pref%'");
+					  $db->Execute('DELETE FROM '.cms_db_prefix().
+								   'routes WHERE dest = ?',array($module));
+					  $db->Execute('DELETE FROM '.cms_db_prefix().
+                                   'module_smarty_plugins WHERE module = ?',array($module));
 				  }
 
 			  // clear the cache.
