@@ -1,6 +1,6 @@
 <?php
 #CMS - CMS Made Simple
-#(c)2004-2010 by Ted Kulp (wishy@users.sf.net)
+#(c)2004-2012 by Ted Kulp (wishy@users.sf.net)
 #This project's homepage is: http://www.cmsmadesimple.org
 #
 #This program is free software; you can redistribute it and/or modify
@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: misc.functions.php 7440 2011-09-25 17:27:01Z calguy1000 $
+#$Id: misc.functions.php 8156 2012-07-06 04:37:25Z calguy1000 $
 
 /**
  * Misc functions
@@ -25,6 +25,7 @@
  */
 
 
+ 
 /**
  * Redirects to relative URL on the current site
  *
@@ -76,7 +77,7 @@ function redirect($to, $noappend=false)
     session_write_close();
 
     $debug = false;
-    if( class_exists('CmsObject') )
+    if( class_exists('CmsApp') )
       {
 	$config = cmsms()->GetConfig();
 	$debug = $config['debug'];
@@ -124,6 +125,7 @@ function redirect($to, $noappend=false)
 }
 
 
+
 /**
  * Given a page ID or an alias, redirect to it
  * Retrieves the URL of the specified page, and performs a redirect
@@ -133,20 +135,25 @@ function redirect($to, $noappend=false)
  */
 function redirect_to_alias($alias)
 {
-  $gCms = cmsms();
-	$manager = $gCms->GetHierarchyManager();
-	$node = $manager->sureGetNodeByAlias($alias);
-	$content = $node->GetContent();
-	if (isset($content))
-	{
-		if ($content->GetURL() != '')
-		{
-			redirect($content->GetURL());
-		}
-	}
+  $manager = cmsms()->GetHierarchyManager();
+  $node = $manager->sureGetNodeByAlias($alias);
+  if( !$node ) {
+	// put mention into the admin log
+    audit('','Core','Attempt to redirect to invalid alias: '.$alias);
+    return;
+  }
+  $content = $node->GetContent();
+  if (!is_object($content)) {
+    audit('','Core','Attempt to redirect to invalid alias: '.$alias);
+    return;
+  }
+  if ($content->GetURL() != '') {
+    redirect($content->GetURL());
+  }
 }
 
 
+
 /**
  * Calculate the difference in seconds between two microtime() values
  *
@@ -162,6 +169,7 @@ function microtime_diff($a, $b) {
 }
 
 
+
 /**
  * Joins a path together using proper directory separators
  * Taken from: http://www.php.net/manual/en/ref.dir.php
@@ -174,23 +182,24 @@ function microtime_diff($a, $b) {
 function cms_join_path()
 {
 	$args = func_get_args();
-	return implode(DIRECTORY_SEPARATOR,$args);
+        return implode(DIRECTORY_SEPARATOR,$args);
 }
 
 
+
 /**
- * Return the global gCms object
+ * Return the global cmsms() object
  *
  * @since 1.7
  * @return object
  */
 function &cmsms()
 {
-  if( class_exists('CmsObject') )
-    return CmsObject::get_instance();
+   return CmsApp::get_instance();
 }
 
 
+
 /**
  * Shows a very close approximation of an Apache generated 404 error.
  *
@@ -201,11 +210,10 @@ function &cmsms()
  * @since 0.3
  * @deprecated
  * @internal
+ * Rolf: function used in /index.php
  */
-#function ErrorHandler404($errno, $errmsg, $filename, $linenum, $vars)
 function ErrorHandler404()
 {
-	#if ($errno == E_USER_WARNING) {
 		@ob_end_clean();
 		header("HTTP/1.0 404 Not Found");
 		header("Status: 404 Not Found");
@@ -217,54 +225,8 @@ function ErrorHandler404()
 <p>The requested URL was not found on this server.</p>
 </body></html>';
 		exit();
-	#}
 }
 
-/**
- * Simple template parser
- *
- * @since 0.6.1
-
-	function parse_template ($template, $tpl_array, $warn=0)
-	{
-		while ( list ($key,$val) = each ($tpl_array) )
-		{
-			if (!(empty($key)))
-			{
-				if(gettype($val) != "string")
-				{
-					settype($val,"string");
-				}
-				$template = eregi_replace('\{' . $key . '\}',$val,$template);
-			}
-		}
-
-		if(!$warn)
-		{
-			// Silently remove anything not already found
-
-			$template = ereg_replace('\{[A-Z0-9_]+\}', "", $template);
-		}
-		else
-		{
-			// Warn about unresolved template variables
-			if (ereg('\{[A-Z0-9_]+\}',$template))
-			{
-				$unknown = split("\n",$template);
-				while (list ($Element,$Line) = each($unknown) )
-				{
-					$UnkVar = $Line;
-					if(!(empty($UnkVar)))
-					{
-						$this->show_unknowns($UnkVar);
-					}
-				}
-			}
-		}
-		return $template;
-
-	}	// end parse_template();
- */
 
 
 /**
@@ -277,20 +239,40 @@ function ErrorHandler404()
  * @param boolean A flag indicating wether single quotes should be converted to entities.
  * @return string the converted string.
  */
-function cms_htmlentities($string, $param=ENT_QUOTES, $charset="UTF-8", $convert_single_quotes = false)
+function cms_htmlentities($val, $param=ENT_QUOTES, $charset="UTF-8", $convert_single_quotes = false)
 {
-	$result = "";
-	#$result = htmlentities($string, $param, $charset);
-	$result = my_htmlentities($string, $convert_single_quotes);
-	return $result;
+  if ($val == "") return "";
+
+  $val = str_replace( "&#032;", " ", $val );
+  $val = str_replace( "&"            , "&amp;"         , $val );
+  $val = str_replace( "<!--"         , "&#60;&#33;--"  , $val );
+  $val = str_replace( "-->"          , "--&#62;"       , $val );
+  $val = preg_replace( "/<script/i"  , "&#60;script"   , $val );
+  $val = str_replace( ">"            , "&gt;"          , $val );
+  $val = str_replace( "<"            , "&lt;"          , $val );
+  $val = str_replace( "\""           , "&quot;"        , $val );
+  $val = preg_replace( "/\\$/"      , "&#036;"        , $val );
+  $val = str_replace( "!"            , "&#33;"         , $val );
+  $val = str_replace( "'"            , "&#39;"         , $val );
+
+  if ($convert_single_quotes)
+    {
+      $val = str_replace("\\'", "&apos;", $val);
+      $val = str_replace("'", "&apos;", $val);
+    }
+
+  return $val;
 }
 
 
+
 /**
  * @ignore
  */
 define('CLEANED_FILENAME','BAD_FILE');
 
+
+
 /**
  * Clean up the filename, and ensure that the filename resides underneath
  * the cms_root directory, if it does not replace it with the hardcoded
@@ -299,6 +281,7 @@ define('CLEANED_FILENAME','BAD_FILE');
  * @internal
  * @param string The complete file specification
  * @return string the cleaned file path.
+ * Rolf: only used in this file
  */
 function cms_cleanfile($filename)
 {
@@ -316,108 +299,25 @@ function cms_cleanfile($filename)
 	return $realpath;
 }
 
-/**
- * Figures out the page name from the uri string.  Has to use different logic
- * based on the type of httpd server.
- *
- * @ignore
- * @access private
- * @return string
- */
-function cms_calculate_url()
-{
-	$result = '';
 
-	$config = cmsms()->GetConfig();
 
-	//apache and lighttpd
-	if (isset($_SERVER["REQUEST_URI"]) && !endswith($_SERVER['REQUEST_URI'], 'index.php'))
-	{
-		$matches = array();
-		if (preg_match('/.*index\.php\/(.*?)$/', $_SERVER['REQUEST_URI'], $matches))
-		{
-			$result = $matches[1];
-		}/*
-		else
-		{
-			$result = $_SERVER['PHP_SELF'];
-		}*/
-	}
-
-	//trim off the extension, if there is one set
-	if ($config['page_extension'] != '' && endswith($result, $config['page_extension']))
-	{
-		$result = substr($result, 0, strlen($result) - strlen($config['page_extension']));
-	}
-
-	return $result;
-
-}
 
 /**
  * A replacement for the built in htmlentities method.
  *
  * @ignore
+ * @deprecated
  * @param string  input string
  * @param boolean A flag wether or not to handle single quotes.
- * @return unknown
+ * @return string
  */
 function my_htmlentities($val, $convert_single_quotes = false)
 {
-	if ($val == "")
-	{
-		return "";
-	}
-	$val = str_replace( "&#032;", " ", $val );
-
-	//Remove sneaky spaces
-	// $val = str_replace( chr(0xCA), "", $val );
-
-	$val = str_replace( "&"            , "&amp;"         , $val );
-	$val = str_replace( "<!--"         , "&#60;&#33;--"  , $val );
-	$val = str_replace( "-->"          , "--&#62;"       , $val );
-	$val = preg_replace( "/<script/i"  , "&#60;script"   , $val );
-	$val = str_replace( ">"            , "&gt;"          , $val );
-	$val = str_replace( "<"            , "&lt;"          , $val );
-
-
-	$val = str_replace( "\""           , "&quot;"        , $val );
-
-	// Uncomment it if you need to convert literal newlines
-	//$val = preg_replace( "/\n/"        , "<br>"          , $val );
-
-	$val = preg_replace( "/\\$/"      , "&#036;"        , $val );
-
-	// Uncomment it if you need to remove literal carriage returns
-	//$val = preg_replace( "/\r/"        , ""              , $val );
-
-	$val = str_replace( "!"            , "&#33;"         , $val );
-	$val = str_replace( "'"            , "&#39;"         , $val );
-
-	// Uncomment if you need to convert unicode chars
-	//$val = preg_replace("/&#([0-9]+);/s", "&#\1;", $val );
-
-	// Strip slashes if not already done so.
-
-	//if ( get_magic_quotes_gpc() )
-	//{
-	//	$val = stripslashes($val);
-	//}
-
-	if ($convert_single_quotes)
-	{
-		$val = str_replace("\\'", "&apos;", $val);
-		$val = str_replace("'", "&apos;", $val);
-	}
-
-	// Swop user inputted backslashes
-
-	//$val = preg_replace( "/\(?!&#|?#)/", "&#092;", $val );
-
-	return $val;
+  return cms_htmlentities($val,ENT_QUOTES,'UTF-8',$confvert_single_quotes);
 }
 
 
+
 /**
  * A method to convert a string into UTF-8 entities
  *
@@ -425,6 +325,7 @@ function my_htmlentities($val, $convert_single_quotes = false)
  * @deprecated
  * @param string Input string
  * @return string
+ * Rolf: used in admin/listmodules.php
  */
 function cms_utf8entities($val)
 {
@@ -433,103 +334,64 @@ function cms_utf8entities($val)
 		return "";
 	}
 	$val = str_replace( "&#032;", " ", $val );
-
-	//Remove sneaky spaces
-	// $val = str_replace( chr(0xCA), "", $val );
-
 	$val = str_replace( "&"            , "\u0026"         , $val );
 	$val = str_replace( ">"            , "\u003E"          , $val );
 	$val = str_replace( "<"            , "\u003C"          , $val );
 
 
 	$val = str_replace( "\""           , "\u0022"        , $val );
-
-	// Uncomment it if you need to convert literal newlines
-	//$val = preg_replace( "/\n/"        , "<br>"          , $val );
-
-	#$val = preg_replace( "/\\$/"      , "&#036;"        , $val );
-
-	// Uncomment it if you need to remove literal carriage returns
-	//$val = preg_replace( "/\r/"        , ""              , $val );
-
 	$val = str_replace( "!"            , "\u0021"         , $val );
 	$val = str_replace( "'"            , "\u0027"         , $val );
 
-	// Uncomment if you need to convert unicode chars
-	//$val = preg_replace("/&#([0-9]+);/s", "&#\1;", $val );
-
-	// Strip slashes if not already done so.
-
-	//if ( get_magic_quotes_gpc() )
-	//{
-	//	$val = stripslashes($val);
-	//}
-
-	// Swop user inputted backslashes
-
-	//$val = preg_replace( "/\(?!&#|?#)/", "&#092;", $val );
-
 	return $val;
 }
 
 
-//Taken from http://www.webmasterworld.com/forum88/164.htm
-/*
-function nl2pnbr( $text )
-{
-	// Use \n for newline on all systems
-	$text = preg_replace("/(\r\n|\n|\r)/", "\n", $text);
-
-	// Only allow two newlines in a row.
-	$text = preg_replace("/\n\n+/", "\n\n", $text);
-
-	// Put <p>..</p> around paragraphs
-	$text = preg_replace('/\n?(.+?)(\n\n|\z)/s', "<p>$1</p>", $text);
-
-	// Convert newlines not preceded by </p> to a <br /> tag
-	$text = preg_replace('|(?<!</p>)\s*\n|', "<br />", $text);
-
-	return $text;
-}*/
-
 
 /**
  * A function to put a backtrace into the generated log file.
  * 
  * @see debug_to_log, debug_bt
  * @return void
+ * Rolf: Looks like not used
  */
 function debug_bt_to_log()
 {
-    $bt=debug_backtrace();
-    $file = $bt[0]['file'];
-    $line = $bt[0]['line'];
-
-    $out = array();
-    $out[] = "Backtrace in $file on line $line";
-
-    $bt = array_reverse($bt);
-    foreach($bt as $trace)
+  if( cmsms()->config['debug_to_log'] || check_login(TRUE) )
     {
-      if( $trace['function'] == 'debug_bt_to_log' ) continue;
+      $bt=debug_backtrace();
+      $file = $bt[0]['file'];
+      $line = $bt[0]['line'];
 
-      $file = $trace['file'];
-      $line = $trace['line'];
-      $function = $trace['function'];
-      $out[] = "$function at $file:$line"; 
+      $out = array();
+      $out[] = "Backtrace in $file on line $line";
+
+      $bt = array_reverse($bt);
+      foreach($bt as $trace)
+	{
+	  if( $trace['function'] == 'debug_bt_to_log' ) continue;
+
+	  $file = $trace['file'];
+	  $line = $trace['line'];
+	  $function = $trace['function'];
+	  $out[] = "$function at $file:$line"; 
+	}
+
+      $filename = TMP_CACHE_LOCATION . '/debug.log';
+      foreach ($out as $txt)
+	{
+	  error_log($txt . "\n", 3, $filename);
+	}
     }
-
-    $filename = TMP_CACHE_LOCATION . '/debug.log';
-    foreach ($out as $txt)
-      {
-	error_log($txt . "\n", 3, $filename);
-      }
 }
 
+
+
 /**
  * A function to generate a backtrace in a readable format.
  *
  * @return void
+ * Rolf: looks like not used
  */
 function debug_bt()
 {
@@ -555,6 +417,8 @@ function debug_bt()
     echo "</dl></pre>\n";
 }
 
+
+
 /**
 * Debug function to display $var nicely in html.
 *
@@ -565,8 +429,7 @@ function debug_bt()
 */
 function debug_display($var, $title="", $echo_to_screen = true, $use_html = true)
 {
-  $gCms = cmsms();
-	$variables =& $gCms->variables;
+	$variables =& cmsms()->variables;
 
 	$starttime = microtime();
 	if (isset($variables['starttime']))
@@ -655,6 +518,8 @@ function debug_display($var, $title="", $echo_to_screen = true, $use_html = true
 	return $output;
 }
 
+
+
 /**
  * Display $var nicely only if $config["debug"] is set
  *
@@ -671,6 +536,7 @@ function debug_output($var, $title="")
 }
 
 
+
 /**
  * Debug function to output debug information about a variable in a formatted matter
  * to a debug file.
@@ -695,8 +561,9 @@ function debug_to_log($var, $title='',$filename = '')
 }
 
 
+
 /**
- * Display $var nicely to the $gCms->errors array if $config['debug'] is set
+ * Display $var nicely to the cmsms()->errors array if $config['debug'] is set
  *
  * @param mixed $var
  * @param string $title
@@ -711,12 +578,14 @@ function debug_buffer($var, $title="")
 }
 
 
+
 /**
  * Debug an sql command
  *
  * @internal
  * @param string SQL query
  * @param boolean (unused)
+ * Rolf: only used in lib/adodb.functions.php
  */
 function debug_sql($str, $newline = false)
 {
@@ -727,6 +596,8 @@ function debug_sql($str, $newline = false)
     }
 }
 
+
+
 /**
 * Retrieve value from $_REQUEST. Returns $default_value if
 *		value is not in $_REQUEST or is not the same basic type as
@@ -739,6 +610,7 @@ function debug_sql($str, $newline = false)
 * @param string $session_key (optional)
 * @deprecated
 * @return mixed
+* Rolf: looks like not used
 */
 function get_request_value($value, $default_value = '', $session_key = '')
 {
@@ -766,6 +638,8 @@ function get_request_value($value, $default_value = '', $session_key = '')
 	return $result;
 }
 
+
+
 /**
 * Return $value if it's set and same basic type as $default_value,
 *			otherwise return $default_value. Note. Also will trim($value)
@@ -775,6 +649,7 @@ function get_request_value($value, $default_value = '', $session_key = '')
 * @param mixed $default_value
 * @deprecated
 * @return mixed
+* Rolf: only used in this file
 */
 function get_value_with_default($value, $default_value = '', $session_key = '')
 {
@@ -825,6 +700,7 @@ function get_value_with_default($value, $default_value = '', $session_key = '')
 }
 
 
+
 /**
  * Retrieve the $value from the $parameters array checking for
  * $parameters[$value] and $params[$id.$value]. Returns $default
@@ -836,6 +712,7 @@ function get_value_with_default($value, $default_value = '', $session_key = '')
  * @param mixed $default_value
  * @param string $session_key
  * @return mixed
+ * Rolf: looks like not used
  */
 function get_parameter_value($parameters, $value, $default_value = '', $session_key = '')
 {
@@ -907,6 +784,8 @@ function get_parameter_value($parameters, $value, $default_value = '', $session_
 	return $return_value;
 }
 
+
+
 /**
  * A convenience function to create a dropdown control with supported encodings.
  *
@@ -914,6 +793,7 @@ function get_parameter_value($parameters, $value, $default_value = '', $session_
  * @param string A name for the control
  * @param string The name of the option that should be selected.
  * @return string
+ * Rolf: only used in admin/edittemplate.php
  */
 function create_encoding_dropdown($name = 'encoding', $selected = '')
 {
@@ -937,6 +817,7 @@ function create_encoding_dropdown($name = 'encoding', $selected = '')
 }
 
 
+
 /**
  * A method to remove a permission from the database.
  *
@@ -964,6 +845,7 @@ function cms_mapi_remove_permission($permission_name)
 }
 
 
+
 /**
  * A method to add a permission to the CMSMS permissions table
  *
@@ -996,6 +878,7 @@ function cms_mapi_create_permission($cms, $permission_name, $permission_text)
 }
 
 
+
 /**
  * A function to test if a file specification matches an array of
  * file specifications that indicate it should be excluded
@@ -1006,6 +889,7 @@ function cms_mapi_create_permission($cms, $permission_name, $permission_text)
  * @param string Flle specification
  * @param array  Array of regular expressions.
  * @return boolean
+ * Rolf: only used in this file
  */
 function filespec_is_excluded( $file, $excludes )
 {
@@ -1022,6 +906,7 @@ function filespec_is_excluded( $file, $excludes )
 }
 
 
+
 /**
  * Check the permissions of a directory recursively to make sure that
  * we have write permission to all files
@@ -1073,6 +958,7 @@ function is_directory_writable( $path )
 }
 
 
+
 /**
  * Return an array containing a list of files in a directory
  * performs a non recursive search
@@ -1081,11 +967,10 @@ function is_directory_writable( $path )
  * @param path - path to search
  * @param extensions - include only files matching these extensions
  *                     case insensitive, comma delimited
+ * Rolf: only used in this file
  */
-function get_matching_files($dir,$extensions = '',$excludedot = true,$excludedir = true,
-			    $fileprefix='',$excludefiles=1)
+function get_matching_files($dir,$extensions = '',$excludedot = true,$excludedir = true, $fileprefix='',$excludefiles=1)
 {
-
   $dh = @opendir($dir);
   if( !$dh ) return false;
 
@@ -1116,6 +1001,7 @@ function get_matching_files($dir,$extensions = '',$excludedot = true,$excludedir
 }
 
 
+
 /**
  * Return an array containing a list of files in a directory
  * performs a recursive search
@@ -1155,6 +1041,7 @@ function get_recursive_file_list ( $path , $excludes, $maxdepth = -1 , $mode = "
 }
 
 
+
 /**
  * A function to recursively delete all files and folders in a directory
  * synonymous with rm -r
@@ -1193,12 +1080,14 @@ function recursive_delete( $dirname )
 }
 
 
+
 /**
  * A function to recursively chmod all files and folders in a directory
  *
  * @see chmod
  * @param string The start location
  * @param integer The mode
+ * Rolf: only used in admin/listmodules.php
  */
 function chmod_r( $path, $mode )
 {
@@ -1234,6 +1123,8 @@ function chmod_r( $path, $mode )
   return @chmod( $path, $mode );
 }
 
+
+
 /**
  * A method to serialize an object and encode it for storage or transport.
  *
@@ -1246,12 +1137,15 @@ function SerializeObject(&$object)
 	return base64_encode(serialize($object));
 }
 
+
+
 /**
  * A function unserialize data into an object
  *
  * @internal
  * @param string The serialized text.
  * @return object  A valid object on success, or null
+ * Rolf: only used in admin/editcontent_extra.php
  */
 function UnserializeObject(&$serialized)
 {
@@ -1259,6 +1153,7 @@ function UnserializeObject(&$serialized)
 }
 
 
+
 /**
  * A convenience function to test wether one string starts with another
  *
@@ -1273,6 +1168,8 @@ function startswith( $str, $sub )
 	return ( substr( $str, 0, strlen( $sub ) ) == $sub );
 }
 
+
+
 /**
  * Similar to the startswith method, this function tests with string A ends with string B
  *
@@ -1287,17 +1184,6 @@ function endswith( $str, $sub )
 	return ( substr( $str, strlen( $str ) - strlen( $sub ) ) == $sub );
 }
 
-/**
- * A convenience function to display the memory usage
- *
- * @internal
- * @param string A prefix to display before the memory output
- * @return void
- */
-function showmem($string = '')
-{
-	var_dump($string . ' -- ' . memory_get_usage());
-}
 
 
 /**
@@ -1328,41 +1214,23 @@ function munge_string_to_url($alias, $tolower = false, $withslash = false)
 	    $expr = '/[^a-z0-9-_\/]+/i';
 	  }
 	$alias = preg_replace($expr,'-',$alias);
-	//$alias = preg_replace("/[^\w-]+/", "-", $alias);
+
+	for( $i = 0; $i < 5; $i++ )
+	  {
+	    $tmp = str_replace('--','-',$alias);
+	    if( $tmp == $alias ) break;
+	    $alias = $tmp;
+	  }
 	$alias = trim($alias, '-');
+	$alias = trim($alias);
 
 	return $alias;
 }
 
-// I'm not gonna document these.
-if (!function_exists('file_put_contents')) {
-    function file_put_contents($filename, $data) {
-        $f = @fopen($filename, 'w');
-        if (!$f) {
-            return false;
-        } else {
-            $bytes = fwrite($f, $data);
-            fclose($f);
-            return $bytes;
-        }
-    }
-}
-
-if(!function_exists("file_get_contents"))
-{
-   function file_get_contents($filename)
-   {
-	   if(($contents = file($filename)))
-	   {
-		   $contents = implode('', $contents);
-		   return $contents;
-	   }
-	   else
-		   return false;
-   }
-}
-
 
+/**
+ * Rolf: only used in admin/style.php
+ */
 function cms_readfile($filename)
 {
   @ob_start();
@@ -1377,57 +1245,6 @@ function cms_readfile($filename)
 }
 
 
-// create the array_walk_recursive function in PHP4
-// from http://www.php.net/manual/en/function.array-walk-recursive.php
-if (!function_exists('array_walk_recursive'))
-{
-   function array_walk_recursive(&$input, $funcname, $userdata = "")
-   {
-       if (!is_callable($funcname))
-       {
-           return false;
-       }
-
-       if (!is_array($input))
-       {
-           return false;
-       }
-
-       foreach ($input AS $key => $value)
-       {
-           if (is_array($input[$key]))
-           {
-               array_walk_recursive($input[$key], $funcname, $userdata);
-           }
-           else
-           {
-               $saved_value = $value;
-               if (!empty($userdata))
-               {
-                   $funcname($value, $key, $userdata);
-               }
-               else
-               {
-                   $funcname($value, $key);
-               }
-
-               if ($value != $saved_value)
-               {
-                   $input[$key] = $value;
-               }
-           }
-       }
-       return true;
-	}
-}
-
-if (!function_exists("stripos")) {
-  function stripos($str,$needle,$offset=0)
-  {
-      return strpos(strtolower($str),strtolower($needle),$offset);
-  }
-}
-
 /*
  * Sanitize input to prevent against XSS and other nasty stuff.
  * Taken from cakephp (http://cakephp.org)
@@ -1461,6 +1278,8 @@ function cleanValue($val) {
 	return $val;
 }
 
+
+
 /*
  * Method to sanitize incoming html.
  * Take from cakephp (http://cakephp.org)
@@ -1469,6 +1288,7 @@ function cleanValue($val) {
  * @param string Input HTML code.
  * @param boolean Wether HTML tags should be removed.
  * @return string
+ * Rolf: only used in this file
  */
 function cleanHtml($string, $remove = false) {
 	if ($remove) {
@@ -1481,7 +1301,6 @@ function cleanHtml($string, $remove = false) {
 	return $string;
 }
 
-
 define('CLEAN_INT','CLEAN_INT');
 define('CLEAN_FLOAT','CLEAN_FLOAT');
 define('CLEAN_NONE','CLEAN_NONE');
@@ -1489,6 +1308,8 @@ define('CLEAN_STRING','CLEAN_STRING');
 define('CLEAN_REGEXP','regexp:');
 define('CLEAN_FILE','CLEAN_FILE');
 
+
+
 /**
  * Method to sanitize all entries in a hash
  * This method is called by the module api to clean incomming parameters in the frontend.
@@ -1500,6 +1321,7 @@ define('CLEAN_FILE','CLEAN_FILE');
  * @param array  A map of param names and type information
  * @param boolean A flag indicating wether unknown keys in the input data should be allowed.
  * @param boolean A flag indicating wether keys should be treated as strings and cleaned.
+ * Rolf: only used in lib/classes/class.CMSModule.php
 */
 function cleanParamHash($modulename,$data,$map = false,
 			$allow_unknown = false,$clean_keys = true)
@@ -1596,6 +1418,7 @@ function cleanParamHash($modulename,$data,$map = false,
 }
 
 
+
 /**
  * Returns all parameters sent that are destined for the module with
  * the given $id.  This method reads the parameters directly from the $_REQUEST
@@ -1628,57 +1451,6 @@ function GetModuleParameters($id)
 }
 
 
-/**
- * A function to test if permissions are set correctly, and the server is set properly
- * to allow users to upload to CMSMS.
- *
- * @internal
- * @return boolean
- */
-function can_users_upload()
-{
-  # first, check to see if safe mode is enabled
-  # if it is, then check to see the owner of the index.php, moduleinterface.php
-  # and the uploads and modules directory.  if they all match, then we
-  # can upload files.
-  # if safe mode is off, then we just have to check the permissions.
-  $gCms = cmsms();
-  $file_index = $gCms->config['root_path'].DIRECTORY_SEPARATOR.'index.php';
-  $dir_uploads = $gCms->config['uploads_path'];
-
-  $stat_index = @stat($file_index);
-  $stat_uploads = @stat($dir_uploads);
-
-  if( $stat_index == FALSE || $stat_uploads == FALSE )
-    {
-      // couldn't get some necessary information.
-      return false;
-    }
-
-  $safe_mode = ini_get_boolean('safe_mode');
-  if( $safe_mode )
-    {
-      // we're in safe mode.
-      if( $stat_index[4] != $stat_uploads[4] )
-	{
-	  return FALSE;
-	}
-    }
-
-  // now check to see if we can write to the directories
-  if( !is_writable( $dir_modules ) )
-    {
-      return FALSE;
-    }
-  if( !is_writable( $dir_uploads ) )
-    {
-      return FALSE;
-    }
-
-  // It all worked.
-  return TRUE;
-}
-
 
 /**
  * A function to test if permissions, and php configuration is setup correctly
@@ -1694,12 +1466,11 @@ function can_admin_upload()
   # and the uploads and modules directory.  if they all match, then we
   # can upload files.
   # if safe mode is off, then we just have to check the permissions.
-  $gCms = cmsms();
-  $file_index = $gCms->config['root_path'].DIRECTORY_SEPARATOR.'index.php';
-  $file_moduleinterface = $gCms->config['root_path'].DIRECTORY_SEPARATOR.
-    $gCms->config['admin_dir'].DIRECTORY_SEPARATOR.'moduleinterface.php';
-  $dir_uploads = $gCms->config['uploads_path'];
-  $dir_modules = $gCms->config['root_path'].DIRECTORY_SEPARATOR.'modules';
+  $file_index = cmsms()->config['root_path'].DIRECTORY_SEPARATOR.'index.php';
+  $file_moduleinterface = cmsms()->config['root_path'].DIRECTORY_SEPARATOR.
+    cmsms()->config['admin_dir'].DIRECTORY_SEPARATOR.'moduleinterface.php';
+  $dir_uploads = cmsms()->config['uploads_path'];
+  $dir_modules = cmsms()->config['root_path'].DIRECTORY_SEPARATOR.'modules';
 
   $stat_index = @stat($file_index);
   $stat_moduleinterface = @stat($file_moduleinterface);
@@ -1719,7 +1490,6 @@ function can_admin_upload()
   $safe_mode = ini_get_boolean('safe_mode');
   if( $safe_mode )
     {
-
       // we're in safe mode.
       if( ($stat_moduleinterface[4] != $stat_modules[4]) ||
 	  ($stat_moduleinterface[4] != $stat_uploads[4]) ||
@@ -1745,6 +1515,7 @@ function can_admin_upload()
 }
 
 
+
 /** 
  * A convenience function to interpret octal permissions, and return 
  * a human readable string.  Uses the lang() function for translation.
@@ -1752,6 +1523,7 @@ function can_admin_upload()
  * @internal
  * @param int The permissions to test.
  * @return string
+ * Rolf: only used in admin/siteprefs.php
  */
 function interpret_permissions($perms)
 {
@@ -1763,10 +1535,12 @@ function interpret_permissions($perms)
     {
       $owner[] = lang('read');
     }
+	
   if( $perms & 0200 )
     {
       $owner[] = lang('write');
     }
+	
   if( $perms & 0100 )
     {
       $owner[] = lang('execute');
@@ -1776,10 +1550,12 @@ function interpret_permissions($perms)
     {
       $group[] = lang('read');
     }
+	
   if( $perms & 0020 )
     {
       $group[] = lang('write');
     }
+	
   if( $perms & 0010 )
     {
       $group[] = lang('execute');
@@ -1789,10 +1565,12 @@ function interpret_permissions($perms)
     {
       $other[] = lang('read');
     }
+	
   if( $perms & 0002 )
     {
       $other[] = lang('write');
     }
+	
   if( $perms & 0001 )
     {
       $other[] = lang('execute');
@@ -1802,11 +1580,13 @@ function interpret_permissions($perms)
 }
 
 
+
 /**
  * A convenience function to return a boolean variable given a php ini key that represents a boolean
  *
  * @param string  The php ini key
  * @return integer
+ * Rolf: only used in admin/header.php
  */
 function ini_get_boolean($str)
 {
@@ -1819,6 +1599,8 @@ function ini_get_boolean($str)
   return $ret;
 }
 
+
+
 /**
  * Another convenience function to output a human readable function stack trace
  *
@@ -1842,6 +1624,7 @@ function stack_trace()
 }
 
 
+
 /** 
  * A wrapper around move_uploaded_file that attempts to ensure permissions on uploaded
  * files are set correctly.
@@ -1864,6 +1647,7 @@ function cms_move_uploaded_file( $tmpfile, $destination )
 }
 
 
+
 /**
  * A function to read CSS cache information
  *
@@ -1871,6 +1655,7 @@ function cms_move_uploaded_file( $tmpfile, $destination )
  * @internal
  * @param string Filename containing cash information
  * @return array of css cache information
+ * Rolf: only used in admin/editcss.php
  */
 function csscache_csvfile_to_hash($filename)
 {
@@ -1887,6 +1672,8 @@ function csscache_csvfile_to_hash($filename)
   return $result;
 }
 
+
+
 /**
  * A function to take hash information representing CSS cache data and store it in a CSV file
  *
@@ -1895,6 +1682,7 @@ function csscache_csvfile_to_hash($filename)
  * @param string Filename to output information to
  * @param array  Hash of CSS cache information.
  * @return void
+ * Rolf: only used in admin/editcss.php
  */
 function csscache_hash_to_csvfile($filename,$hash)
 {
@@ -1909,19 +1697,6 @@ function csscache_hash_to_csvfile($filename,$hash)
   fclose($fh);
 }
 
-/**
- * A function to clear clear the cached CSS information
- *
- * @deprecated
- * @internal
- * @param string Filename containing CSS cache information
- * @return void
- */
-function css_cache_clear($filename)
-{
-  @unlink($filename);
-}
-
 
 /**
  * A function to test wether an IP address matches a list of expressions
@@ -1935,6 +1710,7 @@ function css_cache_clear($filename)
  * @param string IP address to test
  * @param array  Array of match expressions
  * @return boolean
+ * Rolf: only used in lib/content.functions.php
  */
 function cms_ipmatches($ip,$checklist)
 {
@@ -2014,7 +1790,6 @@ function cms_ipmatches($ip,$checklist)
   return FALSE;
 }
 
-
 /**
  * @author	Dominic Sayers <dominic_sayers@hotmail.com>
  * @copyright	2009 Dominic Sayers
@@ -2367,12 +2142,14 @@ function is_email( $email, $checkDNS=false ) {
 }
 
 
+
 /**
  * A convenience method to output the secure param tag that is used on all admin links
  *
  * @internal
  * @access private
  * @return string
+ * Rolf: only used in admin/imagefiles.php
  */
 function get_secure_param()
 {
@@ -2386,6 +2163,10 @@ function get_secure_param()
 }
 
 
+
+/**
+ * Rolf: only used in lib/classes/contenttypes/Content.inc.php
+ */
 function cms_to_bool($str)
 {
   if( is_numeric($str) )
@@ -2399,6 +2180,10 @@ function cms_to_bool($str)
 }
 
 
+
+/**
+ *
+ */
 function cms_get_jquery($exclude = '',$ssl = false,$cdn = false,$append = '',$custom_root='')
 {
   $config = cms_config::get_instance();
@@ -2406,16 +2191,28 @@ function cms_get_jquery($exclude = '',$ssl = false,$cdn = false,$append = '',$cu
   $basePath=$custom_root!=''?trim($custom_root,'/'):($ssl?$config['ssl_url']:$config['root_url']);
   
   // Scripts to include
-  $scripts['jquery-1.6.2.min.js'] = '<script type="text/javascript" src="'.($cdn?'https://ajax.googleapis.com/ajax/libs/jquery/1.6.2/jquery.min.js':$basePath.'/lib/jquery/js/jquery-1.6.2.min.js').'"></script>'."\n";
-  $scripts['jquery-ui-1.8.14.min.js'] = '<script type="text/javascript" src="'.($cdn?'https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.14/jquery-ui.min.js':$basePath.'/lib/jquery/js/jquery-ui-1.8.14.min.js').'"></script>'."\n";
-  $scripts['jquery.ui.nestedSortable-1.3.4.js'] = '<script type="text/javascript" src="'.$basePath.'/lib/jquery/js/jquery.ui.nestedSortable-1.3.4.js"></script>'."\n";
-  $scripts['jquery.json-2.2.js'] = '<script type="text/javascript" src="'.$basePath.'/lib/jquery/js/jquery.json-2.2.js"></script>'."\n";
+  $scripts['jquery.min.js'] = '<script type="text/javascript" src="'.($cdn?'https://ajax.googleapis.com/ajax/libs/jquery/1.7.2/jquery.min.js':$basePath.'/lib/jquery/js/jquery-1.7.2.min.js').'"></script>'."\n";
+  $scripts['jquery-ui.min.js'] = '<script type="text/javascript" src="'.($cdn?'https://ajax.googleapis.com/ajax/libs/jqueryui/1.8.21/jquery-ui.min.js':$basePath.'/lib/jquery/js/jquery-ui-1.8.21.custom.min.js').'"></script>'."\n";
+  $scripts['jquery.ui.nestedSortable.js'] = '<script type="text/javascript" src="'.$basePath.'/lib/jquery/js/jquery.ui.nestedSortable-1.3.4.js"></script>'."\n";
+  $scripts['jquery.json.min.js'] = '<script type="text/javascript" src="'.$basePath.'/lib/jquery/js/jquery.json-2.3.min.js"></script>'."\n";
   
   // Check if we need exclude some script
   if(!empty($exclude)) {
     
     $exclude_list = explode(",", trim(str_replace(' ','',$exclude)));
     foreach($exclude_list as $one) {
+      if ($one == 'jquery-1.6.2.min.js') {
+          $one = 'jquery.min.js';
+      }
+      if ($one == 'jquery-ui-1.8.14.min.js') {
+          $one = 'jquery-ui.min.js';
+      }
+      if ($one == 'jquery.json-2.2.js') {
+          $one = 'jquery.json.min.js';
+      }
+      if ($one == 'jquery.ui.nestedSortable-1.3.4.js') {
+          $one = 'jquery.ui.nestedSortable.js';
+      }
       
       unset($scripts[$one]);
     }		
@@ -2435,5 +2232,47 @@ function cms_get_jquery($exclude = '',$ssl = false,$cdn = false,$append = '',$cu
   }
   return $output;
 }
+	
+	
+
+/**
+ * Rolf: only used in lib/classes/class.CMSModule.php
+ */	
+if(!function_exists('get_called_class')) {
+  function get_called_class() {
+    return cms_function_help::get_called_class();
+  }
+  // this class must exist in this file until CMSMS 1.12 when we dont have to worry abut PHP 5.2
+  // this file is loaded before the autoloader runs.
+  class cms_function_help {
+
+    static $i = 0;
+    static $fl = null;
+	
+    public static function get_called_class() {
+	
+      $bt = debug_backtrace();
+		
+      if(self::$fl == $bt[2]['file'].$bt[2]['line']) {
+	self::$i++;
+      } else {
+	self::$i = 0;
+	self::$fl = $bt[2]['file'].$bt[2]['line'];
+      }
+		
+      $lines = file($bt[2]['file']);
+		
+      preg_match_all('/([a-zA-Z0-9\_]+)::'.$bt[2]['function'].'/',
+		     $lines[$bt[2]['line']-1],
+		     $matches);
+		
+      if( isset($matches[1][self::$i]) )
+	{
+	  return $matches[1][self::$i];
+	}
+    }
+  }
+}
+
 # vim:ts=4 sw=4 noet
 ?>
