@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: page.functions.php 7496 2011-10-29 19:11:00Z calguy1000 $
+#$Id: page.functions.php 8145 2012-06-30 16:02:30Z calguy1000 $
 
 /**
  * Page related functions.  Generally these are functions not necessarily
@@ -35,8 +35,7 @@
  * @return boolean
  */
 function check_login($no_redirect = false)
-{
-  
+{  
   $config = cmsms()->GetConfig();
 
 	//Handle a current login if one is in queue in the SESSION
@@ -88,8 +87,6 @@ function check_login($no_redirect = false)
 		}
 	}
 
-	debug_buffer('Session found.  Moving on...');
-
 	global $CMS_ADMIN_PAGE;
 	if( ($config['debug'] === false) && isset($CMS_ADMIN_PAGE) )
 	  {
@@ -214,64 +211,6 @@ function generate_user_object($userid)
 }
 
 
-/**
- * A function to send lost password recovery email to a specified admin user (by name)
- *
- * @internal
- * @access private
- * @param string the username
- * @return results from the attempt to send a message.
- */
-function send_recovery_email($username)
-{
-  $gCms = cmsms();
-  $config = $gCms->GetConfig();
-  $userops = $gCms->GetUserOperations();
-  $user = $userops->LoadUserByUsername($username);
-  
-  $obj = cms_utils::get_module('CMSMailer');
-  if ($obj == null)
-    {
-      return false;
-    }
-	
-  $obj->AddAddress($user->email, html_entity_decode($user->firstname . ' ' . $user->lastname));
-  $obj->SetSubject(lang('lostpwemailsubject',html_entity_decode(get_site_preference('sitename','CMSMS Site'))));
-  
-  $url = $config['admin_url'] . '/login.php?recoverme=' . md5(md5($config['root_path'] . '--' . $user->username . md5($user->password)));
-  $body = lang('lostpwemail',html_entity_decode(get_site_preference('sitename','CMSMS Site')), $user->username, $url);
-  
-  $obj->SetBody($body);
-  
-  audit('','Core','Sent Lost Password Email for '.$username);
-  return $obj->Send();
-}
-
-/**
- * A function find a matching user id given an identity hash
- *
- * @internal
- * @access private
- * @param string the hash
- * @return object The matching user object if found, or null otherwise.
- */
-function find_recovery_user($hash)
-{
-  $gCms = cmsms();
-	$config = $gCms->GetConfig();
-	$userops = $gCms->GetUserOperations();
-	
-	foreach ($userops->LoadUsers() as $user)
-	{
-		if ($hash == md5(md5($config['root_path'] . '--' . $user->username . md5($user->password))))
-		{
-			return $user;
-		}
-	}
-	
-	return null;
-}
-
 /**
  * Loads all permissions for a particular user into a global variable so we don't hit the db for every one.
  *
@@ -503,6 +442,7 @@ function quick_check_authorship($contentid, $hispages)
  */
 function audit($itemid, $itemname, $action)
 {
+  if( !isset($action) ) $action = '-- unset --';
   $db = cmsms()->GetDb();
 
   $userid = 0;
@@ -610,137 +550,6 @@ function set_preference($userid, $prefname, $value)
 }
 
 
-/**
- * Returns the stylesheet for the given templateid.  Returns a hash with encoding and stylesheet entries.
- *
- * @since 0.1
- * @internal
- * @deprecated
- * @param integer template id
- * @param string  An optional media type
- * @return string
- */
-function get_stylesheet($template_id, $media_type = '')
-{
-	$result = array();
-	$css = "";
-
-	$gCms = cmsms();
-	$db = $gCms->GetDb();
-	$templateops =& $gCms->GetTemplateOperations();
-
-	$templateobj = FALSE;
-
-	#Grab template id and make sure it's actually "somewhat" valid
-	if (isset($template_id) && is_numeric($template_id) && $template_id > -1)
-	{
-		#Ok, it's valid, let's load the bugger
-		$templateobj =& $templateops->LoadTemplateById($template_id);
-	}
-
-	#If it's valid after loading, then start the process...
-	if ($templateobj !== FALSE && ($templateobj->active == '1' || $templateobj->active == TRUE) )
-	{
-		#Grab the encoding
-		if ($templateobj->encoding !== FALSE && $templateobj->encoding != '')
-		{
-			$result['encoding'] = $templateobj->encoding;
-		}
-		else
-		{
-			$result['encoding'] = get_encoding();
-		}
-
-		#Load in the "standard" template CSS if media type is empty
-		if ($media_type == '')
-		{
-			if (isset($templateobj->stylesheet) && $templateobj->stylesheet != '')
-			{
-				$css .= $templateobj->stylesheet;
-			}
-		}
-
-		#Handle "advanced" CSS Management
-		$cssquery = "SELECT css_text FROM ".cms_db_prefix()."css c, ".cms_db_prefix()."css_assoc ca
-			WHERE	css_id		= assoc_css_id
-			AND		assoc_type	= 'template'
-			AND		assoc_to_id = ?
-			AND		c.media_type = ? ORDER BY ca.create_date";
-		$cssresult =& $db->Execute($cssquery, array($template_id, $media_type));
-
-		while ($cssresult && $cssline = $cssresult->FetchRow())
-		{
-			$css .= "\n".$cssline['css_text']."\n";
-		}
-		
-		if ($cssresult) $cssresult->Close();
-	}
-	else
-	{
-		$result['nostylesheet'] = true;
-		$result['encoding'] = get_encoding();
-	}
-
-	#$css = preg_replace("/[\r\n]/", "", $css); //hack for tinymce
-	$result['stylesheet'] = $css;
-
-	return $result;
-}
-
-
-/**
- * Return a list of the media types supported for the specified template
- *
- * @internal
- * @access private
- * @param integer The template ID
- * @return array
- */
-function get_stylesheet_media_types($template_id)
-{
-	$result = array();
-
-	$gCms = cmsms();
-	$db = $gCms->GetDb();
-	$templateops =& $gCms->GetTemplateOperations();
-
-	$templateobj = FALSE;
-
-	#Grab template id and make sure it's actually "somewhat" valid
-	if (isset($template_id) && is_numeric($template_id) && $template_id > -1)
-	{
-		#Ok, it's valid, let's load the bugger
-		$templateobj = $templateops->LoadTemplateById($template_id);
-		if (isset($templateobj->stylesheet) && $templateobj->stylesheet != '')
-		{
-			$result[] = '';
-		}
-	}
-
-	#If it's valid after loading, then start the process...
-	if ($templateobj !== FALSE && ($templateobj->active == '1' || $templateobj->active == TRUE) )
-	{
-		#Handle "advanced" CSS Management
-		$cssquery = "SELECT DISTINCT media_type FROM ".cms_db_prefix()."css c, ".cms_db_prefix()."css_assoc
-			WHERE	css_id		= assoc_css_id
-			AND		assoc_type	= 'template'
-			AND		assoc_to_id = ?";
-		$cssresult = &$db->Execute($cssquery, array($template_id));
-
-		while ($cssresult && !$cssresult->EOF)
-		{
-			if (!in_array($cssresult->fields['media_type'], $result))
-				$result[] =& $cssresult->fields['media_type'];
-			$cssresult->MoveNext();
-		}
-		
-		if ($cssresult) $cssresult->Close();
-	}
-
-	return $result;
-}
-
-
 /**
  * Strips slashes from an array of values.
  *
@@ -748,7 +557,7 @@ function get_stylesheet_media_types($template_id)
  * @param array A reference to an array of strings
  * @return reference to the cleaned values
  */
-function & stripslashes_deep(&$value) 
+function & stripslashes_deep(&$value)
 { 
         if (is_array($value)) 
         { 
@@ -761,27 +570,6 @@ function & stripslashes_deep(&$value)
         return $value;
 }
 
-function create_vanilla_textarea($text, $name, $classname = '', $id = '', $encoding = '', $width = '80', $height = '15', $addtext='')
-{
-  $result = '<textarea name="' . $name . '" cols="' . $width . '" rows="' . $height . '"';
-  if ($classname != '') {
-    $result .= ' class="' . $classname . '"';
-  }
-  else
-  {
-    $result .= ' class="cms_textarea"';
-  }
-  if ($id != '') {
-    $result .= ' id="' . $id . '"';
-  }
-  if (!empty($addtext)) {
-    $result .= ' ' . $addtext;
-  }
-
-  $result .= '>' . cms_htmlentities($text, ENT_NOQUOTES, get_encoding($encoding)) . '</textarea>';
-  return $result;
-}
-
 /**
  * A method to create a text area control
  *
@@ -928,6 +716,7 @@ function cms_db_prefix() {
  * @param string Text containing additional parameters for the dropdown element
  * @param string A prefix to use when filtering files
  * @param boolean A flag indicating wether the files matching the extension and the prefix should be included or excluded from the result set
+ * @param boolean A flag indicating wether the output should be sorted.
  * @return string
  */
 function create_file_dropdown($name,$dir,$value,$allowed_extensions,$optprefix='',$allownone=false,$extratext='',
@@ -1061,10 +850,10 @@ function get_pageid_or_alias_from_url()
   if( is_object($route) )
     {
       $matched = true;
-      if( $route->is_content() )
+      if( $route['key1'] == '__CONTENT__' )
 	{
 	  // a route to a page.
-	  $page = $route->get_content();
+	  $page = (int)$route['key2'];
 	}
       else
 	{
@@ -1141,23 +930,5 @@ function get_pageid_or_alias_from_url()
   return $page;
 }
 
-
-/**
- * Function to return the current page id.
- * 
- * Will return FALSE if in an admin action.
- *
- * @return integer pageid indicating the current page, or FALSE.
- */
-function cms_get_current_pageid()
-{
-  $gCms = cmsms();
-
-  if( isset($gCms->variables['page_id']) )
-    {
-      return (int)$gCms->variables['page_id'];
-    }
-  return FALSE;
-}
 # vim:ts=4 sw=4 noet
 ?>
