@@ -16,7 +16,7 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: listmodules.php 7493 2011-10-29 17:48:31Z calguy1000 $
+#$Id: listmodules.php 8185 2012-07-16 19:54:35Z calguy1000 $
 
 $CMS_ADMIN_PAGE=1;
 $CMS_PREVENT_AUTOINSTALL=1;
@@ -63,6 +63,7 @@ if ($access)
 		}
 		else
 		{
+		  audit('','Core','Changed permissions on '.$module.' directory');
 			redirect($thisurl);
 		}
 	}
@@ -74,8 +75,11 @@ if ($access)
 		$files = 0;
 		$old_display_errors = ini_set('display_errors',0);
 		$modops = $gCms->GetModuleOperations();
+		$orig_lang = CmsNlsOperations::get_current_language();
+		CmsNlsOperations::set_language('en_US');
 		$object = cms_utils::get_module($module);
 		$xmltxt = $modops->CreateXMLPackage($object,$message,$files);
+		CmsNlsOperations::set_language($orig_lang);
 		if( $files == 0 )
 		{
 			echo "<p class=\"error\">".lang('errornofilesexported')."</p>";
@@ -87,6 +91,7 @@ if ($access)
 		else 
 		{
 			$xmlname = $object->GetName().'-'.$object->GetVersion().'.xml';
+			audit('','Core','Exported '.$object->GetName().' to '.$xmlname);
 
 			// and send the file
 			ob_end_clean();
@@ -111,9 +116,9 @@ if ($access)
 		{
 			// normalize the file variable
 			$file = $_FILES[$fieldName];
-
-			// $file['tmp_name'] is the file we have to parse
-			// $xml = file_get_contents( $file['tmp_name'] );
+			if( !isset($file['tmp_name']) || trim($file['tmp_name']) == '' ) {
+			  echo $themeObject->ShowErrors(lang('noxmlfileuploaded').' (empty tmp_name)');
+			}
 
 			// and parse it
 			$modops = $gCms->GetModuleOperations();
@@ -155,6 +160,7 @@ if ($access)
 			    else if( $autoinstallupgrade == 0 )
 			      {
 				// no auto install or upgrade
+				audit('','Core','Expanded XML Package '.$file['name']);
 				redirect($thisurl);
 			      }
 			  }
@@ -290,6 +296,7 @@ if ($access)
 	{
 		$query = "UPDATE ".cms_db_prefix()."modules SET active = ? WHERE module_name = ?";
 		$db->Execute($query, array(1,$module));
+		audit('','Core','Activated module '.$module);
 		cmsms()->clear_cached_files();
 		redirect($thisurl);
 	}
@@ -298,6 +305,7 @@ if ($access)
 	{
 		$query = "UPDATE ".cms_db_prefix()."modules SET active = ? WHERE module_name = ?";
 		$db->Execute($query, array(0,$module));
+		audit('','Core','Deactivated module '.$module);
 		cmsms()->clear_cached_files();
 		redirect($thisurl);
 	}
@@ -320,11 +328,11 @@ else if ($action == "showmodulehelp")
   $modinstance = ModuleOperations::get_instance()->get_module_instance($module,'',TRUE);
   if( is_object($modinstance) )
     {
-      $orig_lang =  cms_admin_current_language();
+      $orig_lang =  CmsNlsOperations::get_current_language();
       $modulehelp_yourlang = lang('modulehelp_yourlang');
       if( isset($_GET['lang']) && $orig_lang != 'en_US' )
 	{
-	  cms_set_admin_language(trim($_GET['lang']));
+	  CmsNlsOperations::set_language(trim($_GET['lang']));
 	}
 
       echo '<div class="pagecontainer">';
@@ -351,7 +359,7 @@ else if ($action == "showmodulehelp")
 
       if( $orig_lang != 'en_US' )
 	{
-	  $cur_lang = cms_admin_current_language();
+	  $cur_lang = CmsNlsOperations::get_current_language();
 	  if( $cur_lang == 'en_US' )
 	    {
 	      $header .= '<span class="helptext"><a href="listmodules.php?'.CMS_SECURE_PARAM_NAME.'='.$_SESSION[CMS_USER_KEY].'&amp;action=showmodulehelp&amp;module='.$module.'&amp;lang='.$orig_lang.'">'.$modulehelp_yourlang.'</a></span>';
@@ -390,7 +398,7 @@ else if ($action == "showmodulehelp")
       $modinstance->params = array(array('name'=>'lang','default'=>'en_US','optional'=>true));
       $modinstance->curlang = $mod_old_lang;
       echo "</div>";
-      cms_set_admin_language($orig_lang);
+      CmsNlsOperations::set_language($orig_lang);
     }
   
   echo '<p class="pageback"><a class="pageback" href="'.$thisurl.'">&#171; '.lang('back').'</a></p>';
@@ -476,14 +484,15 @@ else
       <table cellspacing="0" class="pagetable">
 	 <thead>
 	 <tr>
-	 <th><?php echo lang('name')?></th>
-	 <th><?php echo lang('version')?></th>
-	 <th><?php echo lang('status')?></th>
+	 <th class="modname"><?php echo lang('name')?></th>
+	 <th class="modvers"><?php echo lang('version')?></th>
+	 <th class="modstatus"><?php echo lang('status')?></th>
 	 <th class="pagepos"><?php echo lang('active')?></th>
-	 <th><?php echo lang('action')?></th>
-	 <th><?php echo lang('help')?></th>
-	 <th><?php echo lang('about')?></th>
-	 <th><?php echo lang('export')?></th>
+	 <th class="modaction"><?php echo lang('action')?></th>
+	 <th class="modcachable"><?php echo lang('cachable')?></th>
+	 <th class="modhelp"><?php echo lang('help')?></th>
+	 <th class="modabout"><?php echo lang('about')?></th>
+	 <th class="modexport"><?php echo lang('export')?></th>
 	 </tr>
 	 </thead>
 	 <tbody>
@@ -497,6 +506,7 @@ else
       foreach($allmodules as $key)
 	{
 	  $modinstance = $modops->get_module_instance($key,'',true);
+	  if( !is_object($modinstance) ) continue; // interesting.
 	  $is_sysmodule = $modops->IsSystemModule($key);
 	  $namecol = $key;
 	  $versioncol = "&nbsp;";
@@ -507,6 +517,7 @@ else
 	  $helpcol = "&nbsp;";
 	  $aboutcol = "&nbsp;";	  
 	  $xmlcol = "&nbsp;";
+	  $cachablecol = '&nbsp;';
 
 	  $xmlcol = '<a href="'.$thisurl.'&amp;action=exportxml&amp;module='.$key.'"><img border="0" src="../modules/ModuleManager/images/xml_rss.gif" alt="'.lang('xml').'" /></a>';
 	  
@@ -599,6 +610,7 @@ else
 	    {
 	      $versioncol = $dbm[$key]['Version'];
 	      $statuscol[]  = lang('installed');
+	      $cachablecol = $modinstance->AllowSmartyCaching()?lang('yes'):lang('no');
 	      //$actioncol  = "&nbsp;";
 	      
 	      // Can't be removed if it has a dependency...
@@ -653,6 +665,7 @@ else
 	      echo '<td class="pagepos">'.$activecol.'</td>';
 	      echo '<td>'.implode('<br/>',$actioncol).'</td>';
 	    }
+	  echo "<td>$cachablecol</td>";
 	  echo "<td>$helpcol</td>";
 	  echo "<td>$aboutcol</td>";
 	  echo "<td>$xmlcol</td>";
