@@ -16,9 +16,10 @@
 #along with this program; if not, write to the Free Software
 #Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 #
-#$Id: login.php 7441 2011-09-25 20:51:24Z calguy1000 $
+#$Id: login.php 8122 2012-06-27 10:12:30Z rolf1 $
 
 $CMS_ADMIN_PAGE=1;
+$CMS_LOGIN_PAGE=1;
 
 require_once("../include.php");
 require_once("../lib/classes/class.user.inc.php");
@@ -29,6 +30,66 @@ $error = "";
 $forgotmessage = "";
 $changepwhash = "";
 
+/**
+ * A function to send lost password recovery email to a specified admin user (by name)
+ *
+ * @internal
+ * @access private
+ * @param string the username
+ * @return results from the attempt to send a message.
+ */
+function send_recovery_email($username)
+{
+  $gCms = cmsms();
+  $config = $gCms->GetConfig();
+  $userops = $gCms->GetUserOperations();
+  $user = $userops->LoadUserByUsername($username);
+  
+  $obj = cms_utils::get_module('CMSMailer');
+  if ($obj == null)
+    {
+      return false;
+    }
+	
+  $obj->AddAddress($user->email, html_entity_decode($user->firstname . ' ' . $user->lastname));
+  $obj->SetSubject(lang('lostpwemailsubject',html_entity_decode(get_site_preference('sitename','CMSMS Site'))));
+  
+  $url = $config['admin_url'] . '/login.php?recoverme=' . md5(md5($config['root_path'] . '--' . $user->username . md5($user->password)));
+  $body = lang('lostpwemail',html_entity_decode(get_site_preference('sitename','CMSMS Site')), $user->username, $url);
+  
+  $obj->SetBody($body);
+  
+  audit('','Core','Sent Lost Password Email for '.$username);
+  return $obj->Send();
+}
+
+/**
+ * A function find a matching user id given an identity hash
+ *
+ * @internal
+ * @access private
+ * @param string the hash
+ * @return object The matching user object if found, or null otherwise.
+ */
+function find_recovery_user($hash)
+{
+  $gCms = cmsms();
+	$config = $gCms->GetConfig();
+	$userops = $gCms->GetUserOperations();
+	
+	foreach ($userops->LoadUsers() as $user)
+	{
+		if ($hash == md5(md5($config['root_path'] . '--' . $user->username . md5($user->password))))
+		{
+			return $user;
+		}
+	}
+	
+	return null;
+}
+
+
+
 //Redirect to the normal login screen if we hit cancel on the forgot pw one
 //Otherwise, see if we have a forgotpw hit
 if ((isset($_REQUEST['forgotpwform']) || isset($_REQUEST['forgotpwchangeform'])) && isset($_REQUEST['logincancel']))
@@ -129,21 +190,25 @@ else if ( isset($_SESSION['redirect_url']) )
 	if (true == $is_logged_in)
 	{
 		$userid = get_userid();
-		$homepage = get_preference($userid,'homepage');
+		$homepage = get_preference($userid,'homepage'.'index.php');
 		
 		$homepage = str_replace('&amp;','&',$homepage);
 		$tmp = explode('?',$homepage);
 		if( !file_exists($tmp[0]) ) $tmp[0] = 'index.php';
-		parse_str($tmp[1],$tmp2);
-		if( in_array('_s_',array_keys($tmp2)) ) unset($tmp2['_s_']);
-		if( in_array('sp_',array_keys($tmp2)) ) unset($tmp2['sp_']);
+		$tmp2 = array();
+		if( isset($tmp[1]) )
+                {
+		  parse_str($tmp[1],$tmp2);
+		  if( in_array('_s_',array_keys($tmp2)) ) unset($tmp2['_s_']);
+		  if( in_array('sp_',array_keys($tmp2)) ) unset($tmp2['sp_']);
+                }
 		$tmp2[CMS_SECURE_PARAM_NAME] = $_SESSION[CMS_USER_KEY];
+		$tmp3 = array();
 		foreach( $tmp2 as $k => $v )
 		  {
-		    $tmp3[] = $k.'='.$v;
+		     $tmp3[] = $k.'='.$v;
 		  }
 		$homepage = $tmp[0].'?'.implode('&amp;',$tmp3);
-		
 		$homepage = html_entity_decode($homepage);
 		redirect($homepage);
 	}
@@ -226,7 +291,7 @@ if (isset($_POST["username"]) && isset($_POST["password"])) {
 			      $tmp = $config['admin_url'].'/index.php?'.CMS_SECURE_PARAM_NAME.'='.$_SESSION[CMS_USER_KEY];
 			      debug_to_log('change session var to '.$tmp);
 			    }
-			  
+			 
 			  redirect($tmp);
 			}
 			unset($_SESSION["redirect_url"]);
@@ -252,7 +317,7 @@ if (isset($_POST["username"]) && isset($_POST["password"])) {
 			  $homepage = str_replace('&amp;','&',$homepage);
 			  $tmp = explode('?',$homepage);
 			  if( !file_exists($tmp[0]) ) $tmp[0] = 'index.php';
-			  parse_str($tmp[1],$tmp2);
+			  @parse_str($tmp[1],$tmp2);
 			  if( in_array('_s_',array_keys($tmp2)) ) unset($tmp2['_s_']);
 			  if( in_array('sp_',array_keys($tmp2)) ) unset($tmp2['sp_']);
 			  $tmp2[CMS_SECURE_PARAM_NAME] = $_SESSION[CMS_USER_KEY];
@@ -277,7 +342,7 @@ if (isset($_POST["username"]) && isset($_POST["password"])) {
 		Events::SendEvent('Core','LoginFailed',array('user'=>$_POST['username']));;
 		// put mention into the admin log
 		$ip_login_failed = cms_utils::get_real_ip(); 
-		audit('', "Admin Username: ".$username.' (IP: '.$ip_login_failed.')', 'Login Failed');
+		audit('', '(IP: ' . $ip_login_failed . ') ' . "Admin Username: " . $username, 'Login Failed');
 
 		#Now call the event
 		//Events::SendEvent('Core', 'LoginPost', $username);
@@ -291,19 +356,24 @@ if (isset($_POST["username"]) && isset($_POST["password"])) {
 }
 
 // Language shizzle
-//header("Content-Encoding: " . get_encoding());
-header("Content-Language: " . $current_language);
-header("Content-Type: text/html; charset=" . get_encoding());
+cms_admin_sendheaders();
+header("Content-Language: " . CmsNlsOperations::get_current_language());
 
 //CHANGED
-$theme=get_site_preference('logintheme', 'default');
-//echo "theme:$theme";
 debug_buffer('debug is:' . $error);
-if (file_exists(dirname(__FILE__)."/themes/$theme/login.php")) {
-	include(dirname(__FILE__)."/themes/$theme/login.php");
-} else {
-	include(dirname(__FILE__)."/themes/default/login.php");
-}
+$themeName = CmsAdminThemeBase::GetDefaultTheme();
+$themeObject = CmsAdminThemeBase::GetThemeObject($themeName);
+
+$vars = array('error'=>$error);
+if( isset($warningLogin) ) $vars['warningLogin'] = $warningLogin;
+if( isset($acceptLogin) ) $vars['acceptLogin'] = $acceptLogin;
+if( isset($changepwhash) ) $vars['changepwhash'] = $changepwhash;
+$themeObject->do_login($vars);
+// if (file_exists(dirname(__FILE__)."/themes/$theme/login.php")) {
+// 	include(dirname(__FILE__)."/themes/$theme/login.php");
+// } else {
+// 	include(dirname(__FILE__)."/themes/default/login.php");
+// }
 //STOP
 ?>
 
